#include "sbbzip2.h"

SB_PHP_METHOD(TBzip2Context, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TBzip2Context));
		intern->len = sizeof(TBzip2Context);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TBzip2Context, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TBzip2Context));
}

zend_class_entry *TBzip2Context_ce_ptr = NULL;

static zend_function_entry TBzip2Context_methods[] = {
	PHP_ME(TBzip2Context, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TBzip2Context, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_FE_END
};

void Register_TBzip2Context(TSRMLS_D)
{
	zend_class_entry ce;
	if (TBzip2Context_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TBzip2Context", TBzip2Context_methods);
	TBzip2Context_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

void SB_CALLBACK TSBBzip2OutputFuncRaw(void * _ObjectData, void * Buffer, int32_t Size, void * Param, int8_t * OutResult)
{
	zval **params[3];
	zval * zBuffer;
	zval * zSize;
	zval * zParam;
	zval * pzOutResult = NULL;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zBuffer);
	SBInitPointerObject(zBuffer, Buffer TSRMLS_CC);
	MAKE_STD_ZVAL(zSize);
	ZVAL_LONG(zSize, (long)Size);
	MAKE_STD_ZVAL(zParam);
	SBInitPointerObject(zParam, Param TSRMLS_CC);

	params[0] = &zBuffer;
	params[1] = &zSize;
	params[2] = &zParam;
	SBCallEvent((zval *)_ObjectData, &pzOutResult, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zBuffer);
	zval_ptr_dtor(&zSize);
	zval_ptr_dtor(&zParam);
	if (pzOutResult)
	{
		*OutResult = (int8_t)Z_BVAL_P(pzOutResult);
		zval_ptr_dtor(&pzOutResult);
	}
}

SB_PHP_FUNCTION(SBBzip2, InitializeCompression)
{
	long l4CompressionLevel;
	long u4Verbosity;
	long u4WorkFactor;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Olll", &oContext, TBzip2Context_ce_ptr, &l4CompressionLevel, &u4Verbosity, &u4WorkFactor) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBBzip2_InitializeCompression((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), (int32_t)l4CompressionLevel, (uint32_t)u4Verbosity, (uint32_t)u4WorkFactor) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, integer, integer, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzip2, InitializeDecompression)
{
	long u4Verbosity;
	zend_bool bSmall;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Olb", &oContext, TBzip2Context_ce_ptr, &u4Verbosity, &bSmall) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBBzip2_InitializeDecompression((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), (uint32_t)u4Verbosity, (int8_t)bSmall) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, integer, bool)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzip2, Compress)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piParam;
	void *pzOutputFunc;
	zval *oContext;
	zval *zOutputFunc;
	zval *zpInBuffer;
	zval *zpParam;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TBzip2Context_ce_ptr, &zpInBuffer, &u4InSize, &zOutputFunc, &zpParam) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((IS_STRING == Z_TYPE_P(zOutputFunc)) || (IS_ARRAY == Z_TYPE_P(zOutputFunc)) || (IS_CALLABLE == Z_TYPE_P(zOutputFunc)) || (IS_NULL == Z_TYPE_P(zOutputFunc))) && ((Z_TYPE_P(zpParam) == IS_STRING) || (Z_TYPE_P(zpParam) == IS_ARRAY) || (Z_TYPE_P(zpParam) == IS_NULL) || ((Z_TYPE_P(zpParam) == IS_OBJECT) && (Z_OBJCE_P(zpParam) == TSBPointer_ce_ptr))))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		pzOutputFunc = SBSetEventData(zOutputFunc TSRMLS_CC);
		if (!SBGetPointerFromZVal(zpParam, &piParam TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBBzip2_Compress((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, pzOutputFunc ? &TSBBzip2OutputFuncRaw : NULL, pzOutputFunc, piParam.data) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piParam);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, TSBPointer|array of byte|string|NULL, integer, TSBBzip2OutputFunc|callable|NULL, TSBPointer|array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzip2, Decompress)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piParam;
	void *pzOutputFunc;
	zval *oContext;
	zval *zOutputFunc;
	zval *zpInBuffer;
	zval *zpParam;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TBzip2Context_ce_ptr, &zpInBuffer, &u4InSize, &zOutputFunc, &zpParam) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((IS_STRING == Z_TYPE_P(zOutputFunc)) || (IS_ARRAY == Z_TYPE_P(zOutputFunc)) || (IS_CALLABLE == Z_TYPE_P(zOutputFunc)) || (IS_NULL == Z_TYPE_P(zOutputFunc))) && ((Z_TYPE_P(zpParam) == IS_STRING) || (Z_TYPE_P(zpParam) == IS_ARRAY) || (Z_TYPE_P(zpParam) == IS_NULL) || ((Z_TYPE_P(zpParam) == IS_OBJECT) && (Z_OBJCE_P(zpParam) == TSBPointer_ce_ptr))))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		pzOutputFunc = SBSetEventData(zOutputFunc TSRMLS_CC);
		if (!SBGetPointerFromZVal(zpParam, &piParam TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBBzip2_Decompress((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, pzOutputFunc ? &TSBBzip2OutputFuncRaw : NULL, pzOutputFunc, piParam.data) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piParam);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, TSBPointer|array of byte|string|NULL, integer, TSBBzip2OutputFunc|callable|NULL, TSBPointer|array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzip2, FinalizeCompression)
{
	SBArrayZValInfo piParam;
	void *pzOutputFunc;
	zval *oContext;
	zval *zOutputFunc;
	zval *zpParam;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozz", &oContext, TBzip2Context_ce_ptr, &zOutputFunc, &zpParam) == SUCCESS) && PZVAL_IS_REF(oContext) && ((IS_STRING == Z_TYPE_P(zOutputFunc)) || (IS_ARRAY == Z_TYPE_P(zOutputFunc)) || (IS_CALLABLE == Z_TYPE_P(zOutputFunc)) || (IS_NULL == Z_TYPE_P(zOutputFunc))) && ((Z_TYPE_P(zpParam) == IS_STRING) || (Z_TYPE_P(zpParam) == IS_ARRAY) || (Z_TYPE_P(zpParam) == IS_NULL) || ((Z_TYPE_P(zpParam) == IS_OBJECT) && (Z_OBJCE_P(zpParam) == TSBPointer_ce_ptr))))
	{
		pzOutputFunc = SBSetEventData(zOutputFunc TSRMLS_CC);
		if (!SBGetPointerFromZVal(zpParam, &piParam TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBBzip2_FinalizeCompression((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), pzOutputFunc ? &TSBBzip2OutputFuncRaw : NULL, pzOutputFunc, piParam.data) TSRMLS_CC);
		SBFreePointerZValInfo(&piParam);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, TSBBzip2OutputFunc|callable|NULL, TSBPointer|array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzip2, FinalizeDecompression)
{
	SBArrayZValInfo piParam;
	void *pzOutputFunc;
	zval *oContext;
	zval *zOutputFunc;
	zval *zpParam;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozz", &oContext, TBzip2Context_ce_ptr, &zOutputFunc, &zpParam) == SUCCESS) && PZVAL_IS_REF(oContext) && ((IS_STRING == Z_TYPE_P(zOutputFunc)) || (IS_ARRAY == Z_TYPE_P(zOutputFunc)) || (IS_CALLABLE == Z_TYPE_P(zOutputFunc)) || (IS_NULL == Z_TYPE_P(zOutputFunc))) && ((Z_TYPE_P(zpParam) == IS_STRING) || (Z_TYPE_P(zpParam) == IS_ARRAY) || (Z_TYPE_P(zpParam) == IS_NULL) || ((Z_TYPE_P(zpParam) == IS_OBJECT) && (Z_OBJCE_P(zpParam) == TSBPointer_ce_ptr))))
	{
		pzOutputFunc = SBSetEventData(zOutputFunc TSRMLS_CC);
		if (!SBGetPointerFromZVal(zpParam, &piParam TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBBzip2_FinalizeDecompression((TBzip2Context *)SBGetStructPointer(oContext TSRMLS_CC), pzOutputFunc ? &TSBBzip2OutputFuncRaw : NULL, pzOutputFunc, piParam.data) TSRMLS_CC);
		SBFreePointerZValInfo(&piParam);
	}
	else
	{
		SBErrorExpectsArguments("(&TBzip2Context, TSBBzip2OutputFunc|callable|NULL, TSBPointer|array of byte|string|NULL)" TSRMLS_CC);
	}
}

