#include "sbhttpsclient.h"

void SB_CALLBACK TSBHTTPDynamicDataNeededEventRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pBuffer[], int32_t szBuffer, int32_t ToRead, int32_t * Read)
{
	zval *retval_ptr;
	zval **params[4];
	zval * zSender;
	zval * zBuffer;
	zval * zToRead;
	zval * zRead;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zBuffer);
	ZVAL_STRINGL(zBuffer, pBuffer, szBuffer, 1);
	MAKE_STD_ZVAL(zToRead);
	ZVAL_LONG(zToRead, (long)ToRead);
	MAKE_STD_ZVAL(zRead);
	ZVAL_LONG(zRead, (long)*Read);

	params[0] = &zSender;
	params[1] = &zBuffer;
	params[2] = &zToRead;
	params[3] = &zRead;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 4, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zBuffer);
	zval_ptr_dtor(&zToRead);
	*Read = (int32_t)Z_LVAL_P(zRead);
	zval_ptr_dtor(&zRead);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK TSBHTTPRedirectionEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcOldURL, int32_t szOldURL, char * pcNewURL, int32_t * szNewURL, int8_t * AllowRedirection)
{
	zval *retval_ptr;
	zval **params[4];
	zval * zSender;
	zval * zOldURL;
	zval * zNewURL;
	zval * zAllowRedirection;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zOldURL);
	ZVAL_STRINGL(zOldURL, pcOldURL, szOldURL, 1);
	MAKE_STD_ZVAL(zNewURL);
	ZVAL_STRINGL(zNewURL, pcNewURL, *szNewURL, 1);
	MAKE_STD_ZVAL(zAllowRedirection);
	ZVAL_BOOL(zAllowRedirection, (zend_bool)*AllowRedirection);

	params[0] = &zSender;
	params[1] = &zOldURL;
	params[2] = &zNewURL;
	params[3] = &zAllowRedirection;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 4, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zOldURL);
	SBCheckError(SBSetEventReturnStringA(3, Z_STRVAL_P(zNewURL), (int32_t)Z_STRLEN_P(zNewURL)) TSRMLS_CC);
	zval_ptr_dtor(&zNewURL);
	*AllowRedirection = (int8_t)Z_BVAL_P(zAllowRedirection);
	zval_ptr_dtor(&zAllowRedirection);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK TSBHTTPCookieEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcCookieText, int32_t szCookieText)
{
	zval *retval_ptr;
	zval **params[2];
	zval * zSender;
	zval * zCookieText;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zCookieText);
	ZVAL_STRINGL(zCookieText, pcCookieText, szCookieText, 1);

	params[0] = &zSender;
	params[1] = &zCookieText;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 2, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zCookieText);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

#ifdef SB_WINDOWS
void SB_CALLBACK TSBHTTPOAuth2BrowseEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TStringListHandle ResponseHeaders)
#else
void SB_CALLBACK TSBHTTPOAuth2BrowseEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TElStringListHandle ResponseHeaders)
#endif
{
	zval *retval_ptr;
	zval **params[3];
	zval * zSender;
	zval * zURL;
	zval * zResponseHeaders;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zURL);
	ZVAL_STRINGL(zURL, pcURL, szURL, 1);
	MAKE_STD_ZVAL(zResponseHeaders);
#ifdef SB_WINDOWS
	SBInitObject(zResponseHeaders, TStringList_ce_ptr, ResponseHeaders TSRMLS_CC);
#else
	SBInitObject(zResponseHeaders, TElStringList_ce_ptr, ResponseHeaders TSRMLS_CC);
#endif

	params[0] = &zSender;
	params[1] = &zURL;
	params[2] = &zResponseHeaders;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zURL);
	zval_ptr_dtor(&zResponseHeaders);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK TSBHTTPUnsupportedTransferEncodingRaw(void * _ObjectData, TObjectHandle Sender, const char * pcEncoding, int32_t szEncoding, TElHTTPEncodingProcessorHandle * Processor, int8_t * Success)
{
	zval *retval_ptr;
	zval **params[4];
	zval * zSender;
	zval * zEncoding;
	zval * zProcessor;
	zval * zSuccess;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zEncoding);
	ZVAL_STRINGL(zEncoding, pcEncoding, szEncoding, 1);
	MAKE_STD_ZVAL(zProcessor);
	SBInitObject(zProcessor, TElHTTPEncodingProcessor_ce_ptr, *Processor TSRMLS_CC);
	MAKE_STD_ZVAL(zSuccess);
	ZVAL_BOOL(zSuccess, (zend_bool)*Success);

	params[0] = &zSender;
	params[1] = &zEncoding;
	params[2] = &zProcessor;
	params[3] = &zSuccess;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 4, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zEncoding);
	*Processor = SBGetObjectHandleCE(zProcessor, TElHTTPEncodingProcessor_ce_ptr TSRMLS_CC);
	SBDetachObjectHandleIfUniqueZVal(zProcessor TSRMLS_CC);
	zval_ptr_dtor(&zProcessor);
	*Success = (int8_t)Z_BVAL_P(zSuccess);
	zval_ptr_dtor(&zSuccess);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

zend_class_entry *TSBHTTPClientConnStage_ce_ptr = NULL;

zend_class_entry *TSBHTTPKeepAlivePolicy_ce_ptr = NULL;

void SB_CALLBACK TSecureClientMethodRaw(void * _ObjectData)
{
	zval *retval_ptr;
	TSRMLS_FETCH();

	SBCallEvent((zval *)_ObjectData, &retval_ptr, 0, NULL TSRMLS_CC);

	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK TSBHTTPBeforeWebSocketClientUsedEventRaw(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient, TElHTTPSClientHandle HTTPClient)
{
	zval *retval_ptr;
	zval **params[3];
	zval * zSender;
	zval * zWSClient;
	zval * zHTTPClient;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zWSClient);
	SBInitObject(zWSClient, TElWebSocketClient_ce_ptr, WSClient TSRMLS_CC);
	MAKE_STD_ZVAL(zHTTPClient);
	SBInitObject(zHTTPClient, TElHTTPSClient_ce_ptr, HTTPClient TSRMLS_CC);

	params[0] = &zSender;
	params[1] = &zWSClient;
	params[2] = &zHTTPClient;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zWSClient);
	zval_ptr_dtor(&zHTTPClient);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEventRaw(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient)
{
	zval *retval_ptr;
	zval **params[2];
	zval * zSender;
	zval * zWSClient;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zWSClient);
	SBInitObject(zWSClient, TElWebSocketClient_ce_ptr, WSClient TSRMLS_CC);

	params[0] = &zSender;
	params[1] = &zWSClient;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 2, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zWSClient);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

zend_class_entry *TElHTTPRequestParams_ce_ptr = NULL;

SB_PHP_METHOD(TElHTTPRequestParams, get_Cookie)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPRequestParams_get_Cookie(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1261829690, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPRequestParams, set_Cookie)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElHTTPRequestParams_set_Cookie(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPRequestParams, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPRequestParams_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPRequestParams_get_Cookie, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPRequestParams_set_Cookie, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPRequestParams___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElHTTPRequestParams_methods[] = {
	PHP_ME(TElHTTPRequestParams, get_Cookie, arginfo_TElHTTPRequestParams_get_Cookie, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPRequestParams, set_Cookie, arginfo_TElHTTPRequestParams_set_Cookie, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPRequestParams, __construct, arginfo_TElHTTPRequestParams___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElHTTPRequestParams(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElHTTPRequestParams_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElHTTPRequestParams", TElHTTPRequestParams_methods);
	if (NULL == TElHTTPCustomRequestParams_ce_ptr)
		Register_TElHTTPCustomRequestParams(TSRMLS_C);
	TElHTTPRequestParams_ce_ptr = zend_register_internal_class_ex(&ce, TElHTTPCustomRequestParams_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElHTTPSClient_ce_ptr = NULL;

SB_PHP_METHOD(TElHTTPSClient, StartWS)
{
	char *sURL;
	int sURL_len;
	TElClassHandle hoSocket = SB_NULL_HANDLE;
	TElClassHandle hoWSClient = SB_NULL_HANDLE;
	zval *oSocket;
	zval *oWSClient;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sOO", &sURL, &sURL_len, &oWSClient, TElWebSocketClient_ce_ptr, &oSocket, TElSocket_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oWSClient) && (IS_OBJECT == Z_TYPE_P(oWSClient)) && PZVAL_IS_REF(oSocket) && (IS_OBJECT == Z_TYPE_P(oSocket)))
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_StartWS(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &hoWSClient, &hoSocket, &l4OutResultRaw) TSRMLS_CC);
		SBUpdateObjectHandle(oWSClient, hoWSClient TSRMLS_CC);
		SBUpdateObjectHandle(oSocket, hoSocket TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string, &TElWebSocketClient, &TElSocket)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, CustomRequest)
{
	char *sMethod;
	char *sURL;
	int sMethod_len;
	int sURL_len;
	zend_bool bCloseStream;
	zval *oContent;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ss", &sURL, &sURL_len, &sMethod, &sMethod_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_CustomRequest(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, sMethod, (int32_t)sMethod_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ssO!b", &sURL, &sURL_len, &sMethod, &sMethod_len, &oContent, TStream_ce_ptr, &bCloseStream) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_CustomRequest_1(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, sMethod, (int32_t)sMethod_len, SBGetObjectHandle(oContent TSRMLS_CC), (int8_t)bCloseStream, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string, string) or (string, string, TStream, bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Get)
{
	char *sURL;
	int sURL_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Get(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Head)
{
	char *sURL;
	int sURL_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Head(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Options)
{
	char *sURL;
	int sURL_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Options(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Delete)
{
	char *sURL;
	int sURL_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Delete(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Trace)
{
	char *sURL;
	int sURL_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Trace(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Post)
{
	char *sContent;
	char *sURL;
	int sContent_len;
	int sURL_len;
	SBArrayZValInfo aiContent;
	zend_bool bCloseStream;
	zval *oContent;
	zval *zaContent;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Post(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ss", &sURL, &sURL_len, &sContent, &sContent_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Post_1(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, sContent, (int32_t)sContent_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sz", &sURL, &sURL_len, &zaContent) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaContent)) || (IS_ARRAY == Z_TYPE_P(zaContent)) || (IS_NULL == Z_TYPE_P(zaContent))))
	{
		int32_t l4OutResultRaw = 0;
		if (!SBGetByteArrayFromZVal(zaContent, &aiContent TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElHTTPSClient_Post_2(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, aiContent.data, aiContent.len, &l4OutResultRaw) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiContent);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!b", &sURL, &sURL_len, &oContent, TStream_ce_ptr, &bCloseStream) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Post_3(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, SBGetObjectHandle(oContent TSRMLS_CC), (int8_t)bCloseStream, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string) or (string, string) or (string, array of byte|string|NULL) or (string, TStream, bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, PostWebForm)
{
	char *sCharset;
	char *sContentType;
	char *sFileField;
	char *sFileName;
	char *sURL;
	int sCharset_len;
	int sContentType_len;
	int sFileField_len;
	int sFileName_len;
	int sURL_len;
	zend_bool bCloseStream;
	zval *oFields;
	zval *oFileStream;
#ifdef SB_WINDOWS
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!ssO!sb", &sURL, &sURL_len, &oFields, TStringList_ce_ptr, &sFileField, &sFileField_len, &sFileName, &sFileName_len, &oFileStream, TStream_ce_ptr, &sContentType, &sContentType_len, &bCloseStream) == SUCCESS)
#else
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!ssO!sb", &sURL, &sURL_len, &oFields, TElStringList_ce_ptr, &sFileField, &sFileField_len, &sFileName, &sFileName_len, &oFileStream, TStream_ce_ptr, &sContentType, &sContentType_len, &bCloseStream) == SUCCESS)
#endif
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_PostWebForm(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, SBGetObjectHandle(oFields TSRMLS_CC), sFileField, (int32_t)sFileField_len, sFileName, (int32_t)sFileName_len, SBGetObjectHandle(oFileStream TSRMLS_CC), sContentType, (int32_t)sContentType_len, (int8_t)bCloseStream, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
#ifdef SB_WINDOWS
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!ssO!sbs", &sURL, &sURL_len, &oFields, TStringList_ce_ptr, &sFileField, &sFileField_len, &sFileName, &sFileName_len, &oFileStream, TStream_ce_ptr, &sContentType, &sContentType_len, &bCloseStream, &sCharset, &sCharset_len) == SUCCESS)
#else
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!ssO!sbs", &sURL, &sURL_len, &oFields, TElStringList_ce_ptr, &sFileField, &sFileField_len, &sFileName, &sFileName_len, &oFileStream, TStream_ce_ptr, &sContentType, &sContentType_len, &bCloseStream, &sCharset, &sCharset_len) == SUCCESS)
#endif
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_PostWebForm_1(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, SBGetObjectHandle(oFields TSRMLS_CC), sFileField, (int32_t)sFileField_len, sFileName, (int32_t)sFileName_len, SBGetObjectHandle(oFileStream TSRMLS_CC), sContentType, (int32_t)sContentType_len, (int8_t)bCloseStream, sCharset, (int32_t)sCharset_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
#ifdef SB_WINDOWS
		SBErrorExpectsArguments("(string, TStringList, string, string, TStream, string, bool) or (string, TStringList, string, string, TStream, string, bool, string)" TSRMLS_CC);
#else
		SBErrorExpectsArguments("(string, TElStringList, string, string, TStream, string, bool) or (string, TElStringList, string, string, TStream, string, bool, string)" TSRMLS_CC);
#endif
	}
}

SB_PHP_METHOD(TElHTTPSClient, PostMultipart)
{
	char *sCharset;
	char *sRelatedStart;
	char *sRelatedStartInfo;
	char *sRelatedType;
	char *sURL;
	int sCharset_len;
	int sRelatedStart_len;
	int sRelatedStartInfo_len;
	int sRelatedType_len;
	int sURL_len;
	long fMultipartMode;
	zval *oPartsList;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "slO!", &sURL, &sURL_len, &fMultipartMode, &oPartsList, TElHTTPMultipartList_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_PostMultipart(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, (TSBHTTPMultipartModeRaw)fMultipartMode, SBGetObjectHandle(oPartsList TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "slsssO!", &sURL, &sURL_len, &fMultipartMode, &sRelatedStart, &sRelatedStart_len, &sRelatedStartInfo, &sRelatedStartInfo_len, &sRelatedType, &sRelatedType_len, &oPartsList, TElHTTPMultipartList_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_PostMultipart_1(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, (TSBHTTPMultipartModeRaw)fMultipartMode, sRelatedStart, (int32_t)sRelatedStart_len, sRelatedStartInfo, (int32_t)sRelatedStartInfo_len, sRelatedType, (int32_t)sRelatedType_len, SBGetObjectHandle(oPartsList TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "slsssO!s", &sURL, &sURL_len, &fMultipartMode, &sRelatedStart, &sRelatedStart_len, &sRelatedStartInfo, &sRelatedStartInfo_len, &sRelatedType, &sRelatedType_len, &oPartsList, TElHTTPMultipartList_ce_ptr, &sCharset, &sCharset_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_PostMultipart_2(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, (TSBHTTPMultipartModeRaw)fMultipartMode, sRelatedStart, (int32_t)sRelatedStart_len, sRelatedStartInfo, (int32_t)sRelatedStartInfo_len, sRelatedType, (int32_t)sRelatedType_len, SBGetObjectHandle(oPartsList TSRMLS_CC), sCharset, (int32_t)sCharset_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string, integer, TElHTTPMultipartList) or (string, integer, string, string, string, TElHTTPMultipartList) or (string, integer, string, string, string, TElHTTPMultipartList, string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, Put)
{
	char *sContent;
	char *sURL;
	int sContent_len;
	int sURL_len;
	long l4Count;
	long l4StartIndex;
	SBArrayZValInfo aiContent;
	zend_bool bCloseStream;
	zval *oContent;
	zval *zaContent;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sURL, &sURL_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Put(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ss", &sURL, &sURL_len, &sContent, &sContent_len) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Put_1(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, sContent, (int32_t)sContent_len, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sz", &sURL, &sURL_len, &zaContent) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaContent)) || (IS_ARRAY == Z_TYPE_P(zaContent)) || (IS_NULL == Z_TYPE_P(zaContent))))
	{
		int32_t l4OutResultRaw = 0;
		if (!SBGetByteArrayFromZVal(zaContent, &aiContent TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElHTTPSClient_Put_2(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, aiContent.data, aiContent.len, &l4OutResultRaw) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiContent);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "szll", &sURL, &sURL_len, &zaContent, &l4StartIndex, &l4Count) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaContent)) || (IS_ARRAY == Z_TYPE_P(zaContent)) || (IS_NULL == Z_TYPE_P(zaContent))))
	{
		int32_t l4OutResultRaw = 0;
		if (!SBGetByteArrayFromZVal(zaContent, &aiContent TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElHTTPSClient_Put_3(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, aiContent.data, aiContent.len, (int32_t)l4StartIndex, (int32_t)l4Count, &l4OutResultRaw) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiContent);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sO!b", &sURL, &sURL_len, &oContent, TStream_ce_ptr, &bCloseStream) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_Put_4(SBGetObjectHandle(getThis() TSRMLS_CC), sURL, (int32_t)sURL_len, SBGetObjectHandle(oContent TSRMLS_CC), (int8_t)bCloseStream, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string) or (string, string) or (string, array of byte|string|NULL) or (string, array of byte|string|NULL, integer, integer) or (string, TStream, bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, CancelRequest)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_CancelRequest(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, GetHeaderByName)
{
	char *sHeader;
	int sHeader_len;
	uint32_t _err;
	zval *oHeaders;
#ifdef SB_WINDOWS
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!s", &oHeaders, TStringList_ce_ptr, &sHeader, &sHeader_len) == SUCCESS)
#else
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!s", &oHeaders, TElStringList_ce_ptr, &sHeader, &sHeader_len) == SUCCESS)
#endif
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPSClient_GetHeaderByName(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oHeaders TSRMLS_CC), sHeader, (int32_t)sHeader_len, sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
#ifdef SB_WINDOWS
			SBCheckError(SBGetLastReturnStringA(1481289670, 3, sOutResult, &sOutResult_len) TSRMLS_CC);
#else
			SBCheckError(SBGetLastReturnStringA(-1643282953, 3, sOutResult, &sOutResult_len) TSRMLS_CC);
#endif
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
#ifdef SB_WINDOWS
		SBErrorExpectsArguments("(TStringList, string)" TSRMLS_CC);
#else
		SBErrorExpectsArguments("(TElStringList, string)" TSRMLS_CC);
#endif
	}
}

SB_PHP_METHOD(TElHTTPSClient, GetHeadersByName)
{
	char *sHeader;
	int sHeader_len;
	zval *oHeaders;
	zval *oRes;
#ifdef SB_WINDOWS
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!sO!", &oHeaders, TStringList_ce_ptr, &sHeader, &sHeader_len, &oRes, TStringList_ce_ptr) == SUCCESS)
#else
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!sO!", &oHeaders, TElStringList_ce_ptr, &sHeader, &sHeader_len, &oRes, TElStringList_ce_ptr) == SUCCESS)
#endif
	{
		SBCheckError(TElHTTPSClient_GetHeadersByName(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oHeaders TSRMLS_CC), sHeader, (int32_t)sHeader_len, SBGetObjectHandle(oRes TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
#ifdef SB_WINDOWS
		SBErrorExpectsArguments("(TStringList, string, TStringList)" TSRMLS_CC);
#else
		SBErrorExpectsArguments("(TElStringList, string, TElStringList)" TSRMLS_CC);
#endif
	}
}

SB_PHP_METHOD(TElHTTPSClient, SetHeaderByName)
{
	char *sHeader;
	char *sValue;
	int sHeader_len;
	int sValue_len;
	zval *oHeaders;
#ifdef SB_WINDOWS
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!ss", &oHeaders, TStringList_ce_ptr, &sHeader, &sHeader_len, &sValue, &sValue_len) == SUCCESS)
#else
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!ss", &oHeaders, TElStringList_ce_ptr, &sHeader, &sHeader_len, &sValue, &sValue_len) == SUCCESS)
#endif
	{
		SBCheckError(TElHTTPSClient_SetHeaderByName(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oHeaders TSRMLS_CC), sHeader, (int32_t)sHeader_len, sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
#ifdef SB_WINDOWS
		SBErrorExpectsArguments("(TStringList, string, string)" TSRMLS_CC);
#else
		SBErrorExpectsArguments("(TElStringList, string, string)" TSRMLS_CC);
#endif
	}
}

SB_PHP_METHOD(TElHTTPSClient, SetRequestHeader)
{
	char *sHeader;
	char *sValue;
	int sHeader_len;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ss", &sHeader, &sHeader_len, &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_SetRequestHeader(SBGetObjectHandle(getThis() TSRMLS_CC), sHeader, (int32_t)sHeader_len, sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string, string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, ClearRequest)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_ClearRequest(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, ClearResponse)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_ClearResponse(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, ClearAuthCache)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_ClearAuthCache(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_RequestHeaders)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_RequestHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
#ifdef SB_WINDOWS
		SBInitObject(return_value, TStringList_ce_ptr, hoOutResult TSRMLS_CC);
#else
		SBInitObject(return_value, TElStringList_ce_ptr, hoOutResult TSRMLS_CC);
#endif
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ResponseHeaders)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_ResponseHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
#ifdef SB_WINDOWS
		SBInitObject(return_value, TStringList_ce_ptr, hoOutResult TSRMLS_CC);
#else
		SBInitObject(return_value, TElStringList_ce_ptr, hoOutResult TSRMLS_CC);
#endif
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_RequestCookies)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_RequestCookies(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
#ifdef SB_WINDOWS
		SBInitObject(return_value, TStringList_ce_ptr, hoOutResult TSRMLS_CC);
#else
		SBInitObject(return_value, TElStringList_ce_ptr, hoOutResult TSRMLS_CC);
#endif
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ResponseCookies)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_ResponseCookies(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
#ifdef SB_WINDOWS
		SBInitObject(return_value, TStringList_ce_ptr, hoOutResult TSRMLS_CC);
#else
		SBInitObject(return_value, TElStringList_ce_ptr, hoOutResult TSRMLS_CC);
#endif
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ServerStatusCode)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_ServerStatusCode(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ServerReasonPhrase)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPSClient_get_ServerReasonPhrase(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(1928374283, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ContentLength)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int64_t l8OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_ContentLength(SBGetObjectHandle(getThis() TSRMLS_CC), &l8OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l8OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_Date)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int64_t dtOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_Date(SBGetObjectHandle(getThis() TSRMLS_CC), &dtOutResultRaw) TSRMLS_CC);
		object_init_ex(return_value, php_date_get_date_ce());
		SBSetDateTime(return_value, dtOutResultRaw TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OutputStream)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OutputStream(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TStream_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OutputStream)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TStream_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_OutputStream(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TStream)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_SSLEnabled)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_SSLEnabled(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_SSLEnabled)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_SSLEnabled(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_RequestParameters)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_RequestParameters(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElHTTPRequestParams_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_RequestParameters)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElHTTPRequestParams_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_RequestParameters(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElHTTPRequestParams)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_RequestCompressionLevel)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_RequestCompressionLevel(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_RequestCompressionLevel)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_RequestCompressionLevel(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_RequestCompressionGZip)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_RequestCompressionGZip(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_RequestCompressionGZip)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_RequestCompressionGZip(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_KeepAlivePolicy)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPKeepAlivePolicyRaw fOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_KeepAlivePolicy(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_KeepAlivePolicy)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_KeepAlivePolicy(SBGetObjectHandle(getThis() TSRMLS_CC), (TSBHTTPKeepAlivePolicyRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_MaxRedirections)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_MaxRedirections(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_MaxRedirections)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_MaxRedirections(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_SuppressRedirectionContent)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_SuppressRedirectionContent(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_SuppressRedirectionContent)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_SuppressRedirectionContent(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPVersion)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPVersionRaw fOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_HTTPVersion(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPVersion)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPVersion(SBGetObjectHandle(getThis() TSRMLS_CC), (TSBHTTPVersionRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_UseNTLMAuth)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_UseNTLMAuth(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_UseNTLMAuth)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_UseNTLMAuth(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_UseDigestAuth)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_UseDigestAuth(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_UseDigestAuth)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_UseDigestAuth(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_PersistentAuthHeader)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_PersistentAuthHeader(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_PersistentAuthHeader)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_PersistentAuthHeader(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_ForceNTLMAuth)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_ForceNTLMAuth(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_ForceNTLMAuth)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_ForceNTLMAuth(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_SendBufferSize)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_SendBufferSize(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_SendBufferSize)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_SendBufferSize(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_UseCompression)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_UseCompression(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_UseCompression)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_UseCompression(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

#ifdef SB_WINDOWS
SB_PHP_METHOD(TElHTTPSClient, get_UseIPv6)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_UseIPv6(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_UseIPv6)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_UseIPv6(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}
#endif

SB_PHP_METHOD(TElHTTPSClient, get_CookieManager)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_CookieManager(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElCookieManager_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_CookieManager)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElCookieManager_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_CookieManager(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElCookieManager)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_Use100Continue)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_Use100Continue(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_Use100Continue)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_Use100Continue(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OAuth2)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OAuth2(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElOAuth2Settings_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OAuth2)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElOAuth2Settings_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_OAuth2(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElOAuth2Settings)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_SAMLAdapter)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_SAMLAdapter(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElCustomSAMLAdapter_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_SAMLAdapter)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElCustomSAMLAdapter_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_SAMLAdapter(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElCustomSAMLAdapter)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyUsername)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPSClient_get_HTTPProxyUsername(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-2066344506, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPProxyUsername)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPProxyUsername(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyPassword)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPSClient_get_HTTPProxyPassword(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(1229608292, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPProxyPassword)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPProxyPassword(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyHost)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElHTTPSClient_get_HTTPProxyHost(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-534601838, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPProxyHost)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPProxyHost(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyPort)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_HTTPProxyPort(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPProxyPort)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPProxyPort(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyRequestHeaders)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_HTTPProxyRequestHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
#ifdef SB_WINDOWS
		SBInitObject(return_value, TStringList_ce_ptr, hoOutResult TSRMLS_CC);
#else
		SBInitObject(return_value, TElStringList_ce_ptr, hoOutResult TSRMLS_CC);
#endif
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_HTTPProxyAuthentication)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElWebTunnelAuthenticationRaw fOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_HTTPProxyAuthentication(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_HTTPProxyAuthentication)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_HTTPProxyAuthentication(SBGetObjectHandle(getThis() TSRMLS_CC), (TElWebTunnelAuthenticationRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_UseHTTPProxy)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_UseHTTPProxy(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_UseHTTPProxy)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_UseHTTPProxy(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_IgnoreUnknownTransferEncodings)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElHTTPSClient_get_IgnoreUnknownTransferEncodings(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_IgnoreUnknownTransferEncodings)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElHTTPSClient_set_IgnoreUnknownTransferEncodings(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnBeforeWebSocketClientUsed)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPBeforeWebSocketClientUsedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnBeforeWebSocketClientUsed(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnBeforeWebSocketClientUsed)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnBeforeWebSocketClientUsed(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPBeforeWebSocketClientUsedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPBeforeWebSocketClientUsedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnWebSocketConnectionEstablished)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnWebSocketConnectionEstablished(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnWebSocketConnectionEstablished)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnWebSocketConnectionEstablished(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPWebSocketConnectionEstablishedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCookie)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPCookieEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCookie(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCookie)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCookie(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPCookieEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPCookieEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnData)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBDataEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnData(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnData)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnData(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBDataEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBDataEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnDocumentBegin)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TNotifyEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnDocumentBegin(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnDocumentBegin)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnDocumentBegin(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TNotifyEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TNotifyEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnDocumentEnd)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TNotifyEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnDocumentEnd(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnDocumentEnd)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnDocumentEnd(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TNotifyEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TNotifyEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnReceivingHeaders)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPHeadersEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnReceivingHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnReceivingHeaders)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnReceivingHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPHeadersEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPHeadersEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnPreparedHeaders)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPHeadersEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnPreparedHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnPreparedHeaders)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnPreparedHeaders(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPHeadersEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPHeadersEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnProgress)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBProgressEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnProgress(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnProgress)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnProgress(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBProgressEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBProgressEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnRedirection)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPRedirectionEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnRedirection(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnRedirection)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnRedirection(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPRedirectionEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPRedirectionEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnSendData)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBDataEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnSendData(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnSendData)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnSendData(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBDataEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBDataEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnDynamicDataNeeded)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPDynamicDataNeededEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnDynamicDataNeeded(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnDynamicDataNeeded)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnDynamicDataNeeded(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPDynamicDataNeededEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPDynamicDataNeededEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnOAuth2Browse)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPOAuth2BrowseEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnOAuth2Browse(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnOAuth2Browse)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnOAuth2Browse(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPOAuth2BrowseEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPOAuth2BrowseEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnUnsupportedTransferEncoding)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBHTTPUnsupportedTransferEncoding pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnUnsupportedTransferEncoding(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnUnsupportedTransferEncoding)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnUnsupportedTransferEncoding(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBHTTPUnsupportedTransferEncodingRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBHTTPUnsupportedTransferEncoding|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCertificateChoose)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBChooseCertificateEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCertificateChoose(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCertificateChoose)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCertificateChoose(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBChooseCertificateEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBChooseCertificateEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCertificateNeededEx)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBCertificateNeededExEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCertificateNeededEx(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCertificateNeededEx)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCertificateNeededEx(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBCertificateNeededExEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBCertificateNeededExEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCertificateValidate)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBCertificateValidateEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCertificateValidate(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCertificateValidate)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCertificateValidate(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBCertificateValidateEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBCertificateValidateEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCiphersNegotiated)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TNotifyEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCiphersNegotiated(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCiphersNegotiated)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCiphersNegotiated(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TNotifyEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TNotifyEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCloseConnection)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBCloseConnectionEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCloseConnection(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCloseConnection)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCloseConnection(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBCloseConnectionEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBCloseConnectionEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnError)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBErrorEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnError(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnError)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnError(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBErrorEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBErrorEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnExtensionsReceived)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBExtensionsReceivedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnExtensionsReceived(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnExtensionsReceived)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnExtensionsReceived(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBExtensionsReceivedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBExtensionsReceivedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnExtensionsPrepared)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBExtensionsPreparedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnExtensionsPrepared(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnExtensionsPrepared)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnExtensionsPrepared(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBExtensionsPreparedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBExtensionsPreparedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnCertificateStatus)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBCertificateStatusEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnCertificateStatus(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnCertificateStatus)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnCertificateStatus(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBCertificateStatusEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBCertificateStatusEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnKeyNeeded)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBClientKeyNeededEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnKeyNeeded(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnKeyNeeded)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnKeyNeeded(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBClientKeyNeededEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBClientKeyNeededEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, get_OnRenegotiationRequest)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBRenegotiationRequestEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElHTTPSClient_get_OnRenegotiationRequest(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, set_OnRenegotiationRequest)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElHTTPSClient_set_OnRenegotiationRequest(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBRenegotiationRequestEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBRenegotiationRequestEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElHTTPSClient, __construct)
{
	zval *oAOwner;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oAOwner, TComponent_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElHTTPSClient_Create(SBGetObjectHandle(oAOwner TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TComponent)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_StartWS, 0, 0, 3)
	ZEND_ARG_INFO(0, URL)
	ZEND_ARG_OBJ_INFO(1, WSClient, TElWebSocketClient, 0)
	ZEND_ARG_OBJ_INFO(1, Socket, TElSocket, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_CustomRequest, 0, 0, 2)
	ZEND_ARG_INFO(0, URL)
	ZEND_ARG_INFO(0, Method)
	ZEND_ARG_OBJ_INFO(0, Content, TStream, 1)
	ZEND_ARG_INFO(0, CloseStream)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Get, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Head, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Options, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Delete, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Trace, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Post, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
	ZEND_ARG_TYPE_INFO(0, Content, 0, 1)
	ZEND_ARG_INFO(0, CloseStream)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_PostWebForm, 0, 0, 7)
	ZEND_ARG_INFO(0, URL)
#ifdef SB_WINDOWS
	ZEND_ARG_OBJ_INFO(0, Fields, TStringList, 1)
#else
	ZEND_ARG_OBJ_INFO(0, Fields, TElStringList, 1)
#endif
	ZEND_ARG_INFO(0, FileField)
	ZEND_ARG_INFO(0, FileName)
	ZEND_ARG_OBJ_INFO(0, FileStream, TStream, 1)
	ZEND_ARG_INFO(0, ContentType)
	ZEND_ARG_INFO(0, CloseStream)
	ZEND_ARG_INFO(0, Charset)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_PostMultipart, 0, 0, 3)
	ZEND_ARG_INFO(0, URL)
	ZEND_ARG_INFO(0, MultipartMode)
	ZEND_ARG_TYPE_INFO(0, PartsList_or_RelatedStart, 0, 1)
	ZEND_ARG_INFO(0, RelatedStartInfo)
	ZEND_ARG_INFO(0, RelatedType)
	ZEND_ARG_OBJ_INFO(0, PartsList, TElHTTPMultipartList, 1)
	ZEND_ARG_INFO(0, Charset)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_Put, 0, 0, 1)
	ZEND_ARG_INFO(0, URL)
	ZEND_ARG_TYPE_INFO(0, Content, 0, 1)
	ZEND_ARG_INFO(0, StartIndex_or_CloseStream)
	ZEND_ARG_INFO(0, Count)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_CancelRequest, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_GetHeaderByName, 0, 0, 2)
#ifdef SB_WINDOWS
	ZEND_ARG_OBJ_INFO(0, Headers, TStringList, 1)
#else
	ZEND_ARG_OBJ_INFO(0, Headers, TElStringList, 1)
#endif
	ZEND_ARG_INFO(0, Header)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_GetHeadersByName, 0, 0, 3)
#ifdef SB_WINDOWS
	ZEND_ARG_OBJ_INFO(0, Headers, TStringList, 1)
#else
	ZEND_ARG_OBJ_INFO(0, Headers, TElStringList, 1)
#endif
	ZEND_ARG_INFO(0, Header)
#ifdef SB_WINDOWS
	ZEND_ARG_OBJ_INFO(0, Res, TStringList, 1)
#else
	ZEND_ARG_OBJ_INFO(0, Res, TElStringList, 1)
#endif
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_SetHeaderByName, 0, 0, 3)
#ifdef SB_WINDOWS
	ZEND_ARG_OBJ_INFO(0, Headers, TStringList, 1)
#else
	ZEND_ARG_OBJ_INFO(0, Headers, TElStringList, 1)
#endif
	ZEND_ARG_INFO(0, Header)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_SetRequestHeader, 0, 0, 2)
	ZEND_ARG_INFO(0, Header)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_ClearRequest, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_ClearResponse, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_ClearAuthCache, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_RequestHeaders, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ResponseHeaders, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_RequestCookies, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ResponseCookies, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ServerStatusCode, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ServerReasonPhrase, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ContentLength, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_Date, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OutputStream, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OutputStream, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TStream, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_SSLEnabled, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_SSLEnabled, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_RequestParameters, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_RequestParameters, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElHTTPRequestParams, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_RequestCompressionLevel, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_RequestCompressionLevel, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_RequestCompressionGZip, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_RequestCompressionGZip, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_KeepAlivePolicy, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_KeepAlivePolicy, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_MaxRedirections, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_MaxRedirections, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_SuppressRedirectionContent, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_SuppressRedirectionContent, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPVersion, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPVersion, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_UseNTLMAuth, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_UseNTLMAuth, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_UseDigestAuth, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_UseDigestAuth, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_PersistentAuthHeader, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_PersistentAuthHeader, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_ForceNTLMAuth, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_ForceNTLMAuth, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_SendBufferSize, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_SendBufferSize, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_UseCompression, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_UseCompression, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

#ifdef SB_WINDOWS
ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_UseIPv6, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_UseIPv6, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()
#endif

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_CookieManager, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_CookieManager, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElCookieManager, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_Use100Continue, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_Use100Continue, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OAuth2, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OAuth2, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElOAuth2Settings, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_SAMLAdapter, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_SAMLAdapter, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElCustomSAMLAdapter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyUsername, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPProxyUsername, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyPassword, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPProxyPassword, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyHost, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPProxyHost, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyPort, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPProxyPort, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyRequestHeaders, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_HTTPProxyAuthentication, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_HTTPProxyAuthentication, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_UseHTTPProxy, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_UseHTTPProxy, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_IgnoreUnknownTransferEncodings, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_IgnoreUnknownTransferEncodings, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnBeforeWebSocketClientUsed, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnBeforeWebSocketClientUsed, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnWebSocketConnectionEstablished, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnWebSocketConnectionEstablished, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCookie, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCookie, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnData, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnData, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnDocumentBegin, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnDocumentBegin, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnDocumentEnd, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnDocumentEnd, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnReceivingHeaders, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnReceivingHeaders, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnPreparedHeaders, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnPreparedHeaders, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnProgress, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnProgress, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnRedirection, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnRedirection, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnSendData, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnSendData, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnDynamicDataNeeded, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnDynamicDataNeeded, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnOAuth2Browse, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnOAuth2Browse, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnUnsupportedTransferEncoding, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnUnsupportedTransferEncoding, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCertificateChoose, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCertificateChoose, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCertificateNeededEx, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCertificateNeededEx, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCertificateValidate, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCertificateValidate, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCiphersNegotiated, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCiphersNegotiated, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCloseConnection, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCloseConnection, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnError, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnError, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnExtensionsReceived, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnExtensionsReceived, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnExtensionsPrepared, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnExtensionsPrepared, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnCertificateStatus, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnCertificateStatus, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnKeyNeeded, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnKeyNeeded, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_get_OnRenegotiationRequest, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient_set_OnRenegotiationRequest, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElHTTPSClient___construct, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, AOwner, TComponent, 1)
ZEND_END_ARG_INFO()

static zend_function_entry TElHTTPSClient_methods[] = {
	PHP_ME(TElHTTPSClient, StartWS, arginfo_TElHTTPSClient_StartWS, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, CustomRequest, arginfo_TElHTTPSClient_CustomRequest, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Get, arginfo_TElHTTPSClient_Get, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Head, arginfo_TElHTTPSClient_Head, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Options, arginfo_TElHTTPSClient_Options, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Delete, arginfo_TElHTTPSClient_Delete, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Trace, arginfo_TElHTTPSClient_Trace, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Post, arginfo_TElHTTPSClient_Post, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, PostWebForm, arginfo_TElHTTPSClient_PostWebForm, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, PostMultipart, arginfo_TElHTTPSClient_PostMultipart, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, Put, arginfo_TElHTTPSClient_Put, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, CancelRequest, arginfo_TElHTTPSClient_CancelRequest, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, GetHeaderByName, arginfo_TElHTTPSClient_GetHeaderByName, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, GetHeadersByName, arginfo_TElHTTPSClient_GetHeadersByName, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, SetHeaderByName, arginfo_TElHTTPSClient_SetHeaderByName, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, SetRequestHeader, arginfo_TElHTTPSClient_SetRequestHeader, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, ClearRequest, arginfo_TElHTTPSClient_ClearRequest, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, ClearResponse, arginfo_TElHTTPSClient_ClearResponse, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, ClearAuthCache, arginfo_TElHTTPSClient_ClearAuthCache, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_RequestHeaders, arginfo_TElHTTPSClient_get_RequestHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ResponseHeaders, arginfo_TElHTTPSClient_get_ResponseHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_RequestCookies, arginfo_TElHTTPSClient_get_RequestCookies, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ResponseCookies, arginfo_TElHTTPSClient_get_ResponseCookies, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ServerStatusCode, arginfo_TElHTTPSClient_get_ServerStatusCode, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ServerReasonPhrase, arginfo_TElHTTPSClient_get_ServerReasonPhrase, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ContentLength, arginfo_TElHTTPSClient_get_ContentLength, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_Date, arginfo_TElHTTPSClient_get_Date, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OutputStream, arginfo_TElHTTPSClient_get_OutputStream, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OutputStream, arginfo_TElHTTPSClient_set_OutputStream, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_SSLEnabled, arginfo_TElHTTPSClient_get_SSLEnabled, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_SSLEnabled, arginfo_TElHTTPSClient_set_SSLEnabled, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_RequestParameters, arginfo_TElHTTPSClient_get_RequestParameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_RequestParameters, arginfo_TElHTTPSClient_set_RequestParameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_RequestCompressionLevel, arginfo_TElHTTPSClient_get_RequestCompressionLevel, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_RequestCompressionLevel, arginfo_TElHTTPSClient_set_RequestCompressionLevel, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_RequestCompressionGZip, arginfo_TElHTTPSClient_get_RequestCompressionGZip, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_RequestCompressionGZip, arginfo_TElHTTPSClient_set_RequestCompressionGZip, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_KeepAlivePolicy, arginfo_TElHTTPSClient_get_KeepAlivePolicy, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_KeepAlivePolicy, arginfo_TElHTTPSClient_set_KeepAlivePolicy, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_MaxRedirections, arginfo_TElHTTPSClient_get_MaxRedirections, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_MaxRedirections, arginfo_TElHTTPSClient_set_MaxRedirections, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_SuppressRedirectionContent, arginfo_TElHTTPSClient_get_SuppressRedirectionContent, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_SuppressRedirectionContent, arginfo_TElHTTPSClient_set_SuppressRedirectionContent, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPVersion, arginfo_TElHTTPSClient_get_HTTPVersion, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPVersion, arginfo_TElHTTPSClient_set_HTTPVersion, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_UseNTLMAuth, arginfo_TElHTTPSClient_get_UseNTLMAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_UseNTLMAuth, arginfo_TElHTTPSClient_set_UseNTLMAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_UseDigestAuth, arginfo_TElHTTPSClient_get_UseDigestAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_UseDigestAuth, arginfo_TElHTTPSClient_set_UseDigestAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_PersistentAuthHeader, arginfo_TElHTTPSClient_get_PersistentAuthHeader, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_PersistentAuthHeader, arginfo_TElHTTPSClient_set_PersistentAuthHeader, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_ForceNTLMAuth, arginfo_TElHTTPSClient_get_ForceNTLMAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_ForceNTLMAuth, arginfo_TElHTTPSClient_set_ForceNTLMAuth, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_SendBufferSize, arginfo_TElHTTPSClient_get_SendBufferSize, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_SendBufferSize, arginfo_TElHTTPSClient_set_SendBufferSize, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_UseCompression, arginfo_TElHTTPSClient_get_UseCompression, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_UseCompression, arginfo_TElHTTPSClient_set_UseCompression, ZEND_ACC_PUBLIC)
#ifdef SB_WINDOWS
	PHP_ME(TElHTTPSClient, get_UseIPv6, arginfo_TElHTTPSClient_get_UseIPv6, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_UseIPv6, arginfo_TElHTTPSClient_set_UseIPv6, ZEND_ACC_PUBLIC)
#endif
	PHP_ME(TElHTTPSClient, get_CookieManager, arginfo_TElHTTPSClient_get_CookieManager, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_CookieManager, arginfo_TElHTTPSClient_set_CookieManager, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_Use100Continue, arginfo_TElHTTPSClient_get_Use100Continue, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_Use100Continue, arginfo_TElHTTPSClient_set_Use100Continue, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OAuth2, arginfo_TElHTTPSClient_get_OAuth2, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OAuth2, arginfo_TElHTTPSClient_set_OAuth2, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_SAMLAdapter, arginfo_TElHTTPSClient_get_SAMLAdapter, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_SAMLAdapter, arginfo_TElHTTPSClient_set_SAMLAdapter, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyUsername, arginfo_TElHTTPSClient_get_HTTPProxyUsername, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPProxyUsername, arginfo_TElHTTPSClient_set_HTTPProxyUsername, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyPassword, arginfo_TElHTTPSClient_get_HTTPProxyPassword, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPProxyPassword, arginfo_TElHTTPSClient_set_HTTPProxyPassword, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyHost, arginfo_TElHTTPSClient_get_HTTPProxyHost, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPProxyHost, arginfo_TElHTTPSClient_set_HTTPProxyHost, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyPort, arginfo_TElHTTPSClient_get_HTTPProxyPort, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPProxyPort, arginfo_TElHTTPSClient_set_HTTPProxyPort, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyRequestHeaders, arginfo_TElHTTPSClient_get_HTTPProxyRequestHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_HTTPProxyAuthentication, arginfo_TElHTTPSClient_get_HTTPProxyAuthentication, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_HTTPProxyAuthentication, arginfo_TElHTTPSClient_set_HTTPProxyAuthentication, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_UseHTTPProxy, arginfo_TElHTTPSClient_get_UseHTTPProxy, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_UseHTTPProxy, arginfo_TElHTTPSClient_set_UseHTTPProxy, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_IgnoreUnknownTransferEncodings, arginfo_TElHTTPSClient_get_IgnoreUnknownTransferEncodings, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_IgnoreUnknownTransferEncodings, arginfo_TElHTTPSClient_set_IgnoreUnknownTransferEncodings, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnBeforeWebSocketClientUsed, arginfo_TElHTTPSClient_get_OnBeforeWebSocketClientUsed, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnBeforeWebSocketClientUsed, arginfo_TElHTTPSClient_set_OnBeforeWebSocketClientUsed, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnWebSocketConnectionEstablished, arginfo_TElHTTPSClient_get_OnWebSocketConnectionEstablished, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnWebSocketConnectionEstablished, arginfo_TElHTTPSClient_set_OnWebSocketConnectionEstablished, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCookie, arginfo_TElHTTPSClient_get_OnCookie, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCookie, arginfo_TElHTTPSClient_set_OnCookie, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnData, arginfo_TElHTTPSClient_get_OnData, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnData, arginfo_TElHTTPSClient_set_OnData, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnDocumentBegin, arginfo_TElHTTPSClient_get_OnDocumentBegin, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnDocumentBegin, arginfo_TElHTTPSClient_set_OnDocumentBegin, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnDocumentEnd, arginfo_TElHTTPSClient_get_OnDocumentEnd, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnDocumentEnd, arginfo_TElHTTPSClient_set_OnDocumentEnd, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnReceivingHeaders, arginfo_TElHTTPSClient_get_OnReceivingHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnReceivingHeaders, arginfo_TElHTTPSClient_set_OnReceivingHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnPreparedHeaders, arginfo_TElHTTPSClient_get_OnPreparedHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnPreparedHeaders, arginfo_TElHTTPSClient_set_OnPreparedHeaders, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnProgress, arginfo_TElHTTPSClient_get_OnProgress, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnProgress, arginfo_TElHTTPSClient_set_OnProgress, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnRedirection, arginfo_TElHTTPSClient_get_OnRedirection, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnRedirection, arginfo_TElHTTPSClient_set_OnRedirection, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnSendData, arginfo_TElHTTPSClient_get_OnSendData, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnSendData, arginfo_TElHTTPSClient_set_OnSendData, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnDynamicDataNeeded, arginfo_TElHTTPSClient_get_OnDynamicDataNeeded, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnDynamicDataNeeded, arginfo_TElHTTPSClient_set_OnDynamicDataNeeded, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnOAuth2Browse, arginfo_TElHTTPSClient_get_OnOAuth2Browse, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnOAuth2Browse, arginfo_TElHTTPSClient_set_OnOAuth2Browse, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnUnsupportedTransferEncoding, arginfo_TElHTTPSClient_get_OnUnsupportedTransferEncoding, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnUnsupportedTransferEncoding, arginfo_TElHTTPSClient_set_OnUnsupportedTransferEncoding, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCertificateChoose, arginfo_TElHTTPSClient_get_OnCertificateChoose, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCertificateChoose, arginfo_TElHTTPSClient_set_OnCertificateChoose, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCertificateNeededEx, arginfo_TElHTTPSClient_get_OnCertificateNeededEx, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCertificateNeededEx, arginfo_TElHTTPSClient_set_OnCertificateNeededEx, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCertificateValidate, arginfo_TElHTTPSClient_get_OnCertificateValidate, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCertificateValidate, arginfo_TElHTTPSClient_set_OnCertificateValidate, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCiphersNegotiated, arginfo_TElHTTPSClient_get_OnCiphersNegotiated, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCiphersNegotiated, arginfo_TElHTTPSClient_set_OnCiphersNegotiated, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCloseConnection, arginfo_TElHTTPSClient_get_OnCloseConnection, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCloseConnection, arginfo_TElHTTPSClient_set_OnCloseConnection, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnError, arginfo_TElHTTPSClient_get_OnError, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnError, arginfo_TElHTTPSClient_set_OnError, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnExtensionsReceived, arginfo_TElHTTPSClient_get_OnExtensionsReceived, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnExtensionsReceived, arginfo_TElHTTPSClient_set_OnExtensionsReceived, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnExtensionsPrepared, arginfo_TElHTTPSClient_get_OnExtensionsPrepared, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnExtensionsPrepared, arginfo_TElHTTPSClient_set_OnExtensionsPrepared, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnCertificateStatus, arginfo_TElHTTPSClient_get_OnCertificateStatus, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnCertificateStatus, arginfo_TElHTTPSClient_set_OnCertificateStatus, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnKeyNeeded, arginfo_TElHTTPSClient_get_OnKeyNeeded, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnKeyNeeded, arginfo_TElHTTPSClient_set_OnKeyNeeded, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, get_OnRenegotiationRequest, arginfo_TElHTTPSClient_get_OnRenegotiationRequest, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, set_OnRenegotiationRequest, arginfo_TElHTTPSClient_set_OnRenegotiationRequest, ZEND_ACC_PUBLIC)
	PHP_ME(TElHTTPSClient, __construct, arginfo_TElHTTPSClient___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElHTTPSClient(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElHTTPSClient_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElHTTPSClient", TElHTTPSClient_methods);
	if (NULL == TElCustomSimpleSSLClient_ce_ptr)
		Register_TElCustomSimpleSSLClient(TSRMLS_C);
	TElHTTPSClient_ce_ptr = zend_register_internal_class_ex(&ce, TElCustomSimpleSSLClient_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *SBHTTPSClient_TElStringValue_ce_ptr = NULL;

SB_PHP_METHOD(SBHTTPSClient_TElStringValue, get_Value)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = SBHTTPSClient_TElStringValue_get_Value(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(1883466558, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(SBHTTPSClient_TElStringValue, set_Value)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(SBHTTPSClient_TElStringValue_set_Value(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(SBHTTPSClient_TElStringValue, __construct)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(SBHTTPSClient_TElStringValue_Create(sValue, (int32_t)sValue_len, &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_SBHTTPSClient_TElStringValue_get_Value, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_SBHTTPSClient_TElStringValue_set_Value, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_SBHTTPSClient_TElStringValue___construct, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

static zend_function_entry SBHTTPSClient_TElStringValue_methods[] = {
	PHP_ME(SBHTTPSClient_TElStringValue, get_Value, arginfo_SBHTTPSClient_TElStringValue_get_Value, ZEND_ACC_PUBLIC)
	PHP_ME(SBHTTPSClient_TElStringValue, set_Value, arginfo_SBHTTPSClient_TElStringValue_set_Value, ZEND_ACC_PUBLIC)
	PHP_ME(SBHTTPSClient_TElStringValue, __construct, arginfo_SBHTTPSClient_TElStringValue___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_SBHTTPSClient_TElStringValue(TSRMLS_D)
{
	zend_class_entry ce;
	if (SBHTTPSClient_TElStringValue_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "SBHTTPSClient_TElStringValue", SBHTTPSClient_TElStringValue_methods);
	if (NULL == TObject_ce_ptr)
		Register_TObject(TSRMLS_C);
	SBHTTPSClient_TElStringValue_ce_ptr = zend_register_internal_class_ex(&ce, TObject_ce_ptr, NULL TSRMLS_CC);
}

void Register_SBHTTPSClient_Constants(int module_number TSRMLS_DC)
{
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SCannotSend, SB_SCannotSend, SB_SCannotSend);
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SSocketError, SB_SSocketError, SB_SSocketError);
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SDNSError, SB_SDNSError, SB_SDNSError);
#ifdef SB_WINDOWS
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SInvalidNTLMResponse, SB_SInvalidNTLMResponse, SB_SInvalidNTLMResponse);
#endif
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SInvalidDigestResponse, SB_SInvalidDigestResponse, SB_SInvalidDigestResponse);
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SInvalidDate, SB_SInvalidDate, SB_SInvalidDate);
	SB_REGISTER_STRING_CONSTANT(SBHTTPSClient, SConnectionLost, SB_SConnectionLost, SB_SConnectionLost);
	SB_REGISTER_LONG_CONSTANT(SBHTTPSClient, SB_WEBSOCKET_SUCCESS, SB_WEBSOCKET_SUCCESS, SB_WEBSOCKET_SUCCESS);
}

void Register_SBHTTPSClient_Enum_Flags(TSRMLS_D)
{
	zend_class_entry ce;
	INIT_CLASS_ENTRY(ce, "TSBHTTPClientConnStage", NULL);
	TSBHTTPClientConnStage_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseEnum_ce_ptr, NULL TSRMLS_CC);
	TSBHTTPClientConnStage_ce_ptr->ce_flags |= ZEND_ACC_FINAL_CLASS;
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPClientConnStage_ce_ptr, "csHandshake", 0)
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPClientConnStage_ce_ptr, "csRequest", 1)
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPClientConnStage_ce_ptr, "csResponse", 2)
	
	INIT_CLASS_ENTRY(ce, "TSBHTTPKeepAlivePolicy", NULL);
	TSBHTTPKeepAlivePolicy_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseEnum_ce_ptr, NULL TSRMLS_CC);
	TSBHTTPKeepAlivePolicy_ce_ptr->ce_flags |= ZEND_ACC_FINAL_CLASS;
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPKeepAlivePolicy_ce_ptr, "kapStandardDefined", 0)
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPKeepAlivePolicy_ce_ptr, "kapPreferKeepAlive", 1)
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPKeepAlivePolicy_ce_ptr, "kapRelyOnServer", 2)
	SB_DECLARE_CLASS_LONG_CONST(TSBHTTPKeepAlivePolicy_ce_ptr, "kapKeepAlivesDisabled", 3)
}

void Register_SBHTTPSClient_Aliases(TSRMLS_D)
{
	if (NULL == TElHTTPRequestParams_ce_ptr)
		Register_TElHTTPRequestParams(TSRMLS_C);
	zend_register_class_alias("ElHTTPRequestParams", TElHTTPRequestParams_ce_ptr);
	if (NULL == TElHTTPSClient_ce_ptr)
		Register_TElHTTPSClient(TSRMLS_C);
	zend_register_class_alias("ElHTTPSClient", TElHTTPSClient_ce_ptr);
}
