#include "sbrc2.h"

SB_PHP_METHOD(TRC2ExpandedKey, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TRC2ExpandedKey));
		intern->len = sizeof(TRC2ExpandedKey);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TRC2ExpandedKey, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TRC2ExpandedKey));
}

zend_class_entry *TRC2ExpandedKey_ce_ptr = NULL;

static zend_function_entry TRC2ExpandedKey_methods[] = {
	PHP_ME(TRC2ExpandedKey, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TRC2ExpandedKey, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_FE_END
};

void Register_TRC2ExpandedKey(TSRMLS_D)
{
	zend_class_entry ce;
	if (TRC2ExpandedKey_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TRC2ExpandedKey", TRC2ExpandedKey_methods);
	TRC2ExpandedKey_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

SB_PHP_FUNCTION(SBRC2, ExpandKey)
{
	SBArrayZValInfo aiKey;
	zval *oExpandedKey;
	zval *zaKey;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zO", &zaKey, &oExpandedKey, TRC2ExpandedKey_ce_ptr) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && PZVAL_IS_REF(oExpandedKey))
	{
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBRC2_ExpandKey(aiKey.data, aiKey.len, (TRC2ExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiKey);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, &TRC2ExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBRC2, Encrypt)
{
	uint32_t u4B0Raw;
	uint32_t u4B1Raw;
	zval *oExpandedKey;
	zval *zu4B0;
	zval *zu4B1;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzO", &zu4B0, &zu4B1, &oExpandedKey, TRC2ExpandedKey_ce_ptr) == SUCCESS) && PZVAL_IS_REF(zu4B0) && (IS_LONG == Z_TYPE_P(zu4B0)) && PZVAL_IS_REF(zu4B1) && (IS_LONG == Z_TYPE_P(zu4B1)))
	{
		u4B0Raw = (uint32_t)Z_LVAL_P(zu4B0);
		u4B1Raw = (uint32_t)Z_LVAL_P(zu4B1);
		SBCheckError(SBRC2_Encrypt(&u4B0Raw, &u4B1Raw, (TRC2ExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		ZVAL_LONG(zu4B0, (long)u4B0Raw);
		ZVAL_LONG(zu4B1, (long)u4B1Raw);
	}
	else
	{
		SBErrorExpectsArguments("(&integer, &integer, TRC2ExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBRC2, Decrypt)
{
	uint32_t u4B0Raw;
	uint32_t u4B1Raw;
	zval *oExpandedKey;
	zval *zu4B0;
	zval *zu4B1;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzO", &zu4B0, &zu4B1, &oExpandedKey, TRC2ExpandedKey_ce_ptr) == SUCCESS) && PZVAL_IS_REF(zu4B0) && (IS_LONG == Z_TYPE_P(zu4B0)) && PZVAL_IS_REF(zu4B1) && (IS_LONG == Z_TYPE_P(zu4B1)))
	{
		u4B0Raw = (uint32_t)Z_LVAL_P(zu4B0);
		u4B1Raw = (uint32_t)Z_LVAL_P(zu4B1);
		SBCheckError(SBRC2_Decrypt(&u4B0Raw, &u4B1Raw, (TRC2ExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		ZVAL_LONG(zu4B0, (long)u4B0Raw);
		ZVAL_LONG(zu4B1, (long)u4B1Raw);
	}
	else
	{
		SBErrorExpectsArguments("(&integer, &integer, TRC2ExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBRC2, ParseASN1Params)
{
	int32_t l4KeyBitsRaw;
	SBArrayZValInfo aiIV;
	SBArrayZValInfo aiParams;
	uint32_t _err;
	zval *zaIV;
	zval *zaParams;
	zval *zl4KeyBits;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzz", &zaParams, &zaIV, &zl4KeyBits) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaParams)) || (IS_ARRAY == Z_TYPE_P(zaParams)) || (IS_NULL == Z_TYPE_P(zaParams))) && PZVAL_IS_REF(zaIV) && ((IS_STRING == Z_TYPE_P(zaIV)) || (IS_ARRAY == Z_TYPE_P(zaIV))) && PZVAL_IS_REF(zl4KeyBits) && (IS_LONG == Z_TYPE_P(zl4KeyBits)))
	{
		int8_t bOutResultRaw = 0;
		if (!SBGetByteArrayFromZVal(zaParams, &aiParams TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaIV, &aiIV TSRMLS_CC)) RETURN_FALSE;
		l4KeyBitsRaw = (int32_t)Z_LVAL_P(zl4KeyBits);
		_err = SBRC2_ParseASN1Params(aiParams.data, aiParams.len, aiIV.data, &aiIV.len, &l4KeyBitsRaw, &bOutResultRaw);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			SBDetachDataFromZValAndResize(zaIV, &aiIV TSRMLS_CC);
			SBCheckError(SBGetLastReturnBuffer(-2012554264, 1, aiIV.data, &aiIV.len) TSRMLS_CC);
			((char *)aiIV.data)[aiIV.len] = 0;
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBFreeArrayZValInfo(&aiIV);
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiParams);
		SBSetByteArrayToZVal(&aiIV, zaIV);
		ZVAL_LONG(zl4KeyBits, (long)l4KeyBitsRaw);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, &array of byte|string, &integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBRC2, WriteASN1Params)
{
	long l4KeyBits;
	SBArrayZValInfo aiIV;
	SBArrayZValInfo aiParams;
	uint32_t _err;
	zval *zaIV;
	zval *zaParams;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zlz", &zaIV, &l4KeyBits, &zaParams) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaIV)) || (IS_ARRAY == Z_TYPE_P(zaIV)) || (IS_NULL == Z_TYPE_P(zaIV))) && PZVAL_IS_REF(zaParams) && ((IS_STRING == Z_TYPE_P(zaParams)) || (IS_ARRAY == Z_TYPE_P(zaParams))))
	{
		if (!SBGetByteArrayFromZVal(zaIV, &aiIV TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaParams, &aiParams TSRMLS_CC)) RETURN_FALSE;
		_err = SBRC2_WriteASN1Params(aiIV.data, aiIV.len, (int32_t)l4KeyBits, aiParams.data, &aiParams.len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			SBDetachDataFromZValAndResize(zaParams, &aiParams TSRMLS_CC);
			SBCheckError(SBGetLastReturnBuffer(1781943983, 2, aiParams.data, &aiParams.len) TSRMLS_CC);
			((char *)aiParams.data)[aiParams.len] = 0;
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBFreeArrayZValInfo(&aiParams);
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiIV);
		SBSetByteArrayToZVal(&aiParams, zaParams);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, integer, &array of byte|string)" TSRMLS_CC);
	}
}

void Register_SBRC2_Constants(int module_number TSRMLS_DC)
{
	SB_REGISTER_LONG_CONSTANT(SBRC2, TRC2BufferSize, SB_TRC2BufferSize, SB_TRC2BufferSize);
	SB_REGISTER_LONG_CONSTANT(SBRC2, TRC2ExpandedKeyLength, SB_TRC2ExpandedKeyLength, SB_TRC2ExpandedKeyLength);
}

