#include "sbtarutils.h"

SB_PHP_FUNCTION(SBTarUtils, Oct2Dec)
{
	char *sOct;
	int sOct_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sOct, &sOct_len) == SUCCESS)
	{
		int64_t l8OutResultRaw = 0;
		SBCheckError(SBTarUtils_Oct2Dec(sOct, (int32_t)sOct_len, &l8OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l8OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBTarUtils, Dec2Oct)
{
	long l4Len;
	long l8Dec;
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "ll", &l8Dec, &l4Len) == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = SBTarUtils_Dec2Oct((int64_t)l8Dec, (int32_t)l4Len, sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-331840100, 2, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(integer, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBTarUtils, TruncArray)
{
	SBArrayZValInfo aiB;
	uint32_t _err;
	zval *zaB;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zaB) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaB)) || (IS_ARRAY == Z_TYPE_P(zaB)) || (IS_NULL == Z_TYPE_P(zaB))))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaB, &aiB TSRMLS_CC)) RETURN_FALSE;
		_err = SBTarUtils_TruncArray(aiB.data, aiB.len, u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(1827016839, 1, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiB);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL)" TSRMLS_CC);
	}
}

void Register_SBTarUtils_Constants(int module_number TSRMLS_DC)
{
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidClassOwner, SB_SInvalidClassOwner, SB_SInvalidClassOwner);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidTypeCast, SB_SInvalidTypeCast, SB_SInvalidTypeCast);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidHeaderSize, SB_SInvalidHeaderSize, SB_SInvalidHeaderSize);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidCheckSum, SB_SInvalidCheckSum, SB_SInvalidCheckSum);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidUStarSize, SB_SInvalidUStarSize, SB_SInvalidUStarSize);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidParameter, SB_SInvalidParameter, SB_SInvalidParameter);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidFileData, SB_SInvalidFileData, SB_SInvalidFileData);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidFileDataOffset, SB_SInvalidFileDataOffset, SB_SInvalidFileDataOffset);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidPath, SB_SInvalidPath, SB_SInvalidPath);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidMethodSequence, SB_SInvalidMethodSequence, SB_SInvalidMethodSequence);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SArchiveNotOpened, SB_SArchiveNotOpened, SB_SArchiveNotOpened);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SArchiveNotAssign, SB_SArchiveNotAssign, SB_SArchiveNotAssign);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SFileAlreadyExists, SB_SFileAlreadyExists, SB_SFileAlreadyExists);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SDirectoryAlreadyExists, SB_SDirectoryAlreadyExists, SB_SDirectoryAlreadyExists);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SCannotCreateFile, SB_SCannotCreateFile, SB_SCannotCreateFile);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SInvalidActionRequested, SB_SInvalidActionRequested, SB_SInvalidActionRequested);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SNoOutputStream, SB_SNoOutputStream, SB_SNoOutputStream);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SCRCMismatch, SB_SCRCMismatch, SB_SCRCMismatch);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SParentIsNotDirectory, SB_SParentIsNotDirectory, SB_SParentIsNotDirectory);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SFileAlreadyInArchive, SB_SFileAlreadyInArchive, SB_SFileAlreadyInArchive);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorWriteStream, SB_SErrorWriteStream, SB_SErrorWriteStream);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SNoInputForCompression, SB_SNoInputForCompression, SB_SNoInputForCompression);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorCreateTarFile, SB_SErrorCreateTarFile, SB_SErrorCreateTarFile);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorCreateFile, SB_SErrorCreateFile, SB_SErrorCreateFile);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorOpenFile, SB_SErrorOpenFile, SB_SErrorOpenFile);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorIndexFile, SB_SErrorIndexFile, SB_SErrorIndexFile);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorRepos, SB_SErrorRepos, SB_SErrorRepos);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorCorrupted, SB_SErrorCorrupted, SB_SErrorCorrupted);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorRead, SB_SErrorRead, SB_SErrorRead);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorWrite, SB_SErrorWrite, SB_SErrorWrite);
	SB_REGISTER_STRING_CONSTANT(SBTarUtils, SErrorAttr, SB_SErrorAttr, SB_SErrorAttr);
	SB_REGISTER_LONG_CONSTANT(SBTarUtils, HeaderSize, SB_HeaderSize, SB_HeaderSize);
	SB_REGISTER_LONG_CONSTANT(SBTarUtils, BaseSize, SB_BaseSize, SB_BaseSize);
	SB_REGISTER_LONG_CONSTANT(SBTarUtils, TAR_BUFFER_SIZE, SB_TAR_BUFFER_SIZE, SB_TAR_BUFFER_SIZE);
}

