#include "sbxmlsig.h"

void SB_CALLBACK TSBXMLRemoteSignEventRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pHash[], int32_t szHash, uint8_t pSignedHash[], int32_t * szSignedHash)
{
	zval *retval_ptr;
	zval **params[3];
	zval * zSender;
	zval * zHash;
	zval * zSignedHash;
	SBArrayZValInfo aiSignedHash;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zHash);
	ZVAL_STRINGL(zHash, pHash, szHash, 1);
	MAKE_STD_ZVAL(zSignedHash);
	ZVAL_STRINGL(zSignedHash, pSignedHash, *szSignedHash, 1);

	params[0] = &zSender;
	params[1] = &zHash;
	params[2] = &zSignedHash;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zHash);
	if (SBGetByteArrayFromZVal(zSignedHash, &aiSignedHash TSRMLS_CC))
		SBCheckError(SBSetEventReturnBuffer(3, aiSignedHash.data, aiSignedHash.len) TSRMLS_CC);
	SBFreeArrayZValInfo(&aiSignedHash);
	zval_ptr_dtor(&zSignedHash);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

zend_class_entry *TElXMLSignature_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSignature, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSignature_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLSignature_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oDocument, TElXMLDOMDocument_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_SaveToXML_1(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter) or (TElXMLDOMDocument)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_ID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignature_get_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1251570885, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_ID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_SignedInfo)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_SignedInfo(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLSignedInfo_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_SignedInfo)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLSignedInfo_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_SignedInfo(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLSignedInfo)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_SignatureValue)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_SignatureValue(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLSignatureValue_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_SignatureValue)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLSignatureValue_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_SignatureValue(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLSignatureValue)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_KeyInfo)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_KeyInfo(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLKeyInfo_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_KeyInfo)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLKeyInfo_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_KeyInfo(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLKeyInfo)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_Objects)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_Objects(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLObjectList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_Objects)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLObjectList_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_Objects(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLObjectList)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_SignaturePrefix)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignature_get_SignaturePrefix(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(212021658, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_SignaturePrefix)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_SignaturePrefix(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_SignatureCompliance)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureComplianceRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSignature_get_SignatureCompliance(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_SignatureCompliance)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_SignatureCompliance(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLSignatureComplianceRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_CryptoProviderManager)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_CryptoProviderManager(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElCustomCryptoProviderManager_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_CryptoProviderManager)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElCustomCryptoProviderManager_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_CryptoProviderManager(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElCustomCryptoProviderManager)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_QualifyingProperties)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_QualifyingProperties(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLQualifyingProperties_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, set_QualifyingProperties)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLQualifyingProperties_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignature_set_QualifyingProperties(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLQualifyingProperties)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, get_QualifyingPropertiesReferences)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_get_QualifyingPropertiesReferences(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLQualifyingPropertiesReferenceList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignature, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignature_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_SaveToXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_ID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_ID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_SignedInfo, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_SignedInfo, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLSignedInfo, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_SignatureValue, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_SignatureValue, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLSignatureValue, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_KeyInfo, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_KeyInfo, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLKeyInfo, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_Objects, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_Objects, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLObjectList, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_SignaturePrefix, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_SignaturePrefix, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_SignatureCompliance, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_SignatureCompliance, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_CryptoProviderManager, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_CryptoProviderManager, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElCustomCryptoProviderManager, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_QualifyingProperties, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_set_QualifyingProperties, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLQualifyingProperties, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature_get_QualifyingPropertiesReferences, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignature___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSignature_methods[] = {
	PHP_ME(TElXMLSignature, Clear, arginfo_TElXMLSignature_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, IsEmpty, arginfo_TElXMLSignature_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, LoadFromXML, arginfo_TElXMLSignature_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, SaveToXML, arginfo_TElXMLSignature_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_ID, arginfo_TElXMLSignature_get_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_ID, arginfo_TElXMLSignature_set_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_SignedInfo, arginfo_TElXMLSignature_get_SignedInfo, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_SignedInfo, arginfo_TElXMLSignature_set_SignedInfo, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_SignatureValue, arginfo_TElXMLSignature_get_SignatureValue, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_SignatureValue, arginfo_TElXMLSignature_set_SignatureValue, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_KeyInfo, arginfo_TElXMLSignature_get_KeyInfo, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_KeyInfo, arginfo_TElXMLSignature_set_KeyInfo, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_Objects, arginfo_TElXMLSignature_get_Objects, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_Objects, arginfo_TElXMLSignature_set_Objects, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_SignaturePrefix, arginfo_TElXMLSignature_get_SignaturePrefix, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_SignaturePrefix, arginfo_TElXMLSignature_set_SignaturePrefix, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_SignatureCompliance, arginfo_TElXMLSignature_get_SignatureCompliance, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_SignatureCompliance, arginfo_TElXMLSignature_set_SignatureCompliance, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_CryptoProviderManager, arginfo_TElXMLSignature_get_CryptoProviderManager, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_CryptoProviderManager, arginfo_TElXMLSignature_set_CryptoProviderManager, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_QualifyingProperties, arginfo_TElXMLSignature_get_QualifyingProperties, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, set_QualifyingProperties, arginfo_TElXMLSignature_set_QualifyingProperties, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, get_QualifyingPropertiesReferences, arginfo_TElXMLSignature_get_QualifyingPropertiesReferences, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignature, __construct, arginfo_TElXMLSignature___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSignature(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSignature_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSignature", TElXMLSignature_methods);
	if (NULL == TElXMLCustomElement_ce_ptr)
		Register_TElXMLCustomElement(TSRMLS_C);
	TElXMLSignature_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLCustomElement_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSigProcessor_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSigProcessor, ClearSignatureMethodParameters)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSigProcessor_ClearSignatureMethodParameters(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, get_KeyData)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigProcessor_get_KeyData(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLKeyInfoData_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, set_KeyData)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLKeyInfoData_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigProcessor_set_KeyData(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLKeyInfoData)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, get_Signature)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigProcessor_get_Signature(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLSignature_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, set_Signature)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLSignature_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigProcessor_set_Signature(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLSignature)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, get_SignatureMethodParameters)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigProcessor_get_SignatureMethodParameters(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLAlgorithmParameters_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, set_SignatureMethodParameters)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLAlgorithmParameters_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigProcessor_set_SignatureMethodParameters(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLAlgorithmParameters)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigProcessor, __construct)
{
	zval *oAOwner;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oAOwner, TComponent_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigProcessor_Create(SBGetObjectHandle(oAOwner TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TComponent)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_ClearSignatureMethodParameters, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_get_KeyData, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_set_KeyData, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLKeyInfoData, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_get_Signature, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_set_Signature, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLSignature, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_get_SignatureMethodParameters, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor_set_SignatureMethodParameters, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLAlgorithmParameters, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigProcessor___construct, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, AOwner, TComponent, 1)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSigProcessor_methods[] = {
	PHP_ME(TElXMLSigProcessor, ClearSignatureMethodParameters, arginfo_TElXMLSigProcessor_ClearSignatureMethodParameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, get_KeyData, arginfo_TElXMLSigProcessor_get_KeyData, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, set_KeyData, arginfo_TElXMLSigProcessor_set_KeyData, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, get_Signature, arginfo_TElXMLSigProcessor_get_Signature, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, set_Signature, arginfo_TElXMLSigProcessor_set_Signature, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, get_SignatureMethodParameters, arginfo_TElXMLSigProcessor_get_SignatureMethodParameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, set_SignatureMethodParameters, arginfo_TElXMLSigProcessor_set_SignatureMethodParameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigProcessor, __construct, arginfo_TElXMLSigProcessor___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSigProcessor(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSigProcessor_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSigProcessor", TElXMLSigProcessor_methods);
	if (NULL == TElXMLProcessor_ce_ptr)
		Register_TElXMLProcessor(TSRMLS_C);
	TElXMLSigProcessor_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLProcessor_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSigner_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSigner, CompleteAsyncSign)
{
	zval *oDocument;
	zval *oState;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oState, TElDCAsyncState_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_CompleteAsyncSign(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oState TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElDCAsyncState)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, InitiateAsyncSign)
{
	TElClassHandle hoNode;
	zval *oNode;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oNode, TElXMLDOMNode_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oNode) && (IS_OBJECT == Z_TYPE_P(oNode)))
	{
		TElClassHandle hoOutResult = NULL;
		hoNode = SBGetObjectHandle(oNode TSRMLS_CC);
		SBCheckError(TElXMLSigner_InitiateAsyncSign(SBGetObjectHandle(getThis() TSRMLS_CC), &hoNode, &hoOutResult) TSRMLS_CC);
		SBUpdateObjectHandle(oNode, hoNode TSRMLS_CC);
		SBInitObject(return_value, TElDCAsyncState_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TElXMLDOMNode)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, GenerateSignature)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSigner_GenerateSignature(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, GenerateSignatureAsync)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSigner_GenerateSignatureAsync(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, Sign)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSigner_Sign(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, Save)
{
	TElClassHandle hoNode;
	zval *oNode;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oNode, TElXMLDOMNode_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oNode) && (IS_OBJECT == Z_TYPE_P(oNode)))
	{
		hoNode = SBGetObjectHandle(oNode TSRMLS_CC);
		SBCheckError(TElXMLSigner_Save(SBGetObjectHandle(getThis() TSRMLS_CC), &hoNode) TSRMLS_CC);
		SBUpdateObjectHandle(oNode, hoNode TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TElXMLDOMNode)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, SaveDetached)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_SaveDetached(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMDocument_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, SaveEnveloped)
{
	zval *oParentElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oParentElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_SaveEnveloped(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oParentElement TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, SaveEnveloping)
{
	zval *oEnvelopingNode;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oEnvelopingNode, TElXMLDOMNode_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_SaveEnveloping(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oEnvelopingNode TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMNode)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, UpdateReferencesDigest)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSigner_UpdateReferencesDigest(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_References)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_get_References(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLReferenceList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_References)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLReferenceList_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_References(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLReferenceList)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_RemoteSigningParams)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_get_RemoteSigningParams(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElRemoteSigningParams_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_XAdESProcessor)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_get_XAdESProcessor(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXAdESSigner_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_XAdESProcessor)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXAdESSigner_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_XAdESProcessor(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXAdESSigner)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_CanonicalizationMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLCanonicalizationMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_CanonicalizationMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_CanonicalizationMethod)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_CanonicalizationMethod(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLCanonicalizationMethodRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_InclusiveNamespacesPrefixList)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSigner_get_InclusiveNamespacesPrefixList(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(877253242, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_InclusiveNamespacesPrefixList)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_InclusiveNamespacesPrefixList(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_SignatureType)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureTypeRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_SignatureType(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_SignatureType)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_SignatureType(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLSignatureTypeRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_SignatureCompliance)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureComplianceRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_SignatureCompliance(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_SignatureCompliance)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_SignatureCompliance(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLSignatureComplianceRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_SignatureMethodType)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSigMethodTypeRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_SignatureMethodType(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_SignatureMethodType)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_SignatureMethodType(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLSigMethodTypeRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_MACMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLMACMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_MACMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_MACMethod)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_MACMethod(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLMACMethodRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_SignatureMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_SignatureMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_SignatureMethod)
{
	long fValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &fValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_SignatureMethod(SBGetObjectHandle(getThis() TSRMLS_CC), (TElXMLSignatureMethodRaw)fValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_IncludeKey)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLSigner_get_IncludeKey(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_IncludeKey)
{
	zend_bool bValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "b", &bValue) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_IncludeKey(SBGetObjectHandle(getThis() TSRMLS_CC), (int8_t)bValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_KeyName)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSigner_get_KeyName(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1948372913, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_KeyName)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_KeyName(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_EnvelopingObjectID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSigner_get_EnvelopingObjectID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(709560888, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_EnvelopingObjectID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSigner_set_EnvelopingObjectID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_OnFormatElement)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBXMLFormatElementEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElXMLSigner_get_OnFormatElement(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_OnFormatElement)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElXMLSigner_set_OnFormatElement(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBXMLFormatElementEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBXMLFormatElementEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_OnFormatText)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBXMLFormatTextEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElXMLSigner_get_OnFormatText(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_OnFormatText)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElXMLSigner_set_OnFormatText(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBXMLFormatTextEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBXMLFormatTextEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, get_OnRemoteSign)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBXMLRemoteSignEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElXMLSigner_get_OnRemoteSign(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, set_OnRemoteSign)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElXMLSigner_set_OnRemoteSign(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBXMLRemoteSignEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBXMLRemoteSignEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSigner, __construct)
{
	zval *oAOwner;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oAOwner, TComponent_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSigner_Create(SBGetObjectHandle(oAOwner TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TComponent)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_CompleteAsyncSign, 0, 0, 2)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, State, TElDCAsyncState, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_InitiateAsyncSign, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(1, Node, TElXMLDOMNode, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_GenerateSignature, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_GenerateSignatureAsync, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_Sign, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_Save, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(1, Node, TElXMLDOMNode, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_SaveDetached, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_SaveEnveloped, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, ParentElement, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_SaveEnveloping, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, EnvelopingNode, TElXMLDOMNode, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_UpdateReferencesDigest, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_References, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_References, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLReferenceList, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_RemoteSigningParams, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_XAdESProcessor, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_XAdESProcessor, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXAdESSigner, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_CanonicalizationMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_CanonicalizationMethod, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_InclusiveNamespacesPrefixList, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_InclusiveNamespacesPrefixList, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_SignatureType, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_SignatureType, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_SignatureCompliance, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_SignatureCompliance, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_SignatureMethodType, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_SignatureMethodType, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_MACMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_MACMethod, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_SignatureMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_SignatureMethod, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_IncludeKey, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_IncludeKey, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_KeyName, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_KeyName, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_EnvelopingObjectID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_EnvelopingObjectID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_OnFormatElement, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_OnFormatElement, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_OnFormatText, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_OnFormatText, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_get_OnRemoteSign, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner_set_OnRemoteSign, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSigner___construct, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, AOwner, TComponent, 1)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSigner_methods[] = {
	PHP_ME(TElXMLSigner, CompleteAsyncSign, arginfo_TElXMLSigner_CompleteAsyncSign, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, InitiateAsyncSign, arginfo_TElXMLSigner_InitiateAsyncSign, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, GenerateSignature, arginfo_TElXMLSigner_GenerateSignature, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, GenerateSignatureAsync, arginfo_TElXMLSigner_GenerateSignatureAsync, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, Sign, arginfo_TElXMLSigner_Sign, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, Save, arginfo_TElXMLSigner_Save, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, SaveDetached, arginfo_TElXMLSigner_SaveDetached, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, SaveEnveloped, arginfo_TElXMLSigner_SaveEnveloped, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, SaveEnveloping, arginfo_TElXMLSigner_SaveEnveloping, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, UpdateReferencesDigest, arginfo_TElXMLSigner_UpdateReferencesDigest, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_References, arginfo_TElXMLSigner_get_References, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_References, arginfo_TElXMLSigner_set_References, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_RemoteSigningParams, arginfo_TElXMLSigner_get_RemoteSigningParams, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_XAdESProcessor, arginfo_TElXMLSigner_get_XAdESProcessor, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_XAdESProcessor, arginfo_TElXMLSigner_set_XAdESProcessor, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_CanonicalizationMethod, arginfo_TElXMLSigner_get_CanonicalizationMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_CanonicalizationMethod, arginfo_TElXMLSigner_set_CanonicalizationMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_InclusiveNamespacesPrefixList, arginfo_TElXMLSigner_get_InclusiveNamespacesPrefixList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_InclusiveNamespacesPrefixList, arginfo_TElXMLSigner_set_InclusiveNamespacesPrefixList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_SignatureType, arginfo_TElXMLSigner_get_SignatureType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_SignatureType, arginfo_TElXMLSigner_set_SignatureType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_SignatureCompliance, arginfo_TElXMLSigner_get_SignatureCompliance, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_SignatureCompliance, arginfo_TElXMLSigner_set_SignatureCompliance, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_SignatureMethodType, arginfo_TElXMLSigner_get_SignatureMethodType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_SignatureMethodType, arginfo_TElXMLSigner_set_SignatureMethodType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_MACMethod, arginfo_TElXMLSigner_get_MACMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_MACMethod, arginfo_TElXMLSigner_set_MACMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_SignatureMethod, arginfo_TElXMLSigner_get_SignatureMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_SignatureMethod, arginfo_TElXMLSigner_set_SignatureMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_IncludeKey, arginfo_TElXMLSigner_get_IncludeKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_IncludeKey, arginfo_TElXMLSigner_set_IncludeKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_KeyName, arginfo_TElXMLSigner_get_KeyName, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_KeyName, arginfo_TElXMLSigner_set_KeyName, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_EnvelopingObjectID, arginfo_TElXMLSigner_get_EnvelopingObjectID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_EnvelopingObjectID, arginfo_TElXMLSigner_set_EnvelopingObjectID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_OnFormatElement, arginfo_TElXMLSigner_get_OnFormatElement, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_OnFormatElement, arginfo_TElXMLSigner_set_OnFormatElement, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_OnFormatText, arginfo_TElXMLSigner_get_OnFormatText, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_OnFormatText, arginfo_TElXMLSigner_set_OnFormatText, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, get_OnRemoteSign, arginfo_TElXMLSigner_get_OnRemoteSign, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, set_OnRemoteSign, arginfo_TElXMLSigner_set_OnRemoteSign, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSigner, __construct, arginfo_TElXMLSigner___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSigner(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSigner_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSigner", TElXMLSigner_methods);
	if (NULL == TElXMLSigProcessor_ce_ptr)
		Register_TElXMLSigProcessor(TSRMLS_C);
	TElXMLSigner_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLSigProcessor_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLVerifier_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLVerifier, Load)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLVerifier_Load(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, ValidateSignature)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_ValidateSignature(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, ValidateReference)
{
	zval *oReference;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oReference, TElXMLReference_ce_ptr) == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_ValidateReference(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oReference TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLReference)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, ValidateReferences)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_ValidateReferences(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, RemoveSignature)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLVerifier_RemoveSignature(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_HMACKey)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_get_HMACKey(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLKeyInfoHMACData_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, set_HMACKey)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLKeyInfoHMACData_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLVerifier_set_HMACKey(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLKeyInfoHMACData)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_References)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_get_References(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLReferenceList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_CanonicalizationMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLCanonicalizationMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_CanonicalizationMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_InclusiveNamespacesPrefixList)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLVerifier_get_InclusiveNamespacesPrefixList(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1097865349, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignatureType)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureTypesRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_SignatureType(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignatureCompliance)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureComplianceRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_SignatureCompliance(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignatureMethodType)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSigMethodTypeRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_SignatureMethodType(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_MACMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLMACMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_MACMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignatureMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElXMLSignatureMethodRaw fOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_SignatureMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &fOutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)fOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_KeyDataNeeded)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLVerifier_get_KeyDataNeeded(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_KeyName)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLVerifier_get_KeyName(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-755733651, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignerCertificate)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_get_SignerCertificate(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElX509Certificate_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_SignerKeyData)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_get_SignerKeyData(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLKeyInfoData_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, get_XAdESProcessor)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_get_XAdESProcessor(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXAdESVerifier_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, set_XAdESProcessor)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXAdESVerifier_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLVerifier_set_XAdESProcessor(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXAdESVerifier)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLVerifier, __construct)
{
	zval *oAOwner;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oAOwner, TComponent_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLVerifier_Create(SBGetObjectHandle(oAOwner TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TComponent)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_Load, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_ValidateSignature, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_ValidateReference, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Reference, TElXMLReference, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_ValidateReferences, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_RemoveSignature, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_HMACKey, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_set_HMACKey, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLKeyInfoHMACData, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_References, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_CanonicalizationMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_InclusiveNamespacesPrefixList, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignatureType, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignatureCompliance, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignatureMethodType, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_MACMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignatureMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_KeyDataNeeded, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_KeyName, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignerCertificate, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_SignerKeyData, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_get_XAdESProcessor, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier_set_XAdESProcessor, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXAdESVerifier, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLVerifier___construct, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, AOwner, TComponent, 1)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLVerifier_methods[] = {
	PHP_ME(TElXMLVerifier, Load, arginfo_TElXMLVerifier_Load, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, ValidateSignature, arginfo_TElXMLVerifier_ValidateSignature, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, ValidateReference, arginfo_TElXMLVerifier_ValidateReference, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, ValidateReferences, arginfo_TElXMLVerifier_ValidateReferences, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, RemoveSignature, arginfo_TElXMLVerifier_RemoveSignature, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_HMACKey, arginfo_TElXMLVerifier_get_HMACKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, set_HMACKey, arginfo_TElXMLVerifier_set_HMACKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_References, arginfo_TElXMLVerifier_get_References, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_CanonicalizationMethod, arginfo_TElXMLVerifier_get_CanonicalizationMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_InclusiveNamespacesPrefixList, arginfo_TElXMLVerifier_get_InclusiveNamespacesPrefixList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignatureType, arginfo_TElXMLVerifier_get_SignatureType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignatureCompliance, arginfo_TElXMLVerifier_get_SignatureCompliance, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignatureMethodType, arginfo_TElXMLVerifier_get_SignatureMethodType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_MACMethod, arginfo_TElXMLVerifier_get_MACMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignatureMethod, arginfo_TElXMLVerifier_get_SignatureMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_KeyDataNeeded, arginfo_TElXMLVerifier_get_KeyDataNeeded, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_KeyName, arginfo_TElXMLVerifier_get_KeyName, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignerCertificate, arginfo_TElXMLVerifier_get_SignerCertificate, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_SignerKeyData, arginfo_TElXMLVerifier_get_SignerKeyData, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, get_XAdESProcessor, arginfo_TElXMLVerifier_get_XAdESProcessor, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, set_XAdESProcessor, arginfo_TElXMLVerifier_set_XAdESProcessor, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLVerifier, __construct, arginfo_TElXMLVerifier___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLVerifier(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLVerifier_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLVerifier", TElXMLVerifier_methods);
	if (NULL == TElXMLSigProcessor_ce_ptr)
		Register_TElXMLSigProcessor(TSRMLS_C);
	TElXMLVerifier_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLSigProcessor_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSignatureMethodType_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSignatureMethodType, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSignatureMethodType_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLSignatureMethodType_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureMethodType_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureMethodType_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oDocument, TElXMLDOMDocument_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureMethodType_SaveToXML_1(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter) or (TElXMLDOMDocument)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, get_Algorithm)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignatureMethodType_get_Algorithm(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1252889132, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, set_Algorithm)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureMethodType_set_Algorithm(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, get_HMACOutputLength)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElXMLSignatureMethodType_get_HMACOutputLength(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, set_HMACOutputLength)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureMethodType_set_HMACOutputLength(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, get_Parameters)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureMethodType_get_Parameters(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLAlgorithmParameters_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, set_Parameters)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLAlgorithmParameters_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureMethodType_set_Parameters(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLAlgorithmParameters)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureMethodType, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureMethodType_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_SaveToXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_get_Algorithm, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_set_Algorithm, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_get_HMACOutputLength, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_set_HMACOutputLength, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_get_Parameters, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType_set_Parameters, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLAlgorithmParameters, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureMethodType___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSignatureMethodType_methods[] = {
	PHP_ME(TElXMLSignatureMethodType, Clear, arginfo_TElXMLSignatureMethodType_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, IsEmpty, arginfo_TElXMLSignatureMethodType_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, LoadFromXML, arginfo_TElXMLSignatureMethodType_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, SaveToXML, arginfo_TElXMLSignatureMethodType_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, get_Algorithm, arginfo_TElXMLSignatureMethodType_get_Algorithm, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, set_Algorithm, arginfo_TElXMLSignatureMethodType_set_Algorithm, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, get_HMACOutputLength, arginfo_TElXMLSignatureMethodType_get_HMACOutputLength, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, set_HMACOutputLength, arginfo_TElXMLSignatureMethodType_set_HMACOutputLength, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, get_Parameters, arginfo_TElXMLSignatureMethodType_get_Parameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, set_Parameters, arginfo_TElXMLSignatureMethodType_set_Parameters, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureMethodType, __construct, arginfo_TElXMLSignatureMethodType___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSignatureMethodType(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSignatureMethodType_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSignatureMethodType", TElXMLSignatureMethodType_methods);
	if (NULL == TElXMLCustomElement_ce_ptr)
		Register_TElXMLCustomElement(TSRMLS_C);
	TElXMLSignatureMethodType_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLCustomElement_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSignedInfo_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSignedInfo, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLSignedInfo_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oDocument, TElXMLDOMDocument_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_SaveToXML_1(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter) or (TElXMLDOMDocument)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_ID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignedInfo_get_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-736400028, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_ID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_CanonicalizationMethod)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignedInfo_get_CanonicalizationMethod(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1137074810, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_CanonicalizationMethod)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_CanonicalizationMethod(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_ExclusiveCanonicalizationPrefix)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignedInfo_get_ExclusiveCanonicalizationPrefix(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(359281730, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_ExclusiveCanonicalizationPrefix)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_ExclusiveCanonicalizationPrefix(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_InclusiveNamespacesPrefixList)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignedInfo_get_InclusiveNamespacesPrefixList(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-1702292144, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_InclusiveNamespacesPrefixList)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_InclusiveNamespacesPrefixList(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_SignatureMethod)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_get_SignatureMethod(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLSignatureMethodType_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_SignatureMethod)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLSignatureMethodType_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_SignatureMethod(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLSignatureMethodType)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_References)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_get_References(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLReferenceList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, set_References)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLReferenceList_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignedInfo_set_References(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLReferenceList)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, get_SigPropRef)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_get_SigPropRef(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLReference_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignedInfo, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignedInfo_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_SaveToXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_ID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_ID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_CanonicalizationMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_CanonicalizationMethod, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_ExclusiveCanonicalizationPrefix, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_ExclusiveCanonicalizationPrefix, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_InclusiveNamespacesPrefixList, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_InclusiveNamespacesPrefixList, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_SignatureMethod, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_SignatureMethod, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLSignatureMethodType, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_References, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_set_References, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLReferenceList, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo_get_SigPropRef, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignedInfo___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSignedInfo_methods[] = {
	PHP_ME(TElXMLSignedInfo, Clear, arginfo_TElXMLSignedInfo_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, IsEmpty, arginfo_TElXMLSignedInfo_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, LoadFromXML, arginfo_TElXMLSignedInfo_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, SaveToXML, arginfo_TElXMLSignedInfo_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_ID, arginfo_TElXMLSignedInfo_get_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_ID, arginfo_TElXMLSignedInfo_set_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_CanonicalizationMethod, arginfo_TElXMLSignedInfo_get_CanonicalizationMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_CanonicalizationMethod, arginfo_TElXMLSignedInfo_set_CanonicalizationMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_ExclusiveCanonicalizationPrefix, arginfo_TElXMLSignedInfo_get_ExclusiveCanonicalizationPrefix, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_ExclusiveCanonicalizationPrefix, arginfo_TElXMLSignedInfo_set_ExclusiveCanonicalizationPrefix, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_InclusiveNamespacesPrefixList, arginfo_TElXMLSignedInfo_get_InclusiveNamespacesPrefixList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_InclusiveNamespacesPrefixList, arginfo_TElXMLSignedInfo_set_InclusiveNamespacesPrefixList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_SignatureMethod, arginfo_TElXMLSignedInfo_get_SignatureMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_SignatureMethod, arginfo_TElXMLSignedInfo_set_SignatureMethod, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_References, arginfo_TElXMLSignedInfo_get_References, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, set_References, arginfo_TElXMLSignedInfo_set_References, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, get_SigPropRef, arginfo_TElXMLSignedInfo_get_SigPropRef, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignedInfo, __construct, arginfo_TElXMLSignedInfo___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSignedInfo(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSignedInfo_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSignedInfo", TElXMLSignedInfo_methods);
	if (NULL == TElXMLCustomElement_ce_ptr)
		Register_TElXMLCustomElement(TSRMLS_C);
	TElXMLSignedInfo_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLCustomElement_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLManifest_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLManifest, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLManifest_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLManifest_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLManifest_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLManifest_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, get_XMLElement)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLManifest_get_XMLElement(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, set_XMLElement)
{
	zval *oValue;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oValue, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLManifest_set_XMLElement(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oValue TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, get_ID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLManifest_get_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(556566044, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, set_ID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLManifest_set_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLManifest, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLManifest_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_SaveToXML, 0, 0, 2)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_get_XMLElement, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_set_XMLElement, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Value, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_get_ID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest_set_ID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLManifest___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLManifest_methods[] = {
	PHP_ME(TElXMLManifest, Clear, arginfo_TElXMLManifest_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, IsEmpty, arginfo_TElXMLManifest_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, LoadFromXML, arginfo_TElXMLManifest_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, SaveToXML, arginfo_TElXMLManifest_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, get_XMLElement, arginfo_TElXMLManifest_get_XMLElement, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, set_XMLElement, arginfo_TElXMLManifest_set_XMLElement, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, get_ID, arginfo_TElXMLManifest_get_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, set_ID, arginfo_TElXMLManifest_set_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLManifest, __construct, arginfo_TElXMLManifest___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLManifest(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLManifest_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLManifest", TElXMLManifest_methods);
	if (NULL == TElXMLReferenceList_ce_ptr)
		Register_TElXMLReferenceList(TSRMLS_C);
	TElXMLManifest_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLReferenceList_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSignatureProperties_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSignatureProperties, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureProperties_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureProperties___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSignatureProperties_methods[] = {
	PHP_ME(TElXMLSignatureProperties, __construct, arginfo_TElXMLSignatureProperties___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSignatureProperties(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSignatureProperties_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSignatureProperties", TElXMLSignatureProperties_methods);
	if (NULL == TElXMLProperties_ce_ptr)
		Register_TElXMLProperties(TSRMLS_C);
	TElXMLSignatureProperties_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLProperties_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLObject_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLObject, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLObject_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLObject_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLObject_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObject_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oDocument, TElXMLDOMDocument_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObject_SaveToXML_1(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter) or (TElXMLDOMDocument)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, get_ID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLObject_get_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-2070494151, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, set_ID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLObject_set_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, get_MimeType)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLObject_get_MimeType(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(-2084077490, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, set_MimeType)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLObject_set_MimeType(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, get_Encoding)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLObject_get_Encoding(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(863885702, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, set_Encoding)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLObject_set_Encoding(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, get_DataList)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObject_get_DataList(SBGetObjectHandle(getThis() TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TList_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObject, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObject_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_SaveToXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_get_ID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_set_ID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_get_MimeType, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_set_MimeType, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_get_Encoding, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_set_Encoding, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject_get_DataList, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObject___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLObject_methods[] = {
	PHP_ME(TElXMLObject, Clear, arginfo_TElXMLObject_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, IsEmpty, arginfo_TElXMLObject_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, LoadFromXML, arginfo_TElXMLObject_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, SaveToXML, arginfo_TElXMLObject_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, get_ID, arginfo_TElXMLObject_get_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, set_ID, arginfo_TElXMLObject_set_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, get_MimeType, arginfo_TElXMLObject_get_MimeType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, set_MimeType, arginfo_TElXMLObject_set_MimeType, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, get_Encoding, arginfo_TElXMLObject_get_Encoding, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, set_Encoding, arginfo_TElXMLObject_set_Encoding, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, get_DataList, arginfo_TElXMLObject_get_DataList, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObject, __construct, arginfo_TElXMLObject___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLObject(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLObject_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLObject", TElXMLObject_methods);
	if (NULL == TElXMLCustomElement_ce_ptr)
		Register_TElXMLCustomElement(TSRMLS_C);
	TElXMLObject_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLCustomElement_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLObjectList_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLObjectList, Add)
{
	zval *oAObject;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oAObject, TElXMLObject_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElXMLObjectList_Add(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oAObject TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLObject)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLObjectList_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, Delete)
{
	long l4Index;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Index) == SUCCESS)
	{
		SBCheckError(TElXMLObjectList_Delete(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Index) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, Insert)
{
	long l4Index;
	zval *oAObject;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "lO!", &l4Index, &oAObject, TElXMLObject_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLObjectList_Insert(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Index, SBGetObjectHandle(oAObject TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer, TElXMLObject)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, get_Count)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElXMLObjectList_get_Count(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, get_Objects)
{
	long l4Index;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Index) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObjectList_get_Objects(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Index, &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLObject_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLObjectList, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLObjectList_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_Add, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, AObject, TElXMLObject, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_Delete, 0, 0, 1)
	ZEND_ARG_INFO(0, Index)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_Insert, 0, 0, 2)
	ZEND_ARG_INFO(0, Index)
	ZEND_ARG_OBJ_INFO(0, AObject, TElXMLObject, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_get_Count, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList_get_Objects, 0, 0, 1)
	ZEND_ARG_INFO(0, Index)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLObjectList___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLObjectList_methods[] = {
	PHP_ME(TElXMLObjectList, Add, arginfo_TElXMLObjectList_Add, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, Clear, arginfo_TElXMLObjectList_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, Delete, arginfo_TElXMLObjectList_Delete, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, Insert, arginfo_TElXMLObjectList_Insert, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, get_Count, arginfo_TElXMLObjectList_get_Count, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, get_Objects, arginfo_TElXMLObjectList_get_Objects, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLObjectList, __construct, arginfo_TElXMLObjectList___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLObjectList(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLObjectList_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLObjectList", TElXMLObjectList_methods);
	if (NULL == TObject_ce_ptr)
		Register_TObject(TSRMLS_C);
	TElXMLObjectList_ce_ptr = zend_register_internal_class_ex(&ce, TObject_ce_ptr, NULL TSRMLS_CC);
}

zend_class_entry *TElXMLSignatureValue_ce_ptr = NULL;

SB_PHP_METHOD(TElXMLSignatureValue, Clear)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		SBCheckError(TElXMLSignatureValue_Clear(SBGetObjectHandle(getThis() TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, IsEmpty)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int8_t bOutResultRaw = 0;
		SBCheckError(TElXMLSignatureValue_IsEmpty(SBGetObjectHandle(getThis() TSRMLS_CC), &bOutResultRaw) TSRMLS_CC);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, LoadFromXML)
{
	zval *oElement;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oElement, TElXMLDOMElement_ce_ptr) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureValue_LoadFromXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oElement TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMElement)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, SaveToXML)
{
	zval *oDocument;
	zval *oFormatter;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!O!", &oDocument, TElXMLDOMDocument_ce_ptr, &oFormatter, TElXMLCustomFormatter_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureValue_SaveToXML(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), SBGetObjectHandle(oFormatter TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oDocument, TElXMLDOMDocument_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureValue_SaveToXML_1(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oDocument TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBInitObject(return_value, TElXMLDOMElement_ce_ptr, hoOutResult TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TElXMLDOMDocument, TElXMLCustomFormatter) or (TElXMLDOMDocument)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, get_ID)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		char *sOutResult = NULL;
		int32_t sOutResult_len = 0;
		_err = TElXMLSignatureValue_get_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sOutResult, &sOutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			sOutResult = emalloc(sOutResult_len + 1);
			SBCheckError(SBGetLastReturnStringA(1100860154, 1, sOutResult, &sOutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == sOutResult) sOutResult = emalloc(1);
		sOutResult[sOutResult_len] = 0;
		RETURN_STRINGL(sOutResult, sOutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, set_ID)
{
	char *sValue;
	int sValue_len;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s", &sValue, &sValue_len) == SUCCESS)
	{
		SBCheckError(TElXMLSignatureValue_set_ID(SBGetObjectHandle(getThis() TSRMLS_CC), sValue, (int32_t)sValue_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(string)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, get_Value)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		_err = TElXMLSignatureValue_get_Value(SBGetObjectHandle(getThis() TSRMLS_CC), u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(1559843589, 1, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, set_Value)
{
	SBArrayZValInfo aiValue;
	zval *zaValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zaValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaValue)) || (IS_ARRAY == Z_TYPE_P(zaValue)) || (IS_NULL == Z_TYPE_P(zaValue))))
	{
		if (!SBGetByteArrayFromZVal(zaValue, &aiValue TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElXMLSignatureValue_set_Value(SBGetObjectHandle(getThis() TSRMLS_CC), aiValue.data, aiValue.len) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiValue);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElXMLSignatureValue, __construct)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElXMLSignatureValue_Create(&hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_Clear, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_IsEmpty, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_LoadFromXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Element, TElXMLDOMElement, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_SaveToXML, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Document, TElXMLDOMDocument, 1)
	ZEND_ARG_OBJ_INFO(0, Formatter, TElXMLCustomFormatter, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_get_ID, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_set_ID, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_get_Value, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue_set_Value, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElXMLSignatureValue___construct, 0, 0, 0)
ZEND_END_ARG_INFO()

static zend_function_entry TElXMLSignatureValue_methods[] = {
	PHP_ME(TElXMLSignatureValue, Clear, arginfo_TElXMLSignatureValue_Clear, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, IsEmpty, arginfo_TElXMLSignatureValue_IsEmpty, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, LoadFromXML, arginfo_TElXMLSignatureValue_LoadFromXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, SaveToXML, arginfo_TElXMLSignatureValue_SaveToXML, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, get_ID, arginfo_TElXMLSignatureValue_get_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, set_ID, arginfo_TElXMLSignatureValue_set_ID, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, get_Value, arginfo_TElXMLSignatureValue_get_Value, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, set_Value, arginfo_TElXMLSignatureValue_set_Value, ZEND_ACC_PUBLIC)
	PHP_ME(TElXMLSignatureValue, __construct, arginfo_TElXMLSignatureValue___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElXMLSignatureValue(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElXMLSignatureValue_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElXMLSignatureValue", TElXMLSignatureValue_methods);
	if (NULL == TElXMLCustomElement_ce_ptr)
		Register_TElXMLCustomElement(TSRMLS_C);
	TElXMLSignatureValue_ce_ptr = zend_register_internal_class_ex(&ce, TElXMLCustomElement_ce_ptr, NULL TSRMLS_CC);
}

void Register_SBXMLSig_Aliases(TSRMLS_D)
{
	if (NULL == TElXMLSignature_ce_ptr)
		Register_TElXMLSignature(TSRMLS_C);
	zend_register_class_alias("ElXMLSignature", TElXMLSignature_ce_ptr);
	if (NULL == TElXMLSigProcessor_ce_ptr)
		Register_TElXMLSigProcessor(TSRMLS_C);
	zend_register_class_alias("ElXMLSigProcessor", TElXMLSigProcessor_ce_ptr);
	if (NULL == TElXMLSigner_ce_ptr)
		Register_TElXMLSigner(TSRMLS_C);
	zend_register_class_alias("ElXMLSigner", TElXMLSigner_ce_ptr);
	if (NULL == TElXMLVerifier_ce_ptr)
		Register_TElXMLVerifier(TSRMLS_C);
	zend_register_class_alias("ElXMLVerifier", TElXMLVerifier_ce_ptr);
	if (NULL == TElXMLSignatureMethodType_ce_ptr)
		Register_TElXMLSignatureMethodType(TSRMLS_C);
	zend_register_class_alias("ElXMLSignatureMethodType", TElXMLSignatureMethodType_ce_ptr);
	if (NULL == TElXMLSignedInfo_ce_ptr)
		Register_TElXMLSignedInfo(TSRMLS_C);
	zend_register_class_alias("ElXMLSignedInfo", TElXMLSignedInfo_ce_ptr);
	if (NULL == TElXMLManifest_ce_ptr)
		Register_TElXMLManifest(TSRMLS_C);
	zend_register_class_alias("ElXMLManifest", TElXMLManifest_ce_ptr);
	if (NULL == TElXMLSignatureProperties_ce_ptr)
		Register_TElXMLSignatureProperties(TSRMLS_C);
	zend_register_class_alias("ElXMLSignatureProperties", TElXMLSignatureProperties_ce_ptr);
	if (NULL == TElXMLObject_ce_ptr)
		Register_TElXMLObject(TSRMLS_C);
	zend_register_class_alias("ElXMLObject", TElXMLObject_ce_ptr);
	if (NULL == TElXMLObjectList_ce_ptr)
		Register_TElXMLObjectList(TSRMLS_C);
	zend_register_class_alias("ElXMLObjectList", TElXMLObjectList_ce_ptr);
	if (NULL == TElXMLSignatureValue_ce_ptr)
		Register_TElXMLSignatureValue(TSRMLS_C);
	zend_register_class_alias("ElXMLSignatureValue", TElXMLSignatureValue_ce_ptr);
}

