#ifndef __INC_SBAUTHENTICODE
#define __INC_SBAUTHENTICODE

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbpkicommon.h"
#include "sbcms.h"
#include "sbpkcs7.h"
#include "sbpkcs7utils.h"
#include "sbhashfunction.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbstrutils.h"
#include "sbconstants.h"
#include "sbencoding.h"
#include "sbx509.h"
#include "sbtspclient.h"
#include "sbcustomcertstorage.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
#define SB_AUTHENTICODE_ERROR_BASE 	9216
#define SB_AUTHENTICODE_ERROR_SUCCESS 	0
#define SB_AUTHENTICODE_ERROR_UNKNOWN 	9217
#define SB_AUTHENTICODE_ERROR_CANNOT_OPEN_FILE 	9218
#define SB_AUTHENTICODE_ERROR_FILE_TOO_SMALL 	9219
#define SB_AUTHENTICODE_ERROR_CANNOT_READ_FILE 	9220
#define SB_AUTHENTICODE_ERROR_CANNOT_WRITE_FILE 	9221
#define SB_AUTHENTICODE_ERROR_INVALID_EXECUTABLE 	9222
#define SB_AUTHENTICODE_ERROR_INVALID_PE_FORMAT 	9223
#define SB_AUTHENTICODE_ERROR_FILE_NOT_SIGNED 	9224
#define SB_AUTHENTICODE_ERROR_SIGNATURE_CORRUPTED 	9225
#define SB_AUTHENTICODE_ERROR_INVALID_ALGORITHM 	9226
#define SB_AUTHENTICODE_ERROR_INVALID_DIGEST_SIZE 	9227
#define SB_AUTHENTICODE_ERROR_INVALID_INDEX 	9228
#define SB_AUTHENTICODE_ERROR_NO_SIGNER_CERTIFICATE 	9229
#define SB_AUTHENTICODE_ERROR_INVALID_SIGNATURE 	9230
#define SB_AUTHENTICODE_ERROR_INVALID_CERTIFICATE 	9231
#define SB_AUTHENTICODE_ERROR_FILE_ALREADY_SIGNED 	9232
#define SB_AUTHENTICODE_ERROR_INVALID_ARGUMENT 	9233
#define SB_AUTHENTICODE_ERROR_INVALID_DATA 	9234
#define SB_AUTHENTICODE_ERROR_NO_SIGNATURES 	9235
#define SB_AUTHENTICODE_ERROR_NO_COUNTERSIGNATURES 	9236
#define SB_AUTHENTICODE_ERROR_FILE_NOT_OPEN 	9237
#define SB_AUTHENTICODE_ERROR_SIGNATURE_NOT_LAST 	9238
#define SB_AUTHENTICODE_ERROR_INVALID_AUTHENTICODE 	9239
#define SB_AUTHENTICODE_ERROR_NO_TIMESTAMP 	9240

typedef TElClassHandle TElAuthenticodeProcessorHandle;

typedef TElAuthenticodeProcessorHandle ElAuthenticodeProcessorHandle;

typedef TElClassHandle TElAuthenticodeSignerHandle;

typedef TElAuthenticodeSignerHandle ElAuthenticodeSignerHandle;

typedef TElClassHandle TElAuthenticodeVerifierHandle;

typedef TElAuthenticodeVerifierHandle ElAuthenticodeVerifierHandle;

#pragma pack(4)
typedef struct 
{
	uint32_t Current;
	uint16_t Buffer;
	int8_t BufferInUse;
} TChecksumContext, * PChecksumContext;

typedef uint8_t TSBAuthenticodeDigestAlgorithmRaw;

typedef enum
{
	acMD5 = 0,
	acSHA1 = 1,
	acSHA224 = 2,
	acSHA256 = 3,
	acSHA384 = 4,
	acSHA512 = 5
} TSBAuthenticodeDigestAlgorithm;

typedef uint8_t TSBAuthenticodeDigestEncryptionAlgorithmRaw;

typedef enum
{
	acRSA = 0,
	acDSA = 1
} TSBAuthenticodeDigestEncryptionAlgorithm;

typedef uint8_t TSBAuthenticodeStatementTypeRaw;

typedef enum
{
	acPrivate = 0,
	acCommercial = 1
} TSBAuthenticodeStatementType;

typedef void (SB_CALLBACK *TSBAuthenticodeTimestampNeeded)(void * _ObjectData, TObjectHandle Sender, const uint8_t pRequest[], int32_t szRequest, uint8_t pReply[], int32_t * szReply, int8_t * Succeeded);

#ifdef SB_USE_CLASS_TELAUTHENTICODEPROCESSOR
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeProcessor_Create(TComponentHandle AOwner, TComponentHandle * OutResult);
#endif /* SB_USE_CLASS_TELAUTHENTICODEPROCESSOR */

#ifdef SB_USE_CLASS_TELAUTHENTICODESIGNER
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_AddCertificate(TElAuthenticodeSignerHandle _Handle, TElX509CertificateHandle Certificate, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_AddAuthenticode(TElAuthenticodeSignerHandle _Handle, TSBAuthenticodeDigestAlgorithmRaw DigestAlgorithm, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_AddSignature(TElAuthenticodeSignerHandle _Handle, const char * pcDescription, int32_t szDescription, const char * pcURL, int32_t szURL, TSBAuthenticodeDigestAlgorithmRaw Algorithm, TElX509CertificateHandle Signer, int8_t AddSigner, int8_t AddTimestamp, int8_t TrustedTimestamp, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_Clear(TElAuthenticodeSignerHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_CloseFile(TElAuthenticodeSignerHandle _Handle, int8_t Apply, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_OpenFile(TElAuthenticodeSignerHandle _Handle, const char * pcFileName, int32_t szFileName, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_OpenStream(TElAuthenticodeSignerHandle _Handle, TStreamHandle Stream, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_get_StatementType(TElAuthenticodeSignerHandle _Handle, TSBAuthenticodeStatementTypeRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_set_StatementType(TElAuthenticodeSignerHandle _Handle, TSBAuthenticodeStatementTypeRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_get_OnTimestampNeeded(TElAuthenticodeSignerHandle _Handle, TSBAuthenticodeTimestampNeeded * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_set_OnTimestampNeeded(TElAuthenticodeSignerHandle _Handle, TSBAuthenticodeTimestampNeeded pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeSigner_Create(TComponentHandle AOwner, TElAuthenticodeSignerHandle * OutResult);
#endif /* SB_USE_CLASS_TELAUTHENTICODESIGNER */

#ifdef SB_USE_CLASS_TELAUTHENTICODEVERIFIER
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_CloseFile(TElAuthenticodeVerifierHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_GetSignatureInfo(TElAuthenticodeVerifierHandle _Handle, int32_t Index, char * pcDescription, int32_t * szDescription, char * pcURL, int32_t * szURL, int64_t * TimeStamp, TElClientTSPInfoHandle * TrustedTimeStamp, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_OpenFile(TElAuthenticodeVerifierHandle _Handle, const char * pcFileName, int32_t szFileName, int8_t OpenReadOnly, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_OpenStream(TElAuthenticodeVerifierHandle _Handle, TStreamHandle Stream, int8_t OpenReadOnly, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_RemoveAuthenticode(TElAuthenticodeVerifierHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_VerifySignature(TElAuthenticodeVerifierHandle _Handle, int32_t Index, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_ActualChecksum(TElAuthenticodeVerifierHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_ActualDigest(TElAuthenticodeVerifierHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_Certificates(TElAuthenticodeVerifierHandle _Handle, TElCustomCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_Checksum(TElAuthenticodeVerifierHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_Digest(TElAuthenticodeVerifierHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_DigestAlgorithm(TElAuthenticodeVerifierHandle _Handle, TSBAuthenticodeDigestAlgorithmRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_SignatureCount(TElAuthenticodeVerifierHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_Signatures(TElAuthenticodeVerifierHandle _Handle, int32_t Index, TElPKCS7SignerHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_Timestamps(TElAuthenticodeVerifierHandle _Handle, int32_t Index, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_TrustedTimestamps(TElAuthenticodeVerifierHandle _Handle, int32_t Index, TElClientTSPInfoHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_get_CertStorage(TElAuthenticodeVerifierHandle _Handle, TElCustomCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_set_CertStorage(TElAuthenticodeVerifierHandle _Handle, TElCustomCertStorageHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElAuthenticodeVerifier_Create(TComponentHandle AOwner, TElAuthenticodeVerifierHandle * OutResult);
#endif /* SB_USE_CLASS_TELAUTHENTICODEVERIFIER */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TChecksumContext_ce_ptr;
extern zend_class_entry *TElAuthenticodeProcessor_ce_ptr;
extern zend_class_entry *TElAuthenticodeSigner_ce_ptr;
extern zend_class_entry *TElAuthenticodeVerifier_ce_ptr;

void Register_TChecksumContext(TSRMLS_D);
void SB_CALLBACK TSBAuthenticodeTimestampNeededRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pRequest[], int32_t szRequest, uint8_t pReply[], int32_t * szReply, int8_t * Succeeded);
void Register_TElAuthenticodeProcessor(TSRMLS_D);
void Register_TElAuthenticodeSigner(TSRMLS_D);
void Register_TElAuthenticodeVerifier(TSRMLS_D);
void Register_SBAuthenticode_Constants(int module_number TSRMLS_DC);
void Register_SBAuthenticode_Enum_Flags(TSRMLS_D);
void Register_SBAuthenticode_Aliases(TSRMLS_D);

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBAUTHENTICODE */

