#ifndef __INC_SBCRLSTORAGE
#define __INC_SBCRLSTORAGE

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbasn1.h"
#include "sbasn1tree.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbx509.h"
#include "sbpem.h"
#include "sbx509ext.h"
#include "sbrdn.h"
#include "sbsharedresource.h"
#include "sbcustomcrypto.h"
#include "sbpublickeycrypto.h"
#include "sbalgorithmidentifier.h"
#include "sbcrl.h"
#include "sbconstants.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
typedef TElClassHandle TElCustomCRLStorageHandle;

typedef TElCustomCRLStorageHandle ElCustomCRLStorageHandle;

typedef TElClassHandle TElCRLLookupHandle;

typedef TElCRLLookupHandle ElCRLLookupHandle;

typedef TElClassHandle TElMemoryCRLStorageHandle;

typedef TElMemoryCRLStorageHandle ElMemoryCRLStorageHandle;

typedef TElClassHandle TElCRLCacheStorageHandle;

typedef TElClassHandle TElCustomCRLRetrieverHandle;

typedef TElCustomCRLRetrieverHandle ElCustomCRLRetrieverHandle;

typedef TElClassHandle TElCustomCRLRetrieverFactoryHandle;

typedef TElClassHandle TElCRLManagerHandle;

typedef TElCRLManagerHandle ElCRLManagerHandle;

typedef uint8_t TSBCRLLookupCriterionRaw;

typedef enum
{
	clcIssuer = 0,
	clcDistributionPoint = 1,
	clcNumber = 2,
	clcReason = 3,
	clcAuthorityKeyIdentifier = 4,
	clcBaseCRLNumber = 5
} TSBCRLLookupCriterion;

typedef uint32_t TSBCRLLookupCriteriaRaw;

typedef enum 
{
	f_clcIssuer = 1,
	f_clcDistributionPoint = 2,
	f_clcNumber = 4,
	f_clcReason = 8,
	f_clcAuthorityKeyIdentifier = 16,
	f_clcBaseCRLNumber = 32
} TSBCRLLookupCriteria;

typedef uint8_t TSBCRLLookupOptionRaw;

typedef enum
{
	cloExactMatch = 0,
	cloMatchAll = 1
} TSBCRLLookupOption;

typedef uint32_t TSBCRLLookupOptionsRaw;

typedef enum 
{
	f_cloExactMatch = 1,
	f_cloMatchAll = 2
} TSBCRLLookupOptions;

#ifdef SB_USE_CLASS_TELCUSTOMCRLSTORAGE
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_BeginRead(TElCustomCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_EndRead(TElCustomCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_BeginWrite(TElCustomCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_EndWrite(TElCustomCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_Add(TElCustomCRLStorageHandle _Handle, TElCertificateRevocationListHandle CRL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_FindMatchingCRLs(TElCustomCRLStorageHandle _Handle, TElX509CertificateHandle Certificate, TElDistributionPointHandle DistributionPoint, TListHandle List);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_Remove(TElCustomCRLStorageHandle _Handle, int32_t Index);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_Clear(TElCustomCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_FindFirst(TElCustomCRLStorageHandle _Handle, TElCRLLookupHandle Lookup, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_FindNext(TElCustomCRLStorageHandle _Handle, TElCRLLookupHandle Lookup, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_ExportTo(TElCustomCRLStorageHandle _Handle, TElCustomCRLStorageHandle Storage);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_IndexOf(TElCustomCRLStorageHandle _Handle, TElCertificateRevocationListHandle Crl, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_get_CRLs(TElCustomCRLStorageHandle _Handle, int32_t Index, TElCertificateRevocationListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_get_Count(TElCustomCRLStorageHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLStorage_Create(TComponentHandle AOwner, TElCustomCRLStorageHandle * OutResult);
#endif /* SB_USE_CLASS_TELCUSTOMCRLSTORAGE */

#ifdef SB_USE_CLASS_TELCRLLOOKUP
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_IssuerRDN(TElCRLLookupHandle _Handle, TElRelativeDistinguishedNameHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_DistributionPoint(TElCRLLookupHandle _Handle, TElGeneralNameHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_Number(TElCRLLookupHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_Number(TElCRLLookupHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_Reasons(TElCRLLookupHandle _Handle, TSBCRLReasonFlagsRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_Reasons(TElCRLLookupHandle _Handle, TSBCRLReasonFlagsRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_AuthorityKeyIdentifier(TElCRLLookupHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_AuthorityKeyIdentifier(TElCRLLookupHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_BaseCRLNumber(TElCRLLookupHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_BaseCRLNumber(TElCRLLookupHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_Criteria(TElCRLLookupHandle _Handle, TSBCRLLookupCriteriaRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_Criteria(TElCRLLookupHandle _Handle, TSBCRLLookupCriteriaRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_get_Options(TElCRLLookupHandle _Handle, TSBCRLLookupOptionsRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_set_Options(TElCRLLookupHandle _Handle, TSBCRLLookupOptionsRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElCRLLookup_Create(TComponentHandle AOwner, TElCRLLookupHandle * OutResult);
#endif /* SB_USE_CLASS_TELCRLLOOKUP */

#ifdef SB_USE_CLASS_TELMEMORYCRLSTORAGE
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_BeginRead(TElMemoryCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_EndRead(TElMemoryCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_BeginWrite(TElMemoryCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_EndWrite(TElMemoryCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_Add(TElMemoryCRLStorageHandle _Handle, TElCertificateRevocationListHandle CRL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_Remove(TElMemoryCRLStorageHandle _Handle, int32_t Index);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_Clear(TElMemoryCRLStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_IndexOf(TElMemoryCRLStorageHandle _Handle, TElCertificateRevocationListHandle Crl, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElMemoryCRLStorage_Create(TComponentHandle AOwner, TElMemoryCRLStorageHandle * OutResult);
#endif /* SB_USE_CLASS_TELMEMORYCRLSTORAGE */

#ifdef SB_USE_CLASS_TELCRLCACHESTORAGE
SB_IMPORT uint32_t SB_APIENTRY TElCRLCacheStorage_Add(TElCRLCacheStorageHandle _Handle, TElCertificateRevocationListHandle CRL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLCacheStorage_get_Enabled(TElCRLCacheStorageHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLCacheStorage_set_Enabled(TElCRLCacheStorageHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElCRLCacheStorage_Create(TComponentHandle AOwner, TElMemoryCRLStorageHandle * OutResult);
#endif /* SB_USE_CLASS_TELCRLCACHESTORAGE */

#ifdef SB_USE_CLASS_TELCUSTOMCRLRETRIEVER
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetriever_Supports(TElCustomCRLRetrieverHandle _Handle, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetriever_GetCRL(TElCustomCRLRetrieverHandle _Handle, TElX509CertificateHandle ACertificate, TElX509CertificateHandle CACertificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCertificateRevocationListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetriever_Create(TComponentHandle AOwner, TComponentHandle * OutResult);
#endif /* SB_USE_CLASS_TELCUSTOMCRLRETRIEVER */

#ifdef SB_USE_CLASS_TELCUSTOMCRLRETRIEVERFACTORY
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetrieverFactory_Supports(TElCustomCRLRetrieverFactoryHandle _Handle, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetrieverFactory_GetRetrieverInstance(TElCustomCRLRetrieverFactoryHandle _Handle, TObjectHandle Validator, TElCustomCRLRetrieverHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomCRLRetrieverFactory_Create(TObjectHandle * OutResult);
#endif /* SB_USE_CLASS_TELCUSTOMCRLRETRIEVERFACTORY */

#ifdef SB_USE_CLASS_TELCRLMANAGER
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_PurgeExpiredCRLs(TElCRLManagerHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_RegisterCRLRetrieverFactory(TElCRLManagerHandle _Handle, TElCustomCRLRetrieverFactoryHandle Factory);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_UnregisterCRLRetrieverFactory(TElCRLManagerHandle _Handle, TElCustomCRLRetrieverFactoryHandle Factory);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_FindCRLRetriever(TElCRLManagerHandle _Handle, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TObjectHandle Validator, TElCustomCRLRetrieverHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_get_CRLCache(TElCRLManagerHandle _Handle, TElCRLCacheStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_get_UseCache(TElCRLManagerHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_set_UseCache(TElCRLManagerHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElCRLManager_Create(TElCRLManagerHandle * OutResult);
#endif /* SB_USE_CLASS_TELCRLMANAGER */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElCustomCRLStorage_ce_ptr;
extern zend_class_entry *TElCRLLookup_ce_ptr;
extern zend_class_entry *TElMemoryCRLStorage_ce_ptr;
extern zend_class_entry *TElCRLCacheStorage_ce_ptr;
extern zend_class_entry *TElCustomCRLRetriever_ce_ptr;
extern zend_class_entry *TElCustomCRLRetrieverFactory_ce_ptr;
extern zend_class_entry *TElCRLManager_ce_ptr;

void Register_TElCustomCRLStorage(TSRMLS_D);
void Register_TElCRLLookup(TSRMLS_D);
void Register_TElMemoryCRLStorage(TSRMLS_D);
void Register_TElCRLCacheStorage(TSRMLS_D);
void Register_TElCustomCRLRetriever(TSRMLS_D);
void Register_TElCustomCRLRetrieverFactory(TSRMLS_D);
void Register_TElCRLManager(TSRMLS_D);
SB_PHP_FUNCTION(SBCRLStorage, CRLManagerAddRef);
SB_PHP_FUNCTION(SBCRLStorage, CRLManagerRelease);
void Register_SBCRLStorage_Enum_Flags(TSRMLS_D);
void Register_SBCRLStorage_Aliases(TSRMLS_D);

#ifdef __cplusplus
extern "C" {
#endif

#ifdef SB_USE_GLOBAL_PROCS_CRLSTORAGE
SB_IMPORT uint32_t SB_APIENTRY SBCRLStorage_CRLManagerAddRef(TElCRLManagerHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY SBCRLStorage_CRLManagerRelease(void);
#endif /* SB_USE_GLOBAL_PROCS_CRLSTORAGE */

#ifdef __cplusplus
};	/* extern "C" */
#endif

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBCRLSTORAGE */

