#ifndef __INC_SBHTTPSCLIENT
#define __INC_SBHTTPSCLIENT

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbstringlist.h"
#include "sbsslcommon.h"
#include "sbsimplessl.h"
#include "sbcustomcertstorage.h"
#include "sbcookiemgr.h"
#include "sbdictionary.h"
#include "sbhttpsconstants.h"
#include "sbsslconstants.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbstrutils.h"
#include "sbconstants.h"
#include "sbencoding.h"
#include "sbstreams.h"
#include "sbhttpscommon.h"
#include "sbwebsocketcommon.h"
#include "sbwebsocketclient.h"
#include "sbhttpauth.h"
#include "sbsocket.h"
#include "sboauth2.h"
#include "sbsslclient.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
#define SB_SCannotSend 	"Cannot perform \"send\" on socket."
#define SB_SSocketError 	"Socket error occured. Code is %d."
#define SB_SDNSError 	"DNS error occured. Code is %d."
#ifdef SB_WINDOWS
#define SB_SInvalidNTLMResponse 	"Cannot get valid NTLM response from server."
#endif
#define SB_SInvalidDigestResponse 	"Cannot get valid Digest response from server."
#define SB_SInvalidDate 	"Invalid date/time value"
#define SB_SConnectionLost 	"Connection lost"
#define SB_WEBSOCKET_SUCCESS 	101

typedef TElClassHandle TElHTTPRequestParamsHandle;

typedef TElHTTPRequestParamsHandle ElHTTPRequestParamsHandle;

typedef TElClassHandle TElHTTPSClientHandle;

typedef TElHTTPSClientHandle ElHTTPSClientHandle;

typedef TElClassHandle SBHTTPSClient_TElStringValueHandle;

typedef void (SB_CALLBACK *TSBHTTPDynamicDataNeededEvent)(void * _ObjectData, TObjectHandle Sender, const uint8_t pBuffer[], int32_t szBuffer, int32_t ToRead, int32_t * Read);

typedef void (SB_CALLBACK *TSBHTTPRedirectionEvent)(void * _ObjectData, TObjectHandle Sender, const char * pcOldURL, int32_t szOldURL, char * pcNewURL, int32_t * szNewURL, int8_t * AllowRedirection);

typedef void (SB_CALLBACK *TSBHTTPCookieEvent)(void * _ObjectData, TObjectHandle Sender, const char * pcCookieText, int32_t szCookieText);

#ifdef SB_WINDOWS
typedef void (SB_CALLBACK *TSBHTTPOAuth2BrowseEvent)(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TStringListHandle ResponseHeaders);
#else
typedef void (SB_CALLBACK *TSBHTTPOAuth2BrowseEvent)(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TElStringListHandle ResponseHeaders);
#endif

typedef void (SB_CALLBACK *TSBHTTPUnsupportedTransferEncoding)(void * _ObjectData, TObjectHandle Sender, const char * pcEncoding, int32_t szEncoding, TElHTTPEncodingProcessorHandle * Processor, int8_t * Success);

typedef uint8_t TSBHTTPClientConnStageRaw;

typedef enum
{
	csHandshake = 0,
	csRequest = 1,
	csResponse = 2
} TSBHTTPClientConnStage;

typedef uint8_t TSBHTTPKeepAlivePolicyRaw;

typedef enum
{
	kapStandardDefined = 0,
	kapPreferKeepAlive = 1,
	kapRelyOnServer = 2,
	kapKeepAlivesDisabled = 3
} TSBHTTPKeepAlivePolicy;

typedef void (SB_CALLBACK *TSecureClientMethod)(void * _ObjectData);

typedef void (SB_CALLBACK *TSBHTTPBeforeWebSocketClientUsedEvent)(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient, TElHTTPSClientHandle HTTPClient);

typedef void (SB_CALLBACK *SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEvent)(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient);

#ifdef SB_USE_CLASS_TELHTTPREQUESTPARAMS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPRequestParams_get_Cookie(TElHTTPRequestParamsHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPRequestParams_set_Cookie(TElHTTPRequestParamsHandle _Handle, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPRequestParams_Create(TElHTTPCustomRequestParamsHandle * OutResult);
#endif /* SB_USE_CLASS_TELHTTPREQUESTPARAMS */

#ifdef SB_USE_CLASS_TELHTTPSCLIENT
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_StartWS(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TElWebSocketClientHandle * WSClient, TElSocketHandle * Socket, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_CustomRequest(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const char * pcMethod, int32_t szMethod, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_CustomRequest_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const char * pcMethod, int32_t szMethod, TStreamHandle Content, int8_t CloseStream, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Get(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Head(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Options(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Delete(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Trace(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Post(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Post_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const char * pcContent, int32_t szContent, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Post_2(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const uint8_t pContent[], int32_t szContent, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Post_3(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TStreamHandle Content, int8_t CloseStream, int32_t * OutResult);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostWebForm(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TStringListHandle Fields, const char * pcFileField, int32_t szFileField, const char * pcFileName, int32_t szFileName, TStreamHandle FileStream, const char * pcContentType, int32_t szContentType, int8_t CloseStream, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostWebForm_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TStringListHandle Fields, const char * pcFileField, int32_t szFileField, const char * pcFileName, int32_t szFileName, TStreamHandle FileStream, const char * pcContentType, int32_t szContentType, int8_t CloseStream, const char * pcCharset, int32_t szCharset, int32_t * OutResult);
#else
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostWebForm(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TElStringListHandle Fields, const char * pcFileField, int32_t szFileField, const char * pcFileName, int32_t szFileName, TStreamHandle FileStream, const char * pcContentType, int32_t szContentType, int8_t CloseStream, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostWebForm_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TElStringListHandle Fields, const char * pcFileField, int32_t szFileField, const char * pcFileName, int32_t szFileName, TStreamHandle FileStream, const char * pcContentType, int32_t szContentType, int8_t CloseStream, const char * pcCharset, int32_t szCharset, int32_t * OutResult);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostMultipart(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TSBHTTPMultipartModeRaw MultipartMode, TElHTTPMultipartListHandle PartsList, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostMultipart_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TSBHTTPMultipartModeRaw MultipartMode, const char * pcRelatedStart, int32_t szRelatedStart, const char * pcRelatedStartInfo, int32_t szRelatedStartInfo, const char * pcRelatedType, int32_t szRelatedType, TElHTTPMultipartListHandle PartsList, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_PostMultipart_2(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TSBHTTPMultipartModeRaw MultipartMode, const char * pcRelatedStart, int32_t szRelatedStart, const char * pcRelatedStartInfo, int32_t szRelatedStartInfo, const char * pcRelatedType, int32_t szRelatedType, TElHTTPMultipartListHandle PartsList, const char * pcCharset, int32_t szCharset, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Put(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Put_1(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const char * pcContent, int32_t szContent, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Put_2(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const uint8_t pContent[], int32_t szContent, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Put_3(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, const uint8_t pContent[], int32_t szContent, int32_t StartIndex, int32_t Count, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Put_4(TElHTTPSClientHandle _Handle, const char * pcURL, int32_t szURL, TStreamHandle Content, int8_t CloseStream, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_CancelRequest(TElHTTPSClientHandle _Handle);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_GetHeaderByName(TElHTTPSClientHandle _Handle, TStringListHandle Headers, const char * pcHeader, int32_t szHeader, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_GetHeadersByName(TElHTTPSClientHandle _Handle, TStringListHandle Headers, const char * pcHeader, int32_t szHeader, TStringListHandle Res);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_SetHeaderByName(TElHTTPSClientHandle _Handle, TStringListHandle Headers, const char * pcHeader, int32_t szHeader, const char * pcValue, int32_t szValue);
#else
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_GetHeaderByName(TElHTTPSClientHandle _Handle, TElStringListHandle Headers, const char * pcHeader, int32_t szHeader, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_GetHeadersByName(TElHTTPSClientHandle _Handle, TElStringListHandle Headers, const char * pcHeader, int32_t szHeader, TElStringListHandle Res);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_SetHeaderByName(TElHTTPSClientHandle _Handle, TElStringListHandle Headers, const char * pcHeader, int32_t szHeader, const char * pcValue, int32_t szValue);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_SetRequestHeader(TElHTTPSClientHandle _Handle, const char * pcHeader, int32_t szHeader, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_ClearRequest(TElHTTPSClientHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_ClearResponse(TElHTTPSClientHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_ClearAuthCache(TElHTTPSClientHandle _Handle);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestHeaders(TElHTTPSClientHandle _Handle, TStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ResponseHeaders(TElHTTPSClientHandle _Handle, TStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestCookies(TElHTTPSClientHandle _Handle, TStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ResponseCookies(TElHTTPSClientHandle _Handle, TStringListHandle * OutResult);
#else
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestHeaders(TElHTTPSClientHandle _Handle, TElStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ResponseHeaders(TElHTTPSClientHandle _Handle, TElStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestCookies(TElHTTPSClientHandle _Handle, TElStringListHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ResponseCookies(TElHTTPSClientHandle _Handle, TElStringListHandle * OutResult);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ServerStatusCode(TElHTTPSClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ServerReasonPhrase(TElHTTPSClientHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ContentLength(TElHTTPSClientHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_Date(TElHTTPSClientHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OutputStream(TElHTTPSClientHandle _Handle, TStreamHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OutputStream(TElHTTPSClientHandle _Handle, TStreamHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_SSLEnabled(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_SSLEnabled(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestParameters(TElHTTPSClientHandle _Handle, TElHTTPRequestParamsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_RequestParameters(TElHTTPSClientHandle _Handle, TElHTTPRequestParamsHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestCompressionLevel(TElHTTPSClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_RequestCompressionLevel(TElHTTPSClientHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_RequestCompressionGZip(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_RequestCompressionGZip(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_KeepAlivePolicy(TElHTTPSClientHandle _Handle, TSBHTTPKeepAlivePolicyRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_KeepAlivePolicy(TElHTTPSClientHandle _Handle, TSBHTTPKeepAlivePolicyRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_MaxRedirections(TElHTTPSClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_MaxRedirections(TElHTTPSClientHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_SuppressRedirectionContent(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_SuppressRedirectionContent(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPVersion(TElHTTPSClientHandle _Handle, TSBHTTPVersionRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPVersion(TElHTTPSClientHandle _Handle, TSBHTTPVersionRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_UseNTLMAuth(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_UseNTLMAuth(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_UseDigestAuth(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_UseDigestAuth(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_PersistentAuthHeader(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_PersistentAuthHeader(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_ForceNTLMAuth(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_ForceNTLMAuth(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_SendBufferSize(TElHTTPSClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_SendBufferSize(TElHTTPSClientHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_UseCompression(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_UseCompression(TElHTTPSClientHandle _Handle, int8_t Value);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_UseIPv6(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_UseIPv6(TElHTTPSClientHandle _Handle, int8_t Value);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_CookieManager(TElHTTPSClientHandle _Handle, TElCookieManagerHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_CookieManager(TElHTTPSClientHandle _Handle, TElCookieManagerHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_Use100Continue(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_Use100Continue(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OAuth2(TElHTTPSClientHandle _Handle, TElOAuth2SettingsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OAuth2(TElHTTPSClientHandle _Handle, TElOAuth2SettingsHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_SAMLAdapter(TElHTTPSClientHandle _Handle, TElCustomSAMLAdapterHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_SAMLAdapter(TElHTTPSClientHandle _Handle, TElCustomSAMLAdapterHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyUsername(TElHTTPSClientHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPProxyUsername(TElHTTPSClientHandle _Handle, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyPassword(TElHTTPSClientHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPProxyPassword(TElHTTPSClientHandle _Handle, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyHost(TElHTTPSClientHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPProxyHost(TElHTTPSClientHandle _Handle, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyPort(TElHTTPSClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPProxyPort(TElHTTPSClientHandle _Handle, int32_t Value);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyRequestHeaders(TElHTTPSClientHandle _Handle, TStringListHandle * OutResult);
#else
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyRequestHeaders(TElHTTPSClientHandle _Handle, TElStringListHandle * OutResult);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_HTTPProxyAuthentication(TElHTTPSClientHandle _Handle, TElWebTunnelAuthenticationRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_HTTPProxyAuthentication(TElHTTPSClientHandle _Handle, TElWebTunnelAuthenticationRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_UseHTTPProxy(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_UseHTTPProxy(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_IgnoreUnknownTransferEncodings(TElHTTPSClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_IgnoreUnknownTransferEncodings(TElHTTPSClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnBeforeWebSocketClientUsed(TElHTTPSClientHandle _Handle, TSBHTTPBeforeWebSocketClientUsedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnBeforeWebSocketClientUsed(TElHTTPSClientHandle _Handle, TSBHTTPBeforeWebSocketClientUsedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnWebSocketConnectionEstablished(TElHTTPSClientHandle _Handle, SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnWebSocketConnectionEstablished(TElHTTPSClientHandle _Handle, SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCookie(TElHTTPSClientHandle _Handle, TSBHTTPCookieEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCookie(TElHTTPSClientHandle _Handle, TSBHTTPCookieEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnData(TElHTTPSClientHandle _Handle, TSBDataEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnData(TElHTTPSClientHandle _Handle, TSBDataEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnDocumentBegin(TElHTTPSClientHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnDocumentBegin(TElHTTPSClientHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnDocumentEnd(TElHTTPSClientHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnDocumentEnd(TElHTTPSClientHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnReceivingHeaders(TElHTTPSClientHandle _Handle, TSBHTTPHeadersEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnReceivingHeaders(TElHTTPSClientHandle _Handle, TSBHTTPHeadersEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnPreparedHeaders(TElHTTPSClientHandle _Handle, TSBHTTPHeadersEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnPreparedHeaders(TElHTTPSClientHandle _Handle, TSBHTTPHeadersEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnProgress(TElHTTPSClientHandle _Handle, TSBProgressEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnProgress(TElHTTPSClientHandle _Handle, TSBProgressEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnRedirection(TElHTTPSClientHandle _Handle, TSBHTTPRedirectionEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnRedirection(TElHTTPSClientHandle _Handle, TSBHTTPRedirectionEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnSendData(TElHTTPSClientHandle _Handle, TSBDataEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnSendData(TElHTTPSClientHandle _Handle, TSBDataEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnDynamicDataNeeded(TElHTTPSClientHandle _Handle, TSBHTTPDynamicDataNeededEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnDynamicDataNeeded(TElHTTPSClientHandle _Handle, TSBHTTPDynamicDataNeededEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnOAuth2Browse(TElHTTPSClientHandle _Handle, TSBHTTPOAuth2BrowseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnOAuth2Browse(TElHTTPSClientHandle _Handle, TSBHTTPOAuth2BrowseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnUnsupportedTransferEncoding(TElHTTPSClientHandle _Handle, TSBHTTPUnsupportedTransferEncoding * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnUnsupportedTransferEncoding(TElHTTPSClientHandle _Handle, TSBHTTPUnsupportedTransferEncoding pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCertificateChoose(TElHTTPSClientHandle _Handle, TSBChooseCertificateEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCertificateChoose(TElHTTPSClientHandle _Handle, TSBChooseCertificateEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCertificateNeededEx(TElHTTPSClientHandle _Handle, TSBCertificateNeededExEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCertificateNeededEx(TElHTTPSClientHandle _Handle, TSBCertificateNeededExEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCertificateValidate(TElHTTPSClientHandle _Handle, TSBCertificateValidateEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCertificateValidate(TElHTTPSClientHandle _Handle, TSBCertificateValidateEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCiphersNegotiated(TElHTTPSClientHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCiphersNegotiated(TElHTTPSClientHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCloseConnection(TElHTTPSClientHandle _Handle, TSBCloseConnectionEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCloseConnection(TElHTTPSClientHandle _Handle, TSBCloseConnectionEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnError(TElHTTPSClientHandle _Handle, TSBErrorEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnError(TElHTTPSClientHandle _Handle, TSBErrorEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnExtensionsReceived(TElHTTPSClientHandle _Handle, TSBExtensionsReceivedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnExtensionsReceived(TElHTTPSClientHandle _Handle, TSBExtensionsReceivedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnExtensionsPrepared(TElHTTPSClientHandle _Handle, TSBExtensionsPreparedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnExtensionsPrepared(TElHTTPSClientHandle _Handle, TSBExtensionsPreparedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnCertificateStatus(TElHTTPSClientHandle _Handle, TSBCertificateStatusEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnCertificateStatus(TElHTTPSClientHandle _Handle, TSBCertificateStatusEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnKeyNeeded(TElHTTPSClientHandle _Handle, TSBClientKeyNeededEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnKeyNeeded(TElHTTPSClientHandle _Handle, TSBClientKeyNeededEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_get_OnRenegotiationRequest(TElHTTPSClientHandle _Handle, TSBRenegotiationRequestEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_set_OnRenegotiationRequest(TElHTTPSClientHandle _Handle, TSBRenegotiationRequestEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElHTTPSClient_Create(TComponentHandle AOwner, TElHTTPSClientHandle * OutResult);
#endif /* SB_USE_CLASS_TELHTTPSCLIENT */

#ifdef SB_USE_CLASS_SBHTTPSCLIENT_TELSTRINGVALUE
SB_IMPORT uint32_t SB_APIENTRY SBHTTPSClient_TElStringValue_get_Value(SBHTTPSClient_TElStringValueHandle _Handle, char * pcOutResult, int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY SBHTTPSClient_TElStringValue_set_Value(SBHTTPSClient_TElStringValueHandle _Handle, const char * pcValue, int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY SBHTTPSClient_TElStringValue_Create(const char * pcValue, int32_t szValue, SBHTTPSClient_TElStringValueHandle * OutResult);
#endif /* SB_USE_CLASS_SBHTTPSCLIENT_TELSTRINGVALUE */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElHTTPRequestParams_ce_ptr;
extern zend_class_entry *TElHTTPSClient_ce_ptr;
extern zend_class_entry *SBHTTPSClient_TElStringValue_ce_ptr;

void SB_CALLBACK TSBHTTPDynamicDataNeededEventRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pBuffer[], int32_t szBuffer, int32_t ToRead, int32_t * Read);
void SB_CALLBACK TSBHTTPRedirectionEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcOldURL, int32_t szOldURL, char * pcNewURL, int32_t * szNewURL, int8_t * AllowRedirection);
void SB_CALLBACK TSBHTTPCookieEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcCookieText, int32_t szCookieText);
#ifdef SB_WINDOWS
void SB_CALLBACK TSBHTTPOAuth2BrowseEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TStringListHandle ResponseHeaders);
#else
void SB_CALLBACK TSBHTTPOAuth2BrowseEventRaw(void * _ObjectData, TObjectHandle Sender, const char * pcURL, int32_t szURL, TElStringListHandle ResponseHeaders);
#endif
void SB_CALLBACK TSBHTTPUnsupportedTransferEncodingRaw(void * _ObjectData, TObjectHandle Sender, const char * pcEncoding, int32_t szEncoding, TElHTTPEncodingProcessorHandle * Processor, int8_t * Success);
void SB_CALLBACK TSecureClientMethodRaw(void * _ObjectData);
void SB_CALLBACK TSBHTTPBeforeWebSocketClientUsedEventRaw(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient, TElHTTPSClientHandle HTTPClient);
void SB_CALLBACK SBHTTPSClient_TSBHTTPWebSocketConnectionEstablishedEventRaw(void * _ObjectData, TObjectHandle Sender, TElWebSocketClientHandle WSClient);
void Register_TElHTTPRequestParams(TSRMLS_D);
void Register_TElHTTPSClient(TSRMLS_D);
void Register_SBHTTPSClient_TElStringValue(TSRMLS_D);
void Register_SBHTTPSClient_Constants(int module_number TSRMLS_DC);
void Register_SBHTTPSClient_Enum_Flags(TSRMLS_D);
void Register_SBHTTPSClient_Aliases(TSRMLS_D);

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBHTTPSCLIENT */
