#ifndef __INC_SBZIPENTITIES
#define __INC_SBZIPENTITIES

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbconstants.h"
#include "sbstreams.h"
#include "sbarcbase.h"
#include "sbziputils.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
#define SB_ZIP_READ_BLOCK_SIZE 	65536
#define SB_ZIP64_MARK_32 	4294967295
#define SB_ZIP64_MARK_16 	65535

typedef TElClassHandle TElZipEntityHandle;

typedef TElClassHandle TElZipLocalFileHeaderHandle;

typedef TElClassHandle TElZipCentralFileHeaderHandle;

typedef TElClassHandle TElZipDataDescriptorHandle;

typedef TElClassHandle TElZipEntityExtensionsHandle;

typedef TElClassHandle TElZipCentralDirectorySignatureHandle;

typedef TElClassHandle TElZip64EndOfCentralDirectoryHandle;

typedef TElClassHandle TElZip64EndOfCentralDirectoryLocatorHandle;

typedef TElClassHandle TElZipEndOfCentralDirectoryHandle;

typedef TElClassHandle TElZipArchiveExtraDataHandle;

typedef TElClassHandle TElZipProcessorHandle;

typedef TElClassHandle TElZipEntityExtensionHandle;

typedef TElClassHandle TElZipEntityCustomExtensionHandle;

typedef TElClassHandle TElZipEntityZip64InfoExtensionHandle;

typedef TElClassHandle TElZipEntityStrongEncryptionExtensionHandle;

typedef TElClassHandle TElZipEntityWinZipAESExtensionHandle;

typedef TElClassHandle TElZipEntityCertificateStoreExtensionHandle;

typedef TElClassHandle TElZipEntitySignatureExtensionHandle;

typedef TElClassHandle TElZipEntityCentralDirSignatureExtensionHandle;

typedef TElClassHandle TElZipEntityUnix1ExtensionHandle;

typedef TElClassHandle TElZipEntityUnix2ExtensionHandle;

typedef TElClassHandle TElZipEntityExtendedTimestampExtensionHandle;

typedef TElClassHandle TElZipEntityUIDAndGIDExtensionHandle;

typedef void (SB_CALLBACK *TSBZipReadEvent)(void * _ObjectData, TObjectHandle Sender, void * UserData, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t NeededSize, int32_t * Written, int8_t * Last);

typedef void (SB_CALLBACK *TSBZipWriteEvent)(void * _ObjectData, TObjectHandle Sender, void * UserData, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);

typedef void (SB_CALLBACK *TSBZipLocalFileHeaderLoadedEvent)(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);

typedef void (SB_CALLBACK *TSBZipDataDescriptorLoadedEvent)(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);

typedef void (SB_CALLBACK *TSBZipCentralFileHeaderLoadedEvent)(void * _ObjectData, TObjectHandle Sender, TElZipCentralFileHeaderHandle Header);

typedef void (SB_CALLBACK *TSBZipFileDataEvent)(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);

typedef void (SB_CALLBACK *TSBZipCentralDirectoryProcessEvent)(void * _ObjectData, TObjectHandle Sender, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size, uint8_t pProcessedData[], int32_t * szProcessedData, int32_t ProcessedIndex, int32_t * ProcessedSize);

typedef void (SB_CALLBACK *TSBZipArchiveErrorEvent)(void * _ObjectData, TObjectHandle Sender, int32_t ErrorCode, const char * pcErrorMessage, int32_t szErrorMessage, int8_t * TryContinue);

#ifdef SB_USE_CLASS_TELZIPENTITY
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_Assign(TElZipEntityHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_AssignTo(TElZipEntityHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_Load(TElZipEntityHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_Save(TElZipEntityHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_SaveToStream(TElZipEntityHandle _Handle, TStreamHandle Stream, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_SaveToBuffer(TElZipEntityHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_DataAvailable(TElZipEntityHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_BodySize(TElZipEntityHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_Body(TElZipEntityHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_Loaded(TElZipEntityHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_Signature(TElZipEntityHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_Signature(TElZipEntityHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_SkipSignature(TElZipEntityHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_SkipSignature(TElZipEntityHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_Zip64Used(TElZipEntityHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_Zip64Used(TElZipEntityHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_Position(TElZipEntityHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_Position(TElZipEntityHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_OnRead(TElZipEntityHandle _Handle, TSBZipReadEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_OnRead(TElZipEntityHandle _Handle, TSBZipReadEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_get_OnWrite(TElZipEntityHandle _Handle, TSBZipWriteEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_set_OnWrite(TElZipEntityHandle _Handle, TSBZipWriteEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntity_Create(TElZipEntityHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITY */

#ifdef SB_USE_CLASS_TELZIPLOCALFILEHEADER
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_Assign(TElZipLocalFileHeaderHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_AssignTo(TElZipLocalFileHeaderHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_Load(TElZipLocalFileHeaderHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_Save(TElZipLocalFileHeaderHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_DataAvailable(TElZipLocalFileHeaderHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_VersionToExtract(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_VersionToExtract(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_GeneralBitFlag(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_GeneralBitFlag(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_DataDescriptor(TElZipLocalFileHeaderHandle _Handle, TElZipDataDescriptorHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_DataDescriptor(TElZipLocalFileHeaderHandle _Handle, TElZipDataDescriptorHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_CompressionMethod(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_CompressionMethod(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_LastModFileTime(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_LastModFileTime(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_LastModFileDate(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_LastModFileDate(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_CRC32(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_CRC32(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_CompressedSize(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_CompressedSize(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_OriginalSize(TElZipLocalFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_OriginalSize(TElZipLocalFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_FileName(TElZipLocalFileHeaderHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_FileName(TElZipLocalFileHeaderHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_ExtraField(TElZipLocalFileHeaderHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_ExtraField(TElZipLocalFileHeaderHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_DataOffset(TElZipLocalFileHeaderHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_DataOffset(TElZipLocalFileHeaderHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_Extensions(TElZipLocalFileHeaderHandle _Handle, TElZipEntityExtensionsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_get_DataDescriptorUsed(TElZipLocalFileHeaderHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_set_DataDescriptorUsed(TElZipLocalFileHeaderHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipLocalFileHeader_Create(TElZipLocalFileHeaderHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPLOCALFILEHEADER */

#ifdef SB_USE_CLASS_TELZIPCENTRALFILEHEADER
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_Assign(TElZipCentralFileHeaderHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_AssignTo(TElZipCentralFileHeaderHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_Load(TElZipCentralFileHeaderHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_Save(TElZipCentralFileHeaderHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_DataAvailable(TElZipCentralFileHeaderHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_VersionMadeBy(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_VersionMadeBy(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_VersionToExtract(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_VersionToExtract(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_GeneralBitFlag(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_GeneralBitFlag(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_CompressionMethod(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_CompressionMethod(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_LastModFileTime(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_LastModFileTime(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_LastModFileDate(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_LastModFileDate(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_CRC32(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_CRC32(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_CompressedSize(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_CompressedSize(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_OriginalSize(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_OriginalSize(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_DiskNumberStart(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_DiskNumberStart(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_InternalFileAttributes(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_InternalFileAttributes(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_ExternalFileAttributes(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_ExternalFileAttributes(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_LocalHeaderOffset(TElZipCentralFileHeaderHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_LocalHeaderOffset(TElZipCentralFileHeaderHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_FileName(TElZipCentralFileHeaderHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_FileName(TElZipCentralFileHeaderHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_ExtraField(TElZipCentralFileHeaderHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_ExtraField(TElZipCentralFileHeaderHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_Comment(TElZipCentralFileHeaderHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_set_Comment(TElZipCentralFileHeaderHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_get_Extensions(TElZipCentralFileHeaderHandle _Handle, TElZipEntityExtensionsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralFileHeader_Create(TElZipCentralFileHeaderHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPCENTRALFILEHEADER */

#ifdef SB_USE_CLASS_TELZIPDATADESCRIPTOR
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_Assign(TElZipDataDescriptorHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_AssignTo(TElZipDataDescriptorHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_Load(TElZipDataDescriptorHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_Save(TElZipDataDescriptorHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_DataAvailable(TElZipDataDescriptorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_get_CRC32(TElZipDataDescriptorHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_set_CRC32(TElZipDataDescriptorHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_get_CompressedSize(TElZipDataDescriptorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_set_CompressedSize(TElZipDataDescriptorHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_get_OriginalSize(TElZipDataDescriptorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_set_OriginalSize(TElZipDataDescriptorHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_get_WriteSignature(TElZipDataDescriptorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_set_WriteSignature(TElZipDataDescriptorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipDataDescriptor_Create(TElZipDataDescriptorHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPDATADESCRIPTOR */

#ifdef SB_USE_CLASS_TELZIPENTITYEXTENSIONS
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_Assign(TElZipEntityExtensionsHandle _Handle, TElZipEntityExtensionsHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_AssignTo(TElZipEntityExtensionsHandle _Handle, TElZipEntityExtensionsHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_LoadFromBuffer(TElZipEntityExtensionsHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_SaveToBuffer(TElZipEntityExtensionsHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_Save(TElZipEntityExtensionsHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_AddExtension(TElZipEntityExtensionsHandle _Handle, uint32_t ExtensionType, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_ExtensionByType(TElZipEntityExtensionsHandle _Handle, uint32_t ExtensionType, int32_t Index, TElZipEntityExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_RemoveExtension(TElZipEntityExtensionsHandle _Handle, int32_t Index);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_RemoveExtensionByType(TElZipEntityExtensionsHandle _Handle, uint32_t ExtensionType, int32_t Index);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_ClearExtensions(TElZipEntityExtensionsHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Size32Bit(TElZipEntityExtensionsHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_set_Size32Bit(TElZipEntityExtensionsHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Owner(TElZipEntityExtensionsHandle _Handle, TElZipEntityHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_set_Owner(TElZipEntityExtensionsHandle _Handle, TElZipEntityHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_ExtensionCount(TElZipEntityExtensionsHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Extensions(TElZipEntityExtensionsHandle _Handle, int32_t Index, TElZipEntityExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_BodySize(TElZipEntityExtensionsHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Zip64Info(TElZipEntityExtensionsHandle _Handle, TElZipEntityZip64InfoExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_StrongEncryptionHeader(TElZipEntityExtensionsHandle _Handle, TElZipEntityStrongEncryptionExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_WinZipAesInfo(TElZipEntityExtensionsHandle _Handle, TElZipEntityWinZipAESExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_CertificateStore(TElZipEntityExtensionsHandle _Handle, TElZipEntityCertificateStoreExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_CentralDirectorySignature(TElZipEntityExtensionsHandle _Handle, TElZipEntityCentralDirSignatureExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_ExtendedTimestamp(TElZipEntityExtensionsHandle _Handle, TElZipEntityExtendedTimestampExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_UIDAndGID(TElZipEntityExtensionsHandle _Handle, TElZipEntityUIDAndGIDExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Unix1(TElZipEntityExtensionsHandle _Handle, TElZipEntityUnix1ExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Unix2(TElZipEntityExtensionsHandle _Handle, TElZipEntityUnix2ExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_SignatureCount(TElZipEntityExtensionsHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_get_Signatures(TElZipEntityExtensionsHandle _Handle, int32_t Index, TElZipEntitySignatureExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtensions_Create(TElZipEntityExtensionsHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYEXTENSIONS */

#ifdef SB_USE_CLASS_TELZIPCENTRALDIRECTORYSIGNATURE
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_Assign(TElZipCentralDirectorySignatureHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_AssignTo(TElZipCentralDirectorySignatureHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_Load(TElZipCentralDirectorySignatureHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_Save(TElZipCentralDirectorySignatureHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_DataAvailable(TElZipCentralDirectorySignatureHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_get_Version(TElZipCentralDirectorySignatureHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_get_HashAlgorithm(TElZipCentralDirectorySignatureHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_set_HashAlgorithm(TElZipCentralDirectorySignatureHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_get_IssuerName(TElZipCentralDirectorySignatureHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_set_IssuerName(TElZipCentralDirectorySignatureHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_get_SerialNumber(TElZipCentralDirectorySignatureHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_set_SerialNumber(TElZipCentralDirectorySignatureHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_get_CentralSignature(TElZipCentralDirectorySignatureHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_set_CentralSignature(TElZipCentralDirectorySignatureHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipCentralDirectorySignature_Create(TElZipCentralDirectorySignatureHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPCENTRALDIRECTORYSIGNATURE */

#ifdef SB_USE_CLASS_TELZIP64ENDOFCENTRALDIRECTORY
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_Assign(TElZip64EndOfCentralDirectoryHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_AssignTo(TElZip64EndOfCentralDirectoryHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_Load(TElZip64EndOfCentralDirectoryHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_Save(TElZip64EndOfCentralDirectoryHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_DataAvailable(TElZip64EndOfCentralDirectoryHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_StructureVersion(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_StructureVersion(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_VersionMadeBy(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_VersionMadeBy(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_VersionToExtract(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_VersionToExtract(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_DiskNumber(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_DiskNumber(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_CentralDirStartDisk(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_CentralDirStartDisk(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_EntriesOnDiskCount(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_EntriesOnDiskCount(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_EntriesCount(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_EntriesCount(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_CentralDirSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_CentralDirSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_CentralDirOffset(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_CentralDirOffset(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_ExtensibleData(TElZip64EndOfCentralDirectoryHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_ExtensibleData(TElZip64EndOfCentralDirectoryHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_CompressionMethod(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_CompressionMethod(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_CompressedSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_CompressedSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_OriginalSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_OriginalSize(TElZip64EndOfCentralDirectoryHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_EncryptionAlgorithm(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_EncryptionAlgorithm(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_KeyLength(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_KeyLength(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_EncryptionFlags(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_EncryptionFlags(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_HashAlgortihm(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_HashAlgortihm(TElZip64EndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_get_Hash(TElZip64EndOfCentralDirectoryHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_set_Hash(TElZip64EndOfCentralDirectoryHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectory_Create(TElZip64EndOfCentralDirectoryHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIP64ENDOFCENTRALDIRECTORY */

#ifdef SB_USE_CLASS_TELZIP64ENDOFCENTRALDIRECTORYLOCATOR
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_Assign(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_AssignTo(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_Load(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_Save(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_DataAvailable(TElZip64EndOfCentralDirectoryLocatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_get_DiskNumber(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_set_DiskNumber(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_get_Offset(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_set_Offset(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_get_TotalDiskCount(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_set_TotalDiskCount(TElZip64EndOfCentralDirectoryLocatorHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZip64EndOfCentralDirectoryLocator_Create(TElZip64EndOfCentralDirectoryLocatorHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIP64ENDOFCENTRALDIRECTORYLOCATOR */

#ifdef SB_USE_CLASS_TELZIPENDOFCENTRALDIRECTORY
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_Assign(TElZipEndOfCentralDirectoryHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_AssignTo(TElZipEndOfCentralDirectoryHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_Load(TElZipEndOfCentralDirectoryHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_Save(TElZipEndOfCentralDirectoryHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_DataAvailable(TElZipEndOfCentralDirectoryHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_DiskNumber(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_DiskNumber(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_CentralDirStartDisk(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_CentralDirStartDisk(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_EntriesOnDiskCount(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_EntriesOnDiskCount(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_EntriesCount(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_EntriesCount(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_CentralDirSize(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_CentralDirSize(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_CentralDirOffset(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_CentralDirOffset(TElZipEndOfCentralDirectoryHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_get_Comment(TElZipEndOfCentralDirectoryHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_set_Comment(TElZipEndOfCentralDirectoryHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEndOfCentralDirectory_Create(TElZipEndOfCentralDirectoryHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENDOFCENTRALDIRECTORY */

#ifdef SB_USE_CLASS_TELZIPARCHIVEEXTRADATA
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_Assign(TElZipArchiveExtraDataHandle _Handle, TElZipEntityHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_AssignTo(TElZipArchiveExtraDataHandle _Handle, TElZipEntityHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_Load(TElZipArchiveExtraDataHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_Save(TElZipArchiveExtraDataHandle _Handle, void * UserData);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_DataAvailable(TElZipArchiveExtraDataHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_get_Extensions(TElZipArchiveExtraDataHandle _Handle, TElZipEntityExtensionsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipArchiveExtraData_Create(TElZipArchiveExtraDataHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPARCHIVEEXTRADATA */

#ifdef SB_USE_CLASS_TELZIPPROCESSOR
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_Process(TElZipProcessorHandle _Handle, TStreamHandle Stream);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_ProcessLocalHeader(TElZipProcessorHandle _Handle, TStreamHandle Stream, TElZipLocalFileHeaderHandle * Header, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_DataAvailable(TElZipProcessorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_Processed(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_EndOfData(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectoryCompressed(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectoryEncrypted(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_UseCentralDirectory(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_UseCentralDirectory(TElZipProcessorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnePass(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnePass(TElZipProcessorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_Zip64Format(TElZipProcessorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_EndOfCentralDir(TElZipProcessorHandle _Handle, TElZipEndOfCentralDirectoryHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_Zip64EndOfCentralDir(TElZipProcessorHandle _Handle, TElZip64EndOfCentralDirectoryHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectorySignature(TElZipProcessorHandle _Handle, TElZipCentralDirectorySignatureHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectoryEntriesCount(TElZipProcessorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectorySize(TElZipProcessorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_CentralDirectoryPosition(TElZipProcessorHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_ArchiveExtraData(TElZipProcessorHandle _Handle, TElZipArchiveExtraDataHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnLocalFileHeaderLoaded(TElZipProcessorHandle _Handle, TSBZipLocalFileHeaderLoadedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnLocalFileHeaderLoaded(TElZipProcessorHandle _Handle, TSBZipLocalFileHeaderLoadedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnDataDescriptorLoaded(TElZipProcessorHandle _Handle, TSBZipDataDescriptorLoadedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnDataDescriptorLoaded(TElZipProcessorHandle _Handle, TSBZipDataDescriptorLoadedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnCentralFileHeaderLoaded(TElZipProcessorHandle _Handle, TSBZipCentralFileHeaderLoadedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnCentralFileHeaderLoaded(TElZipProcessorHandle _Handle, TSBZipCentralFileHeaderLoadedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnFileData(TElZipProcessorHandle _Handle, TSBZipFileDataEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnFileData(TElZipProcessorHandle _Handle, TSBZipFileDataEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnFileHeadersLoaded(TElZipProcessorHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnFileHeadersLoaded(TElZipProcessorHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnCentralDirectoryFound(TElZipProcessorHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnCentralDirectoryFound(TElZipProcessorHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnProcessCentralDirectory(TElZipProcessorHandle _Handle, TSBZipCentralDirectoryProcessEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnProcessCentralDirectory(TElZipProcessorHandle _Handle, TSBZipCentralDirectoryProcessEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnCentralDirectoryProcessed(TElZipProcessorHandle _Handle, TNotifyEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnCentralDirectoryProcessed(TElZipProcessorHandle _Handle, TNotifyEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_get_OnArchiveError(TElZipProcessorHandle _Handle, TSBZipArchiveErrorEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_set_OnArchiveError(TElZipProcessorHandle _Handle, TSBZipArchiveErrorEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipProcessor_Create(TElZipProcessorHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPPROCESSOR */

#ifdef SB_USE_CLASS_TELZIPENTITYEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_CreateByType(uint32_t ExtensionType, TElZipEntityExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_CreateByType_1(TElZipEntityExtensionHandle _Handle, uint32_t ExtensionType, TElZipEntityExtensionHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_Assign(TElZipEntityExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_AssignTo(TElZipEntityExtensionHandle _Handle, TElZipEntityExtensionHandle Dest);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_LoadFromBuffer(TElZipEntityExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_SaveToBuffer(TElZipEntityExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_get_BodySize(TElZipEntityExtensionHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_get_ExtensionType(TElZipEntityExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_set_ExtensionType(TElZipEntityExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_get_Owner(TElZipEntityExtensionHandle _Handle, TElZipEntityExtensionsHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_set_Owner(TElZipEntityExtensionHandle _Handle, TElZipEntityExtensionsHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtension_Create(TElZipEntityExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYCUSTOMEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_Assign(TElZipEntityCustomExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_LoadFromBuffer(TElZipEntityCustomExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_SaveToBuffer(TElZipEntityCustomExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_get_ExtensionData(TElZipEntityCustomExtensionHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_set_ExtensionData(TElZipEntityCustomExtensionHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCustomExtension_Create(TElZipEntityCustomExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYCUSTOMEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYZIP64INFOEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_Assign(TElZipEntityZip64InfoExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_LoadFromBuffer(TElZipEntityZip64InfoExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_SaveToBuffer(TElZipEntityZip64InfoExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_OriginalSize(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_set_OriginalSize(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_OriginalSizeAvailable(TElZipEntityZip64InfoExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_CompressedSize(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_set_CompressedSize(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_CompressedSizeAvailable(TElZipEntityZip64InfoExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_RelativeHeaderOffset(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_set_RelativeHeaderOffset(TElZipEntityZip64InfoExtensionHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_RelativeHeaderOffsetAvailable(TElZipEntityZip64InfoExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_DiskStart(TElZipEntityZip64InfoExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_set_DiskStart(TElZipEntityZip64InfoExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_get_DiskStartAvailable(TElZipEntityZip64InfoExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityZip64InfoExtension_Create(TElZipEntityZip64InfoExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYZIP64INFOEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYSTRONGENCRYPTIONEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_Assign(TElZipEntityStrongEncryptionExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_LoadFromBuffer(TElZipEntityStrongEncryptionExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_SaveToBuffer(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_Format(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_Format(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_AlgorithmID(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_AlgorithmID(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_KeyLength(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_KeyLength(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_Flags(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_Flags(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_RecipientCount(TElZipEntityStrongEncryptionExtensionHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_RecipientCount(TElZipEntityStrongEncryptionExtensionHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_HashAlgorithmID(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_HashAlgorithmID(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_HashSize(TElZipEntityStrongEncryptionExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_get_RecipientHashes(TElZipEntityStrongEncryptionExtensionHandle _Handle, int32_t Index, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_set_RecipientHashes(TElZipEntityStrongEncryptionExtensionHandle _Handle, int32_t Index, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityStrongEncryptionExtension_Create(TElZipEntityStrongEncryptionExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYSTRONGENCRYPTIONEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYWINZIPAESEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_Assign(TElZipEntityWinZipAESExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_LoadFromBuffer(TElZipEntityWinZipAESExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_SaveToBuffer(TElZipEntityWinZipAESExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_get_Version(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_set_Version(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_get_Vendor(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_set_Vendor(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_get_KeyStrength(TElZipEntityWinZipAESExtensionHandle _Handle, uint8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_set_KeyStrength(TElZipEntityWinZipAESExtensionHandle _Handle, uint8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_get_ActualCompressionMethod(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_set_ActualCompressionMethod(TElZipEntityWinZipAESExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityWinZipAESExtension_Create(TElZipEntityWinZipAESExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYWINZIPAESEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYCERTIFICATESTOREEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_Assign(TElZipEntityCertificateStoreExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_LoadFromBuffer(TElZipEntityCertificateStoreExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_SaveToBuffer(TElZipEntityCertificateStoreExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_get_Version(TElZipEntityCertificateStoreExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_get_StoreData(TElZipEntityCertificateStoreExtensionHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_set_StoreData(TElZipEntityCertificateStoreExtensionHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCertificateStoreExtension_Create(TElZipEntityCertificateStoreExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYCERTIFICATESTOREEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYSIGNATUREEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_Assign(TElZipEntitySignatureExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_LoadFromBuffer(TElZipEntitySignatureExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_SaveToBuffer(TElZipEntitySignatureExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_get_Version(TElZipEntitySignatureExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_get_HashAlgorithm(TElZipEntitySignatureExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_set_HashAlgorithm(TElZipEntitySignatureExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_get_IssuerName(TElZipEntitySignatureExtensionHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_set_IssuerName(TElZipEntitySignatureExtensionHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_get_SerialNumber(TElZipEntitySignatureExtensionHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_set_SerialNumber(TElZipEntitySignatureExtensionHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_get_Signature(TElZipEntitySignatureExtensionHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_set_Signature(TElZipEntitySignatureExtensionHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntitySignatureExtension_Create(TElZipEntitySignatureExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYSIGNATUREEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYCENTRALDIRSIGNATUREEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCentralDirSignatureExtension_Assign(TElZipEntityCentralDirSignatureExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityCentralDirSignatureExtension_Create(TElZipEntityCentralDirSignatureExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYCENTRALDIRSIGNATUREEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYUNIX1EXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_Assign(TElZipEntityUnix1ExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_LoadFromBuffer(TElZipEntityUnix1ExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_SaveToBuffer(TElZipEntityUnix1ExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_get_ModifyTime(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_set_ModifyTime(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_get_AccessTime(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_set_AccessTime(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_get_UIDAndGIDAvailable(TElZipEntityUnix1ExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_set_UIDAndGIDAvailable(TElZipEntityUnix1ExtensionHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_get_UID(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_set_UID(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_get_GID(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_set_GID(TElZipEntityUnix1ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix1Extension_Create(TElZipEntityUnix1ExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYUNIX1EXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYUNIX2EXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_Assign(TElZipEntityUnix2ExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_LoadFromBuffer(TElZipEntityUnix2ExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_SaveToBuffer(TElZipEntityUnix2ExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_get_UIDAndGIDAvailable(TElZipEntityUnix2ExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_set_UIDAndGIDAvailable(TElZipEntityUnix2ExtensionHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_get_UID(TElZipEntityUnix2ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_set_UID(TElZipEntityUnix2ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_get_GID(TElZipEntityUnix2ExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_set_GID(TElZipEntityUnix2ExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUnix2Extension_Create(TElZipEntityUnix2ExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYUNIX2EXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYEXTENDEDTIMESTAMPEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_Assign(TElZipEntityExtendedTimestampExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_LoadFromBuffer(TElZipEntityExtendedTimestampExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_SaveToBuffer(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_ModifyTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_ModifyTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_AccessTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_AccessTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_CreateTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_CreateTimeAvailable(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_ModifyTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_ModifyTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_AccessTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_AccessTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_CreateTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_set_CreateTime(TElZipEntityExtendedTimestampExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_get_CentralHeader(TElZipEntityExtendedTimestampExtensionHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityExtendedTimestampExtension_Create(TElZipEntityExtendedTimestampExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYEXTENDEDTIMESTAMPEXTENSION */

#ifdef SB_USE_CLASS_TELZIPENTITYUIDANDGIDEXTENSION
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_Assign(TElZipEntityUIDAndGIDExtensionHandle _Handle, TElZipEntityExtensionHandle Source);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_LoadFromBuffer(TElZipEntityUIDAndGIDExtensionHandle _Handle, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_SaveToBuffer(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t * Size, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_get_Version(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_get_UID(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_set_UID(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_get_GID(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_set_GID(TElZipEntityUIDAndGIDExtensionHandle _Handle, uint32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElZipEntityUIDAndGIDExtension_Create(TElZipEntityUIDAndGIDExtensionHandle * OutResult);
#endif /* SB_USE_CLASS_TELZIPENTITYUIDANDGIDEXTENSION */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElZipEntity_ce_ptr;
extern zend_class_entry *TElZipLocalFileHeader_ce_ptr;
extern zend_class_entry *TElZipCentralFileHeader_ce_ptr;
extern zend_class_entry *TElZipDataDescriptor_ce_ptr;
extern zend_class_entry *TElZipEntityExtensions_ce_ptr;
extern zend_class_entry *TElZipCentralDirectorySignature_ce_ptr;
extern zend_class_entry *TElZip64EndOfCentralDirectory_ce_ptr;
extern zend_class_entry *TElZip64EndOfCentralDirectoryLocator_ce_ptr;
extern zend_class_entry *TElZipEndOfCentralDirectory_ce_ptr;
extern zend_class_entry *TElZipArchiveExtraData_ce_ptr;
extern zend_class_entry *TElZipProcessor_ce_ptr;
extern zend_class_entry *TElZipEntityExtension_ce_ptr;
extern zend_class_entry *TElZipEntityCustomExtension_ce_ptr;
extern zend_class_entry *TElZipEntityZip64InfoExtension_ce_ptr;
extern zend_class_entry *TElZipEntityStrongEncryptionExtension_ce_ptr;
extern zend_class_entry *TElZipEntityWinZipAESExtension_ce_ptr;
extern zend_class_entry *TElZipEntityCertificateStoreExtension_ce_ptr;
extern zend_class_entry *TElZipEntitySignatureExtension_ce_ptr;
extern zend_class_entry *TElZipEntityCentralDirSignatureExtension_ce_ptr;
extern zend_class_entry *TElZipEntityUnix1Extension_ce_ptr;
extern zend_class_entry *TElZipEntityUnix2Extension_ce_ptr;
extern zend_class_entry *TElZipEntityExtendedTimestampExtension_ce_ptr;
extern zend_class_entry *TElZipEntityUIDAndGIDExtension_ce_ptr;

void SB_CALLBACK TSBZipReadEventRaw(void * _ObjectData, TObjectHandle Sender, void * UserData, uint8_t pBuffer[], int32_t * szBuffer, int32_t Index, int32_t NeededSize, int32_t * Written, int8_t * Last);
void SB_CALLBACK TSBZipWriteEventRaw(void * _ObjectData, TObjectHandle Sender, void * UserData, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size);
void SB_CALLBACK TSBZipLocalFileHeaderLoadedEventRaw(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);
void SB_CALLBACK TSBZipDataDescriptorLoadedEventRaw(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);
void SB_CALLBACK TSBZipCentralFileHeaderLoadedEventRaw(void * _ObjectData, TObjectHandle Sender, TElZipCentralFileHeaderHandle Header);
void SB_CALLBACK TSBZipFileDataEventRaw(void * _ObjectData, TObjectHandle Sender, TElZipLocalFileHeaderHandle Header);
void SB_CALLBACK TSBZipCentralDirectoryProcessEventRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pBuffer[], int32_t szBuffer, int32_t Index, int32_t Size, uint8_t pProcessedData[], int32_t * szProcessedData, int32_t ProcessedIndex, int32_t * ProcessedSize);
void SB_CALLBACK TSBZipArchiveErrorEventRaw(void * _ObjectData, TObjectHandle Sender, int32_t ErrorCode, const char * pcErrorMessage, int32_t szErrorMessage, int8_t * TryContinue);
void Register_TElZipEntity(TSRMLS_D);
void Register_TElZipLocalFileHeader(TSRMLS_D);
void Register_TElZipCentralFileHeader(TSRMLS_D);
void Register_TElZipDataDescriptor(TSRMLS_D);
void Register_TElZipEntityExtensions(TSRMLS_D);
void Register_TElZipCentralDirectorySignature(TSRMLS_D);
void Register_TElZip64EndOfCentralDirectory(TSRMLS_D);
void Register_TElZip64EndOfCentralDirectoryLocator(TSRMLS_D);
void Register_TElZipEndOfCentralDirectory(TSRMLS_D);
void Register_TElZipArchiveExtraData(TSRMLS_D);
void Register_TElZipProcessor(TSRMLS_D);
void Register_TElZipEntityExtension(TSRMLS_D);
void Register_TElZipEntityCustomExtension(TSRMLS_D);
void Register_TElZipEntityZip64InfoExtension(TSRMLS_D);
void Register_TElZipEntityStrongEncryptionExtension(TSRMLS_D);
void Register_TElZipEntityWinZipAESExtension(TSRMLS_D);
void Register_TElZipEntityCertificateStoreExtension(TSRMLS_D);
void Register_TElZipEntitySignatureExtension(TSRMLS_D);
void Register_TElZipEntityCentralDirSignatureExtension(TSRMLS_D);
void Register_TElZipEntityUnix1Extension(TSRMLS_D);
void Register_TElZipEntityUnix2Extension(TSRMLS_D);
void Register_TElZipEntityExtendedTimestampExtension(TSRMLS_D);
void Register_TElZipEntityUIDAndGIDExtension(TSRMLS_D);
void Register_SBZipEntities_Constants(int module_number TSRMLS_DC);

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBZIPENTITIES */

