<?php
    error_reporting(E_ALL);
    date_default_timezone_set("UTC");
    
    $callbacksStr = " <br/>";
    $count = 0;
    $clientCert = null;
    $client = null;
    
    function OnDocumentBegin($Sender)
    {
        global $callbacksStr;
        $callbacksStr .= "<br/> -- Document started -- <br/>";
    }
    
    function OnDocumentEnd($Sender)
    {
        global $callbacksStr;
        $callbacksStr .= "<br/> -- Document finished -- <br/>";
    }
    
    function OnCloseConnection($Sender, $CloseReason)
    {
        global $callbacksStr;
        $callbacksStr .= "<br/> -- Connection closed -- <br/>";
    }
    
    function OnData($Sender, $Buffer, $Size)
    {
        global $callbacksStr;
        if (!$Buffer->isNULL()) {
            $str = SBStrUtils\UTF8ToWideStr($Buffer, $Size);
        } else {
            $str = "Buffer is null";
        }
        $callbacksStr .= "<br/> " .$str . " <br/>";
    }
    
    function OnPreparedHeaders($Sender, $Headers)
    {
        global $callbacksStr;
        $str = $Headers->Text;
        $callbacksStr .= "<br/> Sending headers: <br/>" . $str . " <br/>";
    }
    
    function OnReceivingHeaders($Sender, $Headers)
    {
        global $callbacksStr;
        $str = $Headers->Text;
        $callbacksStr .= "<br/> Received headers: <br/>" . $str . " <br/>";
    }
    
    function OnRedirection($Sender, $OldURL, &$NewURL, &$AllowRedirection)
    {
        global $callbacksStr;
        $AllowRedirection = true;
        $callbacksStr .= "<br/> Redirected from " . $OldURL . " to " . $NewURL . " <br/>";
    }
    
    function OnCertificateNeededEx($Sender, &$Certificate)
    {
        global $callbacksStr;
        global $clientCert;
        global $count;
        if (!is_null($clientCert)) {
            if ($count == 0) {
                $Certificate = $clientCert;
                $count++;
                $issuer = "";
                try {
                    $issuer = GetOIDValue($clientCert->IssuerRDN, SBConstants\SB_CERT_OID_COMMON_NAME_STR);
                    if (strlen($issuer) == 0) {
                        $issuer = GetOIDValue($clientCert->IssuerRDN, SBConstants\SB_CERT_OID_ORGANIZATION_STR);
                    }
                    if (strlen($issuer) == 0) {
                        $issuer = "<unknown>";
                    }
                } catch(SBException $e) {
                    $issuer = "Error while getting certificate issuer: " . $e->getErrorMessage();
                }
                $callbacksStr .= "<br/> Sending client certificate ( " .$issuer ." )<br/>";
            } else {
                $Certificate = null;
                $count = 0;
            }
        } else {
            $Certificate = null;
            $callbacksStr .= "<br/> Client certificate is needed but there is nothing to send <br/>";
        }
    }
    
    function GetOIDValue($RDN, $S)
    {
        $t = "";
        for ($i = 0; $i < $RDN->Count; $i++) {
            $oid = $RDN->get_OIDs($i);
            if (SBStrUtils\StringEquals($oid, $S, true)) {
                if (strlen($t) > 0) {
                    $t .= " / ";
                }
                $t .= $RDN->get_Values($i);
            }
        }
        return $t;
    }
    
    function OnCertificateValidate($Sender, $X509Certificate, &$Validate)
    {
        global $callbacksStr;
        $str = "";
        $rstr = "";
        $vstr = "";
        try {
            $M160 = $X509Certificate->GetHashSHA1();
            $dgst = SBUtils\DigestToStr($M160, true);
            $str = "<br/> Server certificate received, fingerprint " . $dgst;
            if (is_null($X509Certificate->Chain) || ($X509Certificate->Chain->get_Certificates(0)->Equals($X509Certificate))) {
                $validity = TSBCertificateValidity::cvInvalid;
                $reason = 0;
                $HTTPSClient = $Sender->castTo("TElHTTPSClient");
                $rHost = $HTTPSClient->RemoteHost;
                $rIP = $HTTPSClient->RemoteIP;
                // For proper CRL and OCSP validation please read instructions in
                // description of ElX509CertificateValidator class in the help file
                $certificateValidator = new TElX509CertificateValidator(null);
                $certificateValidator->OnBeforeCRLRetrieverUse = "OnBeforeCRLRetrieverUse";
                $certificateValidator->OnBeforeOCSPClientUse = "OnBeforeOCSPClientUse";
                $dt = SBUtils\DateTimeNow();
                $certificateValidator->ValidateForSSL($X509Certificate, $rHost, $rIP, TSBHostRole::hrServer, null, true, $dt, $validity, $reason);
                
                if ($validity == TSBCertificateValidity::cvOk) {
                    $vstr .= "Ok";
                } elseif ($validity == TSBCertificateValidity::cvSelfSigned) {
                    $vstr .= "SelfSigned";
                } elseif ($validity == TSBCertificateValidity::cvInvalid) {
                    $vstr .= "Invalid";
                } elseif ($validity == TSBCertificateValidity::cvStorageError) {
                    $vstr .= "StorageError";
                } elseif ($validity == TSBCertificateValidity::cvChainUnvalidated) {
                    $vstr .= "ChainUnvalidated";
                }
                
                if ($reason & TSBCertificateValidityReason::vrBadData) {
                    $rstr .= "BadData, ";
                }
                if ($reason & TSBCertificateValidityReason::vrRevoked) {
                    $rstr .= "Revoked, ";
                }
                if ($reason & TSBCertificateValidityReason::vrNotYetValid) {
                    $rstr .= "NotYetValid, ";
                }
                if ($reason & TSBCertificateValidityReason::vrExpired) {
                    $rstr .= "Expired, ";
                }
                if ($reason & TSBCertificateValidityReason::vrInvalidSignature) {
                    $rstr .= "InvalidSignature, ";
                }
                if ($reason & TSBCertificateValidityReason::vrUnknownCA) {
                    $rstr .= "UnknownCA, ";
                }
                if ($reason & TSBCertificateValidityReason::vrCAUnauthorized) {
                    $rstr .= "CAUnauthorized, ";
                }
                if ($reason & TSBCertificateValidityReason::vrCRLNotVerified) {
                    $rstr .= "CRLNotVerified, ";
                }
                if ($reason & TSBCertificateValidityReason::vrOCSPNotVerified) {
                    $rstr .= "OCSPNotVerified, ";
                }
                if ($reason & TSBCertificateValidityReason::vrIdentityMismatch) {
                    $rstr .= "IdentityMismatch, ";
                }
                if ($reason & TSBCertificateValidityReason::vrNoKeyUsage) {
                    $rstr .= "NoKeyUsage, ";
                }
                if ($reason & TSBCertificateValidityReason::vrBlocked) {
                    $rstr .= "Blocked, ";
                }
                if (strlen($rstr) > 0) {
                    $rstr = substr($rstr, 0, strlen($rstr) - 2);
                }
                
                $Validate = ($validity == TSBCertificateValidity::cvOk);
            }
            else $Validate = true;// NEVER do this. You MUST check validity somehow
            $str .= " <br/> Server certificate is " . ($Validate ? "VALID" : "NOT VALID");
            if (strlen($vstr) > 0) {
                $str .= ". Validity: " .$vstr;
            }
            if (strlen($rstr) > 0) {
                $str .= ". Reason: " .$rstr;
            }
            if ($Validate == false) {
                $Validate = true;
                $str .= " <br/><p style='color:red'>!!!! Certificate validity was explicitly set to 'true'. Please inspect /Samples/PKIBlackbox/CertValidator/PKI_CertValidator.php demo for proper certificate validation example !!!!</p>";
            }
        } catch (SBException $e) {
            $str = "<br/> Unexpected error in OnCertificateValidate event handler: " . $e->getErrorMessage();
            $Validate = false;
        }
        $callbacksStr .= $str . " <br/>";
    }
    
    function OnBeforeOCSPClientUse($Sender, $Certificate, $CACertificate, $OCSPLocation, &$OCSPClient)
    {
        global $callbacksStr;
        $callbacksStr .= " <br/> OnBeforeOCSPClientUse OCSPLocation = " .$OCSPLocation . " <br/>";
        global $client;
        $OCSPHTTPClient = $OCSPClient->castTo("TElHTTPOCSPClient");
        $OCSPHTTPClient->HTTPClient->UseHTTPProxy = $client->UseHTTPProxy;
        $OCSPHTTPClient->HTTPClient->HTTPProxyHost = $client->HTTPProxyHost;
        $OCSPHTTPClient->HTTPClient->HTTPProxyPort = $client->HTTPProxyPort;
        $OCSPHTTPClient->HTTPClient->HTTPProxyUsername = $client->HTTPProxyUsername;
        $OCSPHTTPClient->HTTPClient->HTTPProxyPassword = $client->HTTPProxyPassword;
    }
    
    function OnBeforeCRLRetrieverUse($Sender, $Certificate, $CACertificate, $NameType, $Location, &$Retriever)
    {
        global $callbacksStr;
        $callbacksStr .= " <br/> OnBeforeCRLRetrieverUse Location = " .$Location ." NameType = " .$NameType ." <br/>";
        global $client;
        $HTTPRetriever = $Retriever->castTo("TElHTTPCRLRetriever");
        $HTTPRetriever->HTTPClient->UseHTTPProxy = $client->UseHTTPProxy;
        $HTTPRetriever->HTTPClient->HTTPProxyHost = $client->HTTPProxyHost;
        $HTTPRetriever->HTTPClient->HTTPProxyPort = $client->HTTPProxyPort;
        $HTTPRetriever->HTTPClient->HTTPProxyUsername = $client->HTTPProxyUsername;
        $HTTPRetriever->HTTPClient->HTTPProxyPassword = $client->HTTPProxyPassword;
    }
    
    if (isset($_POST["post"])) {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) {
            print "SecureBlackbox extension NOT available";
            die;
        }
        
        try {
            if (!SBUtils\GetLicense()) {
                #error Please pick the evaluation license key from <SecureBlackbox>\LicenseKey.txt file and place it in "sbb.license_key" php.ini directive or here. If the evaluation key expires, you can request an extension using the form on https://www.eldos.com/sbb/keyreq/
                SBUtils\SetLicenseKey("<enter license key here>");
            }
        } catch (SBException $e) {
            print "<p style='color:red'>Setting SBB License Key failed with message: <br/>" . $e->getErrorMessage() . "</p>";
            die;
        }
        
        $url = $_POST["url"];
        $filename = "";
        $name = "";
        $dataStr = "";
        if ($_FILES["filename"]["error"] > 0) {
            $dataStr = $_POST["data"];
        } else {
            $filename = $_FILES["filename"]["tmp_name"];
            $name = $_FILES["filename"]["name"];
        }
        $pass = $_POST["pass"];
        $certfile = "";
        if ($_FILES["certfile"]["error"] == 0) {
            $certfile = $_FILES["certfile"]["tmp_name"];
        }
        
        if ((strlen($url) > 0) and ((strlen($filename) > 0) or (strlen($dataStr) > 0))) {
            $error_happened = false;
            $error_details = "";
            
            // The following lines are required for HTTP retrieval of CRLs and OCSP in TElX509CertificateValidator to work
            SBHTTPCRL\RegisterHTTPCRLRetrieverFactory();
            SBHTTPOCSPClient\RegisterHTTPOCSPClientFactory();
            SBHTTPCertRetriever\RegisterHTTPCertificateRetrieverFactory();
            
            $client = new TElHTTPSClient(null);
            $client->HTTPVersion = TSBHTTPVersion::hvHTTP11;
            // see the full list of HTTP versions at https://www.eldos.com/documentation/sbb/documentation/ref_cl_httpsclient_prp_httpversion.html
            $versions = (TSBVersions::sbTLS1 | TSBVersions::sbTLS11 | TSBVersions::sbTLS12);
            // see the full list of SSL/TLS versions at https://www.eldos.com/documentation/sbb/documentation/ref_cl_httpsclient_prp_httpversion.html
            $client->Versions = $versions;
            $client->OnReceivingHeaders = "OnReceivingHeaders";
            $client->OnDocumentBegin = "OnDocumentBegin";
            $client->OnCloseConnection = "OnCloseConnection";
            $client->OnRedirection = "OnRedirection";
            $client->OnDocumentEnd = "OnDocumentEnd";
            $client->OnData = "OnData";
            $client->OnPreparedHeaders = "OnPreparedHeaders";
            $client->OnCertificateValidate = "OnCertificateValidate";
            $client->OnCertificateNeededEx = "OnCertificateNeededEx";
            
            if (strlen($certfile) > 0) {
                $clientCert = new TElX509Certificate(null);
                try {
                    $res = $clientCert->LoadFromFileAuto($certfile, $pass);
                    if ($res != 0) {
                        $error_happened = true;
                        $cert = null;
                        $error_details = "Loading client certificate failed with error: " . $res;
                    }
                } catch(SBException $e) {
                    $error_happened = true;
                    $cert = null;
                    $error_details = "Loading client certificate failed with message: " . $e->getErrorMessage();
                }
            }
            
            if (!$error_happened) {
                try {
                    if ($client->Active) {
                        $client->CancelRequest();
                        $client->ClearRequest();
                        $client->ClearResponse();
                        $client->Close(true);
                    }
                    
                    if (strlen($filename) > 0) {
                        $sFile = new TFileStream($filename, TFileMode::fmOpenRead);
                        $multiPart = new TElStringList();
                        $multiPart->Add("upload=Upload1");
                        $multiPart->Add("upload=Upload2");
                        try {
                            $client->PostWebForm($url, $multiPart, "input_file", $name, $sFile, "", false);
                            $sFile->Free();
                        } catch(SBException $e) {
                            $sFile->Free();
                            $error_happened = true;
                            $error_details = "HTTPS POST request failed with message: " . $e->getErrorMessage();
                        }
                    } else {
                        $client->Post($url, $dataStr);
                    }
                    $client->Close(true);
                } catch(SBException $e) {
                    $error_happened = true;
                    $error_details = "HTTPS POST request failed with message: " . $e->getErrorMessage();
                }
            }
            
            if (!$error_happened) {
                print $callbacksStr ." <br/><br/>";
                if (strlen($filename) > 0) {
                    print "File '" .$filename ."' was successfully posted";
                } elseif (strlen($dataStr) > 0) {
                    print "Data '" .$dataStr ."' was successfully posted";
                } else {
                    print "Something wrong happened..";
                }
            } else {
                print "Error happened: <br/>" . $error_details . " <br/>" . $callbacksStr;
            }
            
            return;
        } else {
            $error_details = "";
            if (strlen($url) == 0) {
                $error_details .= "URL is empty <br/>";
            }
            if ((strlen($filename) == 0) and (strlen($dataStr) == 0)) {
                $error_details = $error_details . "File/Data for uploading is not specified <br/>";
            }
            print "Error happened: <br/><br/>" . $error_details;
        }
    }
?>

<html>
<head>
  <title>EldoS HTTPS Post demo</title>
  <style type="text/css">
  .textheader {
    font-family: Arial;
    font-size: 16;
    font-weight: bold;
  }
  .textnormal {
    font-family: Arial;
    font-size: 12;
  }
  </style>
</head>
<body>
  <div align="center">
  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">
    <tr height="*"></tr>
    <tr height="400">
      <td width="600" valign="top">
        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">
          <tr height="50">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textheader">EldoS SecureBlackbox HTTPS Post demo</div>
            </td>
          </tr>
          <tr height="70">
            <td width="100%" height="*" align="center" valign="center" class="textnormal">
              <div align="center"> This sample illustrates the use of SecureBlackbox HTTPS components for uploading data to remote host over HTTP or HTTPS connection via PHP calls on the server side. <br/>
              Please provide the full host URL in the text box below, select file for uloading and select client certificate file if needed, next click the 'Post' button to post data. </div>
            </td>
          </tr>
          <tr height="*">
            <td width="100%" height="*">
              <form action="" method="post" enctype="multipart/form-data">
                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">
                  <tr height="30">
                    <td width="25%" align="right"> URL: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input width="20" type="text" name="url" value="http://www.eldos.com:80/" size="40" /> <td>
                  </tr>
                  <tr height="30">
                    <td width="35%" align="right"> Client certificate file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="certfile" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="35%" align="right"> Client certificate passphrase: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input width="20" type="password" name="pass" value="" size="20" /> <td>
                  </tr>
                  <tr height="30">
                    <td width="35%" align="right"> File to upload: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="filename" value="" size="50" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="25%" align="right"> or DataString to upload: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="text" name="data" value="Hello from PHP HTTPS Post Demo" size="40" /> </td>
                  </tr>
                  <tr height="45" valign="center">
                    <td colspan="3" align="center"> <input type="submit" name="post" value="Post"/> </td>
                  </tr>
                  <tr height="30" valign="bottom">
                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>
                  </tr>
                </table>
              </form>
            </td>
          </tr>
          <tr height="20">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>
            </td>
          </tr>
        </table>
      </td>
    </tr>
    <tr height="*"></tr>
  </table>
  </div>
</body>
</html>