<?php
    error_reporting(E_ALL);
    date_default_timezone_set("UTC");
    
    $pass = "";
    $cprocess = "";
    
    function OnUserActionNeeded($Sender, $ForEvent, $Description, $Param, &$UserAction)
    {
        global $cprocess;
        $cprocess .= "Compression. " .$Description ." <br/>";
        $UserAction = SBArcZip\ZIP_ACTION_ABORT;
        // see information about OnUserActionNeeded callback at https://www.eldos.com/documentation/sbb/documentation/ref_cl_zipreader_evt_onuseractionneeded.html
    }
    
    function OnCompressionStart($Sender, $Entry, &$Compress)
    {
        $path = $Entry->Path;
        global $cprocess;
        $cprocess .= "Compression. Current file: " .$path ." <br/>";
    }
    
    function OnCompressionFinished($Sender, $Entry)
    {
        if (!$Entry->IsDirectory) {
            $name = $Entry->FileName;
            global $cprocess;
            $cprocess .= "Compression. File compressed: " .$name ." <br/>";
        }
    }
    
    function OnPasswordNeeded($Sender, $Param, &$Password, &$Cancel)
    {
        global $pass;
        $Password = $pass;
    }
    
    function OnProgress($Sender, $Processed, $Total, $OverallProcessed, $OverallTotal, &$Cancel)
    {
        global $cprocess;
        $cprocess .= "Compression. Progress: current " .$Processed ." / " .$Total .", total " .$OverallProcessed ." / " .$OverallTotal ." <br/>";
    }
    
    if (isset($_POST["pack"])) {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) {
            print "SecureBlackbox extension NOT available";
            die;
        }
        
        try {
            if (!SBUtils\GetLicense()) {
                #error Please pick the evaluation license key from <SecureBlackbox>\LicenseKey.txt file and place it in "sbb.license_key" php.ini directive or here. If the evaluation key expires, you can request an extension using the form on https://www.eldos.com/sbb/keyreq/
                SBUtils\SetLicenseKey("<enter license key here>");
            }
        } catch (SBException $e) {
            print "<p style='color:red'>Setting SBB License Key failed with message: <br/>" . $e->getErrorMessage() . "</p>";
            die;
        }
        
        $pass = $_POST["pass"];
        $filename = "";
        if ($_FILES["filename"]["error"] == 0) {
            $filename = $_FILES["filename"]["tmp_name"];
        }
        
        if (strlen($filename) > 0) {
            $error_happened = false;
            $error_details = "";
            
            $zipWriter = new TElZipWriter(null);
            $zipWriter->OnUserActionNeeded = "OnUserActionNeeded";
            $zipWriter->OnCompressionStart = "OnCompressionStart";
            $zipWriter->OnCompressionFinished = "OnCompressionFinished";
            $zipWriter->OnPasswordNeeded = "OnPasswordNeeded";
            $zipWriter->OnProgress = "OnProgress";
            
            try {
                // compression algorithm
                $zipWriter->CompressionAlgorithm = SBZipUtils\ZIP_COMPRESSION_BZIP2;
                // see the full list of compression algorithm constants at https://www.eldos.com/documentation/sbb/documentation/ref_cl_zipwriter_prp_compressionalgorithm.html
                
                // compression level
                $zipWriter->CompressionLevel = 6; //Normal
                // see the full list of compression levels at https://www.eldos.com/documentation/sbb/documentation/ref_cl_zipwriter_prp_compressionlevel.html
                
                // compress directory
                $zipWriter->DirectoryCompressed = true;
                
                // encryption algorithm
                if (strlen($pass) > 0) {
                    $zipWriter->Encrypt = true;
                    $atype = $_POST["atype"];
                    
                    if ($atype == "Zip") {
                        $zipWriter->StrongEncryption = false;
                        $zipWriter->WinZipEncryption = false;
                    } elseif ($atype == "WinZip") {
                        $zipWriter->StrongEncryption = false;
                        $zipWriter->WinZipEncryption = true;
                        
                        $zipWriter->WinZipAesKeySize = 256;
                        // see the full list of WinZip AES key sizes at https://www.eldos.com/documentation/sbb/documentation/ref_cl_zipwriter_prp_winzipaeskeysize.html
                    } elseif ($atype == "PKWare") {
                        $zipWriter->StrongEncryption = true;
                        $zipWriter->WinZipEncryption = false;
                        
                        $sei = $zipWriter->StrongEncryptionInfo;
                        $sei->EncryptionAlgorithm = SBZipUtils\ZIP_ENCRYPTION_AES256;
                        // see the full list of encryption algorithm constants at https://www.eldos.com/documentation/sbb/documentation/ref_cl_zipstrongencryptioninfo_prp_encryptionalgorithm.html
                        
                        $zipWriter->DirectoryEncrypted = true;
                        if ($zipWriter->DirectoryEncrypted) {
                            $zipWriter->DirectoryCompressed = true;
                        }
                    }
                    
                    $zipWriter->Password = $pass;
                } else {
                    $zipWriter->Encrypt = false;
                }
                $zipWriter->CreateArchive();
                $zipWriter->Add($filename);
                $outputPath = SBStrUtils\SBExtractFilePath($filename);
                $dt = SBUtils\DateTimeNow();
                $aname = "archive" .$dt->format('YmdHis') .".zip";
                $outputPath = SBStrUtils\PathConcatenate($outputPath, $aname);
                $zipWriter->Compress($outputPath);
            } catch(SBException $e) {
                $error_happened = true;
                $error_details = "Packing zip archive failed with message: " . $e->getErrorMessage();
            }
            
            if (!$error_happened) {
                if (strlen($cprocess) == 0) {
                    print "Zero files were compressed";
                } else {
                    print "Compression process: <br/><br/>" .$cprocess;
                }
            } else {
                print "Error happened: <br/>" . $error_details;
            }
            
            return;
        } else {
            $error_details = "";
            if (strlen($filename) == 0) {
                $error_details = $error_details . "File for packing into archive is not specified <br/>";
            }
            print "Error happened: <br/><br/>" . $error_details;
        }
    } 
?>

<html>
<head>
  <title>EldoS ZIP Writer demo</title>
  <style type="text/css">
  .textheader {
    font-family: Arial;
    font-size: 16;
    font-weight: bold;
  }
  .textnormal {
    font-family: Arial;
    font-size: 12;
  }
  </style>
</head>
<body>
  <div align="center">
  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">
    <tr height="*"></tr>
    <tr height="400">
      <td width="600" valign="top">
        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">
          <tr height="50">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textheader">EldoS SecureBlackbox ZIP Writer demo</div>
            </td>
          </tr>
          <tr height="70">
            <td width="100%" height="*" align="center" valign="center" class="textnormal">
              <div align="center"> This sample illustrates the use of SecureBlackbox components for packing zip archive. <br/>
              Please select file for packing into archive and provide archive password and archive type if needed, next click the 'Pack' button to pack archive. </div>
            </td>
          </tr>
          <tr height="*">
            <td width="100%" height="*">
              <form action="" method="post" enctype="multipart/form-data">
                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">
                  <tr height="30">
                    <td width="40%" align="right"> File: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="filename" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right"> Archive password: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input width="20" type="password" name="pass" value="" size="20" /> <td>
                  </tr>
                  <tr height="30" valign="center">
                    <td colspan="3" align="center"> Archive type: </td>
                  </tr>
                  <tr height="30" valign="center">
                    <td colspan="3" align="center"> <label><input type ="radio" checked="checked" name="atype" value="Zip" /> Zip (weak)</label> <td>
                  </tr>
                  <tr height="30" valign="center">
                    <td colspan="3" align="center"> <label><input type ="radio" name="atype" value="WinZip" /> WinZip AES</label> <td>
                  </tr>
                  <tr height="30" valign="center">
                    <td colspan="3" align="center"> <label><input type ="radio" name="atype" value="PKWare" /> PKWare Strong Encryption</label> <td>
                  </tr>
                  <tr height="45" valign="center">
                    <td colspan="3" align="center"> <input type="submit" name="pack" value="Pack"/> </td>
                  </tr>
                  <tr height="30" valign="bottom">
                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>
                  </tr>
                </table>
              </form>
            </td>
          </tr>
          <tr height="20">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>
            </td>
          </tr>
        </table>
      </td>
    </tr>
    <tr height="*"></tr>
  </table>
  </div>
</body>
</html>